@@ -6,6 +6,8 @@ var _ogre_prerequisites_8h =
     [ "multimap", "struct_ogre_1_1multimap.html", "struct_ogre_1_1multimap" ],
     [ "set", "struct_ogre_1_1set.html", "struct_ogre_1_1set" ],
     [ "vector", "struct_ogre_1_1vector.html", "struct_ogre_1_1vector" ],
+    [ "OGRE_TOKEN_PASTE_INNER", "_ogre_prerequisites_8h.html#aedf23cd1e0d0cca2268388ba1d64ba3d", null ],
+    [ "OGRE_TOKEN_PASTE", "_ogre_prerequisites_8h.html#aadfaee1c10a53055c49ad591cbbb9e38", null ],
     [ "OGRE_VERSION", "_ogre_prerequisites_8h.html#a3f631403da0a255c201870bfd068f8c5", null ],
     [ "OGRE_HashMap", "_ogre_prerequisites_8h.html#aae66141905ddac9ea7b0a562d2dab69d", null ],
     [ "OGRE_HashMultiMap", "_ogre_prerequisites_8h.html#a669d1b4211776fa2d7fdbf0e17ecd304", null ],
@@ -21,6 +23,7 @@ var _ogre_prerequisites_8h =
     [ "Vector3", "_ogre_prerequisites_8h.html#ac94fc4008c1165dea017263fee56b273", null ],
     [ "Vector3i", "_ogre_prerequisites_8h.html#aecf82a286f08cdf003677d472d33989b", null ],
     [ "Vector4", "_ogre_prerequisites_8h.html#a739a289a4d5235f5f509a1795f5ffd5b", null ],
+    [ "Vector4f", "_ogre_prerequisites_8h.html#a272ffe59e216908cce70c5fd11eaa7ff", null ],
     [ "AnimableValuePtr", "_ogre_prerequisites_8h.html#a5e0882c3b9f7ca32a795f98cf034e428", null ],
     [ "CompositorPtr", "_ogre_prerequisites_8h.html#a1c816d34e4e50e5b65e60ecc9451f94f", null ],
     [ "DataStreamPtr", "_ogre_prerequisites_8h.html#a8a2a961b4205aacff9c01e81e08d7781", null ],
