@@ -1,8 +1,6 @@
 var _ogre_shader_ex_per_pixel_lighting_8h =
 [
     [ "SGX_LIB_PERPIXELLIGHTING", "group___r_t_shader.html#ga62fd9d3400be2887116459919fa3d3aa", null ],
-    [ "SGX_FUNC_TRANSFORMNORMAL", "group___r_t_shader.html#gac4c2f56c704cf41f9900c7d508b386c3", null ],
-    [ "SGX_FUNC_TRANSFORMPOSITION", "group___r_t_shader.html#ga41be37c0f0861c758b33e240ab11378a", null ],
     [ "SGX_FUNC_LIGHT_DIRECTIONAL_DIFFUSE", "group___r_t_shader.html#ga75eb5ea0eac488234a8749b8a86ae918", null ],
     [ "SGX_FUNC_LIGHT_DIRECTIONAL_DIFFUSESPECULAR", "group___r_t_shader.html#gae56f940b43f696b1d9c90a5d419903d8", null ],
     [ "SGX_FUNC_LIGHT_POINT_DIFFUSE", "group___r_t_shader.html#ga783580599433f492381773aff51b3e66", null ],
