@@ -1,13 +1,13 @@
 var _runtime__shader__generation =
 [
     [ "RTSS: Run Time Shader System", "rtss.html", [
-      [ "Core features of the system", "rtss.html#core-feats", null ],
+      [ "RTSS properties in Material Scripts", "rtss.html#rtss_custom_mat", null ],
       [ "System overview", "rtss.html#rtss_overview", [
-        [ "Customizing the RTSS using Material Scripts", "rtss.html#rtss_custom_mat", null ],
-        [ "Customising the RTSS using the API", "rtss.html#rtss_custom_api", null ]
+        [ "Core features of the system", "rtss.html#core-feats", null ]
       ] ],
       [ "The RTSS in Depth", "rtss.html#rtss_indepth", [
         [ "Main components", "rtss.html#rtss__components", null ],
+        [ "Customizing the default RenderState", "rtss.html#rtss_custom_api", null ],
         [ "Creating shader based technique", "rtss.html#rtssTech", null ],
         [ "Runtime shader generation", "rtss.html#rtssGenerate", null ],
         [ "Creating custom shader extensions", "rtss.html#creating-extensions", null ],
