@@ -1,13 +1,10 @@
 var class_ogre_1_1_c_preprocessor =
 [
-    [ "ErrorHandlerFunc", "class_ogre_1_1_c_preprocessor.html#ad9572bfcaa1b4a3e290d6d3586664539", null ],
     [ "CPreprocessor", "class_ogre_1_1_c_preprocessor.html#a70001f3fef03cc20b5142e67702c3b3f", null ],
     [ "~CPreprocessor", "class_ogre_1_1_c_preprocessor.html#a2b7c3b1a3208a27b36e87eee69464508", null ],
     [ "Define", "class_ogre_1_1_c_preprocessor.html#a3026667d0f447d89bcac3fd8c6007a00", null ],
     [ "Define", "class_ogre_1_1_c_preprocessor.html#a70c0a271d5ea9dcf93d13f9c08318458", null ],
     [ "Undef", "class_ogre_1_1_c_preprocessor.html#a3849848c4223928aea432f66184d541e", null ],
     [ "Parse", "class_ogre_1_1_c_preprocessor.html#ac9c8ca6c8013a5217275e35e9727052d", null ],
-    [ "CPreprocessor::Macro", "class_ogre_1_1_c_preprocessor.html#ae5a6f539ddabca71928dd965f2211434", null ],
-    [ "ErrorHandler", "class_ogre_1_1_c_preprocessor.html#ad335ac476f629eb7668c8189b21fb232", null ],
-    [ "ErrorData", "class_ogre_1_1_c_preprocessor.html#a0341555997c45e9d084154c04fd83ecc", null ]
+    [ "CPreprocessor::Macro", "class_ogre_1_1_c_preprocessor.html#ae5a6f539ddabca71928dd965f2211434", null ]
 ];
\ No newline at end of file
