@@ -17,7 +17,9 @@ var class_ogre_1_1_d3_d11_render_texture =
     [ "D3D11RenderTexture", "class_ogre_1_1_d3_d11_render_texture.html#ae602da17c8ef0ed3f4e069ee28b6948e", null ],
     [ "~D3D11RenderTexture", "class_ogre_1_1_d3_d11_render_texture.html#add0fdcad757f28278ff23548409751a3", null ],
     [ "rebind", "class_ogre_1_1_d3_d11_render_texture.html#ad028e211ccd347372404245580d92d1e", null ],
-    [ "getCustomAttribute", "class_ogre_1_1_d3_d11_render_texture.html#a0e7d714194282d87c7e01f36ed0f1ed2", null ],
+    [ "getNumberOfViews", "class_ogre_1_1_d3_d11_render_texture.html#abe6819d5c0316f89faee35e6879afa34", null ],
+    [ "getSurface", "class_ogre_1_1_d3_d11_render_texture.html#ac669be7f31c732dea15052aac4a69e3e", null ],
+    [ "getRenderTargetView", "class_ogre_1_1_d3_d11_render_texture.html#a8edf2a8a9484716311848496ea10c9c9", null ],
     [ "requiresTextureFlipping", "class_ogre_1_1_d3_d11_render_texture.html#a7e0203debb5051ba46a24276e2629dea", null ],
     [ "copyContentsToMemory", "class_ogre_1_1_d3_d11_render_texture.html#ab251ab4046e34b249be7d85ed7a358db", null ],
     [ "copyContentsToMemory", "class_ogre_1_1_d3_d11_render_texture.html#a62f7ce3ddeb263e5561c8521401f4ad6", null ],
@@ -46,6 +48,7 @@ var class_ogre_1_1_d3_d11_render_texture =
     [ "removeAllViewports", "class_ogre_1_1_d3_d11_render_texture.html#a0c00ca9d1ba7f3efc248ae86511fbff9", null ],
     [ "getStatistics", "class_ogre_1_1_d3_d11_render_texture.html#ac3738d38363cf3188e7ad86c92f1af06", null ],
     [ "resetStatistics", "class_ogre_1_1_d3_d11_render_texture.html#add4ba5bd15bc4920c19c5e823d5b2c22", null ],
+    [ "getCustomAttribute", "class_ogre_1_1_d3_d11_render_texture.html#a6c32524efacf6da599d5daccf3d9e166", null ],
     [ "getCustomAttribute", "class_ogre_1_1_d3_d11_render_texture.html#a7d424cfbab20149fad8a7caf6c2ed07e", null ],
     [ "addListener", "class_ogre_1_1_d3_d11_render_texture.html#a1799514a8ad7958919ca48c654a47e8e", null ],
     [ "insertListener", "class_ogre_1_1_d3_d11_render_texture.html#a8263e7bbed9eea3b8452c9e315c41ee3", null ],
