@@ -18,7 +18,7 @@ var class_ogre_1_1_d3_d9_texture =
     [ "D3D9Texture", "class_ogre_1_1_d3_d9_texture.html#a32ce5899ef0c534de28ec4c1f3a601f0", null ],
     [ "~D3D9Texture", "class_ogre_1_1_d3_d9_texture.html#aedec7c3a2b04b5c8046782ebf8a05fc8", null ],
     [ "copyToTexture", "class_ogre_1_1_d3_d9_texture.html#a9877df680d0756fa081a3a558ac94b2a", null ],
-    [ "getBuffer", "class_ogre_1_1_d3_d9_texture.html#a31a756c7827434953aa06a3a63c4b96e", null ],
+    [ "getBuffer", "class_ogre_1_1_d3_d9_texture.html#a65829361eb6b2a1ad7fb713b53bedba8", null ],
     [ "getTexture", "class_ogre_1_1_d3_d9_texture.html#a3a293ab98e82f11ed97450eeba5b6094", null ],
     [ "getNormTexture", "class_ogre_1_1_d3_d9_texture.html#a9bbf9b1af398cfc80ab7678797039bb5", null ],
     [ "getCubeTexture", "class_ogre_1_1_d3_d9_texture.html#ae46c60b0e5468caadae17b5772393a76", null ],
@@ -71,7 +71,7 @@ var class_ogre_1_1_d3_d9_texture =
     [ "getCustomAttribute", "class_ogre_1_1_d3_d9_texture.html#accfa5467ab8ccfc5920ec64101f8f532", null ],
     [ "getCustomAttribute", "class_ogre_1_1_d3_d9_texture.html#a4b257658297582848fe47a027f75bb3a", null ],
     [ "createShaderAccessPoint", "class_ogre_1_1_d3_d9_texture.html#ad233adde489a5b2129eb20fc93952839", null ],
-    [ "createShaderAccessPoint", "class_ogre_1_1_d3_d9_texture.html#a2f3077804bdbef1f118c415c23f05a67", null ],
+    [ "setLayerNames", "class_ogre_1_1_d3_d9_texture.html#aa539a94d1bd9ea8f4e804093be538c3e", null ],
     [ "prepare", "class_ogre_1_1_d3_d9_texture.html#a350b287fa3e83a389221274f68760008", null ],
     [ "load", "class_ogre_1_1_d3_d9_texture.html#a699d1c851f494a8d5d23d23b695ceb47", null ],
     [ "reload", "class_ogre_1_1_d3_d9_texture.html#a5016aec1762b026997ddd346775879ef", null ],
