@@ -63,10 +63,10 @@ var class_ogre_1_1_g_l_e_s2_texture =
     [ "setTreatLuminanceAsAlpha", "class_ogre_1_1_g_l_e_s2_texture.html#a963616fe631db2b5bef45234a15bff7f", null ],
     [ "getTreatLuminanceAsAlpha", "class_ogre_1_1_g_l_e_s2_texture.html#af10046684f1810855fdc76bde88ec8d6", null ],
     [ "getNumFaces", "class_ogre_1_1_g_l_e_s2_texture.html#a31d04160addb56e190c5155c21f998bf", null ],
-    [ "getBuffer", "class_ogre_1_1_g_l_e_s2_texture.html#a7ebc51ffe79ea6bffd8ea45f1faf53c7", null ],
+    [ "getBuffer", "class_ogre_1_1_g_l_e_s2_texture.html#a1381484c57cf3d8f2f480c834f164950", null ],
     [ "convertToImage", "class_ogre_1_1_g_l_e_s2_texture.html#a6c5c6be0ec434481a055ab6b03b644fd", null ],
     [ "createShaderAccessPoint", "class_ogre_1_1_g_l_e_s2_texture.html#ad233adde489a5b2129eb20fc93952839", null ],
-    [ "createShaderAccessPoint", "class_ogre_1_1_g_l_e_s2_texture.html#a2f3077804bdbef1f118c415c23f05a67", null ],
+    [ "setLayerNames", "class_ogre_1_1_g_l_e_s2_texture.html#aa539a94d1bd9ea8f4e804093be538c3e", null ],
     [ "prepare", "class_ogre_1_1_g_l_e_s2_texture.html#a350b287fa3e83a389221274f68760008", null ],
     [ "load", "class_ogre_1_1_g_l_e_s2_texture.html#a699d1c851f494a8d5d23d23b695ceb47", null ],
     [ "reload", "class_ogre_1_1_g_l_e_s2_texture.html#a5016aec1762b026997ddd346775879ef", null ],
