@@ -4,7 +4,6 @@ var class_ogre_1_1_g_l_gpu_program_manager =
     [ "SyntaxCodes", "class_ogre_1_1_g_l_gpu_program_manager.html#abc416b46732467b3b90cfd1332adb57e", null ],
     [ "SharedParametersMap", "class_ogre_1_1_g_l_gpu_program_manager.html#a2f14bd2002eb4be4b1d5ce5fb68fa505", null ],
     [ "Microcode", "class_ogre_1_1_g_l_gpu_program_manager.html#aef34af73ab87b0b09d2707ebeb43508d", null ],
-    [ "MicrocodeMap", "class_ogre_1_1_g_l_gpu_program_manager.html#a54909323000a5cb8e25585d3d54886c5", null ],
     [ "ResourceCreateOrRetrieveResult", "class_ogre_1_1_g_l_gpu_program_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5", null ],
     [ "ResourceMap", "class_ogre_1_1_g_l_gpu_program_manager.html#a849d25862f43feec07252f0ae139c3e4", null ],
     [ "ResourceWithGroupMap", "class_ogre_1_1_g_l_gpu_program_manager.html#a31a40854bf7ade620d6632550f2c474b", null ],
@@ -24,8 +23,8 @@ var class_ogre_1_1_g_l_gpu_program_manager =
     [ "createProgram", "class_ogre_1_1_g_l_gpu_program_manager.html#a3fa0473ad1390af99f69325c2eced427", null ],
     [ "createProgramFromString", "class_ogre_1_1_g_l_gpu_program_manager.html#a1eadda53bbed16d5a3804cdba2ad687e", null ],
     [ "create", "class_ogre_1_1_g_l_gpu_program_manager.html#a964ed591329cc8046c9fbab0713a35ce", null ],
-    [ "getResourceByName", "class_ogre_1_1_g_l_gpu_program_manager.html#a7c5eb595d0c757d3cd390e0f92b71c22", null ],
-    [ "getResourceByName", "class_ogre_1_1_g_l_gpu_program_manager.html#a0154dd3f0ed6e8665eecab30d2535101", null ],
+    [ "getResourceByName", "class_ogre_1_1_g_l_gpu_program_manager.html#a8d99991e69e8aee53afcfa6f9df7b6a8", null ],
+    [ "getResourceByName", "class_ogre_1_1_g_l_gpu_program_manager.html#ad43bb4fa7094b05f1a167869dd9ce2ab", null ],
     [ "createSharedParameters", "class_ogre_1_1_g_l_gpu_program_manager.html#a4d6b9934b69d6c0731d717b22fae5715", null ],
     [ "getSharedParameters", "class_ogre_1_1_g_l_gpu_program_manager.html#a2aebd515c488f378e859db9bded95412", null ],
     [ "getAvailableSharedParameters", "class_ogre_1_1_g_l_gpu_program_manager.html#a499cfbb66f95aeefa240f4f0963cfa40", null ],
@@ -34,14 +33,10 @@ var class_ogre_1_1_g_l_gpu_program_manager =
     [ "isCacheDirty", "class_ogre_1_1_g_l_gpu_program_manager.html#a3e5398bdfcac88d573ea1dc0ba68e5aa", null ],
     [ "canGetCompiledShaderBuffer", "class_ogre_1_1_g_l_gpu_program_manager.html#a398a837adb041741e0610fd6ef55a8bd", null ],
     [ "isMicrocodeAvailableInCache", "class_ogre_1_1_g_l_gpu_program_manager.html#a9a4fccaf335882f3bb7100720ca23898", null ],
-    [ "isMicrocodeAvailableInCache", "class_ogre_1_1_g_l_gpu_program_manager.html#a5c4d7937ba6853713c93f92926d81636", null ],
     [ "getMicrocodeFromCache", "class_ogre_1_1_g_l_gpu_program_manager.html#ae7acf64f3adbc17a0e47a4ceebfc734a", null ],
-    [ "getMicrocodeFromCache", "class_ogre_1_1_g_l_gpu_program_manager.html#abda46c72f94bdc55924c5b576b756b52", null ],
     [ "createMicrocode", "class_ogre_1_1_g_l_gpu_program_manager.html#aa9241f45587eeb1a782f76cbbfed297c", null ],
     [ "addMicrocodeToCache", "class_ogre_1_1_g_l_gpu_program_manager.html#ab03fd65fa6ec3cd96a5befd84b267c39", null ],
-    [ "addMicrocodeToCache", "class_ogre_1_1_g_l_gpu_program_manager.html#a8958f8db9cf1f41f793e4f527f87e7ec", null ],
     [ "removeMicrocodeFromCache", "class_ogre_1_1_g_l_gpu_program_manager.html#a7c762394e6b263c5274749596dc244cd", null ],
-    [ "removeMicrocodeFromCache", "class_ogre_1_1_g_l_gpu_program_manager.html#ab65b0ea866a94fc21c7a4184a76241a1", null ],
     [ "saveMicrocodeCache", "class_ogre_1_1_g_l_gpu_program_manager.html#a93cdcdf09ee4d5b0cd500fdede40a980", null ],
     [ "loadMicrocodeCache", "class_ogre_1_1_g_l_gpu_program_manager.html#a5fa836987040eb3d22753d58ce53ea3d", null ],
     [ "getSingleton", "class_ogre_1_1_g_l_gpu_program_manager.html#a215f8a158be2840363627ee55161de0c", null ],
