@@ -2,8 +2,9 @@ var class_ogre_1_1_g_l_p_buffer =
 [
     [ "GLPBuffer", "class_ogre_1_1_g_l_p_buffer.html#aefe478999b828ccb021c7abc9103a0c8", null ],
     [ "~GLPBuffer", "class_ogre_1_1_g_l_p_buffer.html#a2708f8444c54a26066b253d21d326c6c", null ],
-    [ "getContext", "class_ogre_1_1_g_l_p_buffer.html#a5909ad1a50959ec9c33b0adaed554eba", null ],
     [ "getFormat", "class_ogre_1_1_g_l_p_buffer.html#a79f78d53cfc6f515136ca9c5a488b1ae", null ],
     [ "getWidth", "class_ogre_1_1_g_l_p_buffer.html#a861572560ca5c8ed9e1127bb2c190f71", null ],
-    [ "getHeight", "class_ogre_1_1_g_l_p_buffer.html#a073f8f6ef43df6c9e9b9a0235802fba5", null ]
+    [ "getHeight", "class_ogre_1_1_g_l_p_buffer.html#a073f8f6ef43df6c9e9b9a0235802fba5", null ],
+    [ "getContext", "class_ogre_1_1_g_l_p_buffer.html#afc98ccbed3a3d1b4b738c07296d6eb4b", null ],
+    [ "getFBO", "class_ogre_1_1_g_l_p_buffer.html#afa7a57f77f868d3e76b02d2a5a3682a6", null ]
 ];
\ No newline at end of file
