@@ -4,28 +4,27 @@ var class_ogre_1_1_g_l_render_system =
     [ "RenderTargetIterator", "class_ogre_1_1_g_l_render_system.html#a50a15a7bbc1beca5c91b6584a3060f1b", null ],
     [ "GLRenderSystem", "class_ogre_1_1_g_l_render_system.html#a645c652995972bdc77ab87fa550fd4f9", null ],
     [ "~GLRenderSystem", "class_ogre_1_1_g_l_render_system.html#a5cdbf5bc81db26a06ea374852f8c06db", null ],
+    [ "getFixedFunctionParams", "class_ogre_1_1_g_l_render_system.html#a79ca1f9beaf50123ce51da1d08682e51", null ],
+    [ "applyFixedFunctionParams", "class_ogre_1_1_g_l_render_system.html#a08741bce3fbc7f92c2b84442a9a64aab", null ],
     [ "getName", "class_ogre_1_1_g_l_render_system.html#a974b45a7e0833185453341e445c78e12", null ],
-    [ "_initialise", "class_ogre_1_1_g_l_render_system.html#ab2660f106ccb2302539178ad146d7e89", null ],
+    [ "_initialise", "class_ogre_1_1_g_l_render_system.html#ae5c12ef7ad0ab10bcc8828feb9069c4f", null ],
     [ "createRenderSystemCapabilities", "class_ogre_1_1_g_l_render_system.html#aafc7c5d46e828ccf79af4ddb551fa0d4", null ],
     [ "initialiseFromRenderSystemCapabilities", "class_ogre_1_1_g_l_render_system.html#a3e98fb2adf19867876058115dd0b9bcb", null ],
     [ "shutdown", "class_ogre_1_1_g_l_render_system.html#a991465d648db98639dbdb73151ba73bc", null ],
-    [ "setAmbientLight", "class_ogre_1_1_g_l_render_system.html#a8d2f10981ce7e0dc5f034cc610f2593b", null ],
     [ "setShadingType", "class_ogre_1_1_g_l_render_system.html#a0eb20e9e23aa15f29f95196b2c5cb195", null ],
     [ "setLightingEnabled", "class_ogre_1_1_g_l_render_system.html#a8ad91e7b5c78abc64f9d863043169d2b", null ],
     [ "_createRenderWindow", "class_ogre_1_1_g_l_render_system.html#af902bf35fc1eb207d76fe573ecc3b931", null ],
     [ "_createRenderWindows", "class_ogre_1_1_g_l_render_system.html#a24f267e0a7de0572930047282a5f60cb", null ],
     [ "_createDepthBufferFor", "class_ogre_1_1_g_l_render_system.html#a0eb41719e67485588227e29dee1441ea", null ],
-    [ "_getDepthStencilFormatFor", "class_ogre_1_1_g_l_render_system.html#a49cd301c80bfcbf591161c6ac6fb3b5a", null ],
     [ "createMultiRenderTarget", "class_ogre_1_1_g_l_render_system.html#ae6648d7257c68fdebd1dc751848b637b", null ],
     [ "destroyRenderWindow", "class_ogre_1_1_g_l_render_system.html#aa77bc009dff88a2ab7acf900881a782b", null ],
     [ "setNormaliseNormals", "class_ogre_1_1_g_l_render_system.html#a0a394336cd14834d98baaad844fb944b", null ],
-    [ "_useLights", "class_ogre_1_1_g_l_render_system.html#a8a2df3e1ae7f03c553ed3988e4fa1418", null ],
-    [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_g_l_render_system.html#ae823599b2860a17253bedb4fcf8282eb", null ],
-    [ "_setWorldMatrix", "class_ogre_1_1_g_l_render_system.html#a65edb67cf43b19c6fb2468b539d01065", null ],
-    [ "_setViewMatrix", "class_ogre_1_1_g_l_render_system.html#ad426fb02df31d8b12f8f2d0f713a5e28", null ],
-    [ "_setProjectionMatrix", "class_ogre_1_1_g_l_render_system.html#a463edc7f303f05401baadb8e4a4fb502", null ],
-    [ "_setSurfaceParams", "class_ogre_1_1_g_l_render_system.html#abb1907dda34e378deba4cffdb0d0a269", null ],
-    [ "_setPointParameters", "class_ogre_1_1_g_l_render_system.html#aa5876c5905c9bf391ba5a6cb048091f7", null ],
+    [ "_useLights", "class_ogre_1_1_g_l_render_system.html#a7d18dbb7023b9dc4628e786e560ab48d", null ],
+    [ "setWorldMatrix", "class_ogre_1_1_g_l_render_system.html#af39996a322d39eb76012cbae889c7e55", null ],
+    [ "setViewMatrix", "class_ogre_1_1_g_l_render_system.html#aae04d55e2a070ccb41238bd487ec94af", null ],
+    [ "setProjectionMatrix", "class_ogre_1_1_g_l_render_system.html#a4a10e74f96f2a3d9b8d34565335e02cf", null ],
+    [ "_setSurfaceTracking", "class_ogre_1_1_g_l_render_system.html#a81f7450dd4535aa378a9e16ea27ed1eb", null ],
+    [ "_setPointParameters", "class_ogre_1_1_g_l_render_system.html#a63c3dd37f81d3a268aa81e0da7bb15ba", null ],
     [ "_setLineWidth", "class_ogre_1_1_g_l_render_system.html#a45218b92432521f0ba4822f683c0f46d", null ],
     [ "_setPointSpritesEnabled", "class_ogre_1_1_g_l_render_system.html#a1e6d7387880c747e089d9eb45c2afeb7", null ],
     [ "_setTexture", "class_ogre_1_1_g_l_render_system.html#af386371d383841ee4202352a5d2ca1c6", null ],
@@ -34,8 +33,6 @@ var class_ogre_1_1_g_l_render_system =
     [ "_setTextureCoordCalculation", "class_ogre_1_1_g_l_render_system.html#aac03f63c77f0728121db8bd8b3d36ccd", null ],
     [ "_setTextureBlendMode", "class_ogre_1_1_g_l_render_system.html#a533c3fcd317b3f8c4c9b872ec81e85c5", null ],
     [ "_setTextureAddressingMode", "class_ogre_1_1_g_l_render_system.html#a01a95aea1f8ae541834918f2993d0e5a", null ],
-    [ "_setTextureBorderColour", "class_ogre_1_1_g_l_render_system.html#acf58133dea0e52a8e87fe298fc6bf288", null ],
-    [ "_setTextureMipmapBias", "class_ogre_1_1_g_l_render_system.html#a1d53c10bd82bc8de155f6882fdd0c79b", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_g_l_render_system.html#a9dc0ac6493242e225ed03ba0049a9ae3", null ],
     [ "_setSeparateSceneBlending", "class_ogre_1_1_g_l_render_system.html#a6f3c83cc74f963cdf80223abd4b0bbd6", null ],
     [ "_setAlphaRejectSettings", "class_ogre_1_1_g_l_render_system.html#a0b00a68cbcfe3204d0827f0545097aee", null ],
@@ -49,16 +46,13 @@ var class_ogre_1_1_g_l_render_system =
     [ "_setDepthBufferFunction", "class_ogre_1_1_g_l_render_system.html#a555ced43b4ad8f029398f3bd94f1a128", null ],
     [ "_setDepthBias", "class_ogre_1_1_g_l_render_system.html#aa40f16fe1001f0aa26dfea32070e8056", null ],
     [ "_setColourBufferWriteEnabled", "class_ogre_1_1_g_l_render_system.html#a19e8bde3e1fcd98d6ad204e21de62ff6", null ],
-    [ "_setFog", "class_ogre_1_1_g_l_render_system.html#af6ef8cf2361aa57a0956599e4b72011c", null ],
+    [ "_setFog", "class_ogre_1_1_g_l_render_system.html#ac93692547dd4615fb4d0aec503aa9c41", null ],
     [ "setClipPlane", "class_ogre_1_1_g_l_render_system.html#aac5fcc0d42f327976f779f11e53a4d23", null ],
     [ "enableClipPlane", "class_ogre_1_1_g_l_render_system.html#a7071890524a4893e80ece1a814ec8480", null ],
     [ "_setPolygonMode", "class_ogre_1_1_g_l_render_system.html#a23edcc88ccb0bcbcb680a0fcc3cf1494", null ],
     [ "setStencilCheckEnabled", "class_ogre_1_1_g_l_render_system.html#a61dd158a8d5d1f98a9844f962ac7d699", null ],
     [ "setStencilBufferParams", "class_ogre_1_1_g_l_render_system.html#a8b4d1679b9ac4a474d5ae189941ef1bb", null ],
     [ "_setTextureUnitFiltering", "class_ogre_1_1_g_l_render_system.html#abfa29b60a904af42706370b91905e1cc", null ],
-    [ "_setTextureUnitCompareFunction", "class_ogre_1_1_g_l_render_system.html#addb5d433f246b523a63227666914c470", null ],
-    [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_g_l_render_system.html#ad885d715dc1b86037b08ae77e22f19a7", null ],
-    [ "_setTextureLayerAnisotropy", "class_ogre_1_1_g_l_render_system.html#a7451f77bcd9029684e6d52df61e1f8cc", null ],
     [ "_render", "class_ogre_1_1_g_l_render_system.html#ae864439ace42c4bf2ab645f8e2e86558", null ],
     [ "bindGpuProgram", "class_ogre_1_1_g_l_render_system.html#aac0ea19643a55921a6fd968bb698d7fb", null ],
     [ "unbindGpuProgram", "class_ogre_1_1_g_l_render_system.html#aac18158225e9fdd39e0853210e2bca57", null ],
@@ -78,7 +72,6 @@ var class_ogre_1_1_g_l_render_system =
     [ "_unregisterContext", "class_ogre_1_1_g_l_render_system.html#a0a04e023983b11eb8e96441644aa1fbf", null ],
     [ "_getStateCacheManager", "class_ogre_1_1_g_l_render_system.html#ac6a996af7192df7aa405f1139c7cf5e3", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_g_l_render_system.html#a16247fa7de924dda8458ec73e261e200", null ],
-    [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_g_l_render_system.html#afda4f926afca3de3e3fada45ef726476", null ],
     [ "beginProfileEvent", "class_ogre_1_1_g_l_render_system.html#ae6118f5e48be4e322d58b88e583f9d3a", null ],
     [ "endProfileEvent", "class_ogre_1_1_g_l_render_system.html#abb787cabbd49e5a13cb870660cc69415", null ],
     [ "markProfileEvent", "class_ogre_1_1_g_l_render_system.html#af0fcfc1d49ce50f44adf6b9f2f709d8d", null ],
@@ -96,23 +89,22 @@ var class_ogre_1_1_g_l_render_system =
     [ "getColourVertexElementType", "class_ogre_1_1_g_l_render_system.html#a98654d465668da5979ba19970f340c6c", null ],
     [ "reinitialise", "class_ogre_1_1_g_l_render_system.html#ae7f49f141ecbec19ae167a1f41410831", null ],
     [ "_convertProjectionMatrix", "class_ogre_1_1_g_l_render_system.html#a659737b922eab484406ba4185bbdba11", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_g_l_render_system.html#a83b79138c5a836ff9e9b64b9034411ba", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_g_l_render_system.html#aa0bed8165409135364a650970823076e", null ],
-    [ "_makeOrthoMatrix", "class_ogre_1_1_g_l_render_system.html#a29f04ca5283c108f347abea792acda4c", null ],
-    [ "_applyObliqueDepthProjection", "class_ogre_1_1_g_l_render_system.html#a5396bb98e10b98f63d919125393e6cf8", null ],
+    [ "_getDepthStencilFormatFor", "class_ogre_1_1_g_l_render_system.html#adea4ea5c6eeab804929dde6e1f8e6f9c", null ],
     [ "_createVao", "class_ogre_1_1_g_l_render_system.html#adcab922f596a9d320f4d7364170630d6", null ],
     [ "_bindVao", "class_ogre_1_1_g_l_render_system.html#aaff5306b91066a812a20f579b2e45d30", null ],
     [ "_destroyVao", "class_ogre_1_1_g_l_render_system.html#ab63c7bbf924aa7d8494c0a2439ce1590", null ],
     [ "_destroyFbo", "class_ogre_1_1_g_l_render_system.html#ad4d90e3e01ce12f90247e494c21fe8b9", null ],
     [ "_completeDeferredVaoFboDestruction", "class_ogre_1_1_g_l_render_system.html#a4e1583bcb013072db22095835eda8d64", null ],
-    [ "getConfigOptions", "class_ogre_1_1_g_l_render_system.html#a4415ece805ed62ee16c8343c96766231", null ],
+    [ "getConfigOptions", "class_ogre_1_1_g_l_render_system.html#aca550d0c75935c7f11b1b8ef6ae0a69b", null ],
+    [ "getRenderWindowDescription", "class_ogre_1_1_g_l_render_system.html#aa6e8e2994c6b93d4a075e93223d2def1", null ],
     [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_g_l_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
     [ "isStaticBufferLockable", "class_ogre_1_1_g_l_render_system.html#a319564dc746b19bb9a1490a473227b20", null ],
     [ "getMutableCapabilities", "class_ogre_1_1_g_l_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
     [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_g_l_render_system.html#afc69e09f59064b79f3bfd4402617d07a", null ],
-    [ "setAmbientLight", "class_ogre_1_1_g_l_render_system.html#af2364f8648585cd4fb7bb16761b35b2d", null ],
-    [ "setWBufferEnabled", "class_ogre_1_1_g_l_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
-    [ "getWBufferEnabled", "class_ogre_1_1_g_l_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
+    [ "_setProjectionMatrix", "class_ogre_1_1_g_l_render_system.html#a12183f0e2538e4c65e0ec775eeafde68", null ],
+    [ "_setViewMatrix", "class_ogre_1_1_g_l_render_system.html#acf464521f1b593f9c1bc89467e195691", null ],
+    [ "_setWorldMatrix", "class_ogre_1_1_g_l_render_system.html#a3b31342c80388e10155c5e6e4d91fc2d", null ],
+    [ "_setSceneBlending", "class_ogre_1_1_g_l_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "destroyRenderTexture", "class_ogre_1_1_g_l_render_system.html#a354ceaa02574d1cf68dcb5999b34df50", null ],
     [ "destroyRenderTarget", "class_ogre_1_1_g_l_render_system.html#a43a03671d1c7efd7e95100d77080eb8c", null ],
     [ "attachRenderTarget", "class_ogre_1_1_g_l_render_system.html#ac7ce258ff899b1694a18e1d51e1a3ba0", null ],
@@ -127,13 +119,11 @@ var class_ogre_1_1_g_l_render_system =
     [ "setGlobalNumberOfInstances", "class_ogre_1_1_g_l_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
     [ "setDepthBufferFor", "class_ogre_1_1_g_l_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
     [ "_setTextureUnitSettings", "class_ogre_1_1_g_l_render_system.html#ad504623eff0678f9f79b075f32673414", null ],
-    [ "_setBindingType", "class_ogre_1_1_g_l_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
     [ "_disableTextureUnit", "class_ogre_1_1_g_l_render_system.html#a058d6805142fce7ec095a018447cbe33", null ],
     [ "_disableTextureUnitsFrom", "class_ogre_1_1_g_l_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
     [ "_setVertexTexture", "class_ogre_1_1_g_l_render_system.html#af40bfb084b051d8433b0893921613ba7", null ],
     [ "_setTextureUnitFiltering", "class_ogre_1_1_g_l_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
     [ "setColourBlendState", "class_ogre_1_1_g_l_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
-    [ "_setSceneBlending", "class_ogre_1_1_g_l_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_g_l_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
     [ "_cleanupDepthBuffers", "class_ogre_1_1_g_l_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
     [ "_pauseFrame", "class_ogre_1_1_g_l_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
@@ -152,8 +142,6 @@ var class_ogre_1_1_g_l_render_system =
     [ "isGpuProgramBound", "class_ogre_1_1_g_l_render_system.html#a6077b61e7511ae56887c67498f5282a1", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_g_l_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
     [ "setClipPlanes", "class_ogre_1_1_g_l_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
-    [ "addClipPlane", "class_ogre_1_1_g_l_render_system.html#abe36b06513ccdd9daca4c6443144bcfc", null ],
-    [ "resetClipPlanes", "class_ogre_1_1_g_l_render_system.html#a844d233fa4ba66a95e56c086f76287f9", null ],
     [ "_initRenderTargets", "class_ogre_1_1_g_l_render_system.html#aacdaca375b0736ea8b9fe660f17405ab", null ],
     [ "_notifyCameraRemoved", "class_ogre_1_1_g_l_render_system.html#aad4ebe6f669319f83fc44cf9d5a8f9cc", null ],
     [ "_updateAllRenderTargets", "class_ogre_1_1_g_l_render_system.html#a8ef6bbe5a63769cfe73319ac418624a8", null ],
