@@ -12,6 +12,7 @@ var class_ogre_1_1_manual_object =
     [ "estimateVertexCount", "class_ogre_1_1_manual_object.html#a9448c472c45235366231ec1a6e4e5b73", null ],
     [ "estimateIndexCount", "class_ogre_1_1_manual_object.html#a59153e5ecd0f694c9ef143ad57ae082f", null ],
     [ "begin", "class_ogre_1_1_manual_object.html#a70d5945478fbc7fa056cecd88fdf2781", null ],
+    [ "begin", "class_ogre_1_1_manual_object.html#a3cbfd2ed4cf060822bd006f70bf71a4b", null ],
     [ "setDynamic", "class_ogre_1_1_manual_object.html#a83143f157514a3bb44e325df19fdefde", null ],
     [ "getDynamic", "class_ogre_1_1_manual_object.html#aaefce8deb9790ede37de3fd00834b3e4", null ],
     [ "beginUpdate", "class_ogre_1_1_manual_object.html#a0c4103359ee463b1a000623d9516291c", null ],
@@ -37,6 +38,7 @@ var class_ogre_1_1_manual_object =
     [ "getCurrentIndexCount", "class_ogre_1_1_manual_object.html#aa28d24f2c5aec5ea284dd5c4d264d458", null ],
     [ "end", "class_ogre_1_1_manual_object.html#a49d6bfe460ff1e0178c6d77b95d3dc5a", null ],
     [ "setMaterialName", "class_ogre_1_1_manual_object.html#ad67a3cc60f094ea252621023f084887b", null ],
+    [ "setMaterial", "class_ogre_1_1_manual_object.html#a3918863276220985b22c2e91d6530b9f", null ],
     [ "convertToMesh", "class_ogre_1_1_manual_object.html#a657275e617d9558951a3037f02b07efe", null ],
     [ "setUseIdentityProjection", "class_ogre_1_1_manual_object.html#a7f832d5605c489db7be396ec7cd20b85", null ],
     [ "getUseIdentityProjection", "class_ogre_1_1_manual_object.html#aad31d200073c1ea8c816ee4eb815fb74", null ],
