@@ -157,12 +157,14 @@ var class_ogre_1_1_r_t_shader_1_1_const_parameter =
     [ "isConstParameter", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#aeacadad2424b2f76c78a6c7b86c31ead", null ],
     [ "toString", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a2014742ec73086399899da2775d01cfc", null ],
     [ "getName", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a3cfb1556a4f7606ce7f10e5b9fe67add", null ],
-    [ "_rename", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#aae564cdbc8eb80bcb57d6afca63eed43", null ],
+    [ "_rename", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a731d5bfce5b8813f0588775ecae64259", null ],
     [ "getType", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a83a641fd3be8b42222c1a5988c5c74fd", null ],
     [ "getSemantic", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a572567ffac22974529947d127e66fab8", null ],
     [ "getIndex", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a66737b9982cbf8778c4114082d8ab496", null ],
     [ "getContent", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#ab8ed4fa20a94d4dc3b964ee20d56769f", null ],
     [ "isArray", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a35b50410cc2fef7dbf39066b1b44e4ae", null ],
     [ "getSize", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#aefb06f44383244d59e3832f691d9f7b6", null ],
-    [ "setSize", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a1f7b2b048c450c18bcf23a44732e565e", null ]
+    [ "setSize", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a1f7b2b048c450c18bcf23a44732e565e", null ],
+    [ "setUsed", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a32f1e28c1a590fd9e50d6f9a14c0d34c", null ],
+    [ "isUsed", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a6b181e0bfdc6ac8d1ac8b5ea857caffa", null ]
 ];
\ No newline at end of file
