@@ -6,7 +6,7 @@ var class_ogre_1_1_r_t_shader_1_1_normal_map_lighting =
     ] ],
     [ "NormalMapLighting", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a69b33cabe7c99bc8750d40ae11399fb4", null ],
     [ "getType", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a7f9625974c6ecdf24c1688beafb052a9", null ],
-    [ "updateGpuProgramsParams", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a12b0e1c74da86e9e2ba63bd409240178", null ],
+    [ "updateGpuProgramsParams", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#ac1ae6e2ad7ccdfb4f4ae68fa60cce4a1", null ],
     [ "copyFrom", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a77e4353cfba7bda94f1e92e8834c5811", null ],
     [ "preAddToRenderState", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a843b43b2c134bfb623da7392a5cba3e9", null ],
     [ "setTexCoordIndex", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a928fa5c82069c3b767a627290e430c40", null ],
@@ -16,11 +16,8 @@ var class_ogre_1_1_r_t_shader_1_1_normal_map_lighting =
     [ "setNormalMapTextureName", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#afaf2b3125bbf17d4cb07396d178633cb", null ],
     [ "getNormalMapTextureName", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#ab243908260544b3e3a5fba2bbcdf2a97", null ],
     [ "setNormalMapFiltering", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a0763857506b0a277864bb343b54b8351", null ],
-    [ "getNormalMapFiltering", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a3cf4aff9cee0f55fe44a5a391f763539", null ],
     [ "setNormalMapAnisotropy", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#ad013d132ac6a7824b30d6b1b639ad672", null ],
-    [ "getNormalMapAnisotropy", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a0093439720c1351e0dbaa09bd8fcf003", null ],
     [ "setNormalMapMipBias", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#aaa91938b0f28e03d3b4ec421e98a5d64", null ],
-    [ "getNormalMapMipBias", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#aa2fa840ac668b8f934bebbc80a19091a", null ],
     [ "getNormalMapSampler", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a21d435104786893354bbcb86e743eb8b", null ],
     [ "setNormalMapSampler", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a548cc98b5a0dd2b4aea99fb847aa24ad", null ],
     [ "getExecutionOrder", "class_ogre_1_1_r_t_shader_1_1_normal_map_lighting.html#a11bddfecc7052cf235f1a0321600b7c5", null ],
