@@ -1,9 +1,9 @@
 var class_ogre_1_1_r_t_shader_1_1_program =
 [
+    [ "~Program", "class_ogre_1_1_r_t_shader_1_1_program.html#a1738228b71726715dea9c34bed1933df", null ],
     [ "getType", "class_ogre_1_1_r_t_shader_1_1_program.html#a8681d83df819eb590cf0cf110c78307f", null ],
     [ "resolveAutoParameterReal", "class_ogre_1_1_r_t_shader_1_1_program.html#ae0b281147a7daf59ec04e45523df75d0", null ],
     [ "resolveAutoParameterReal", "class_ogre_1_1_r_t_shader_1_1_program.html#afa95a589bbc662fdadf93c9fa3630508", null ],
-    [ "resolveAutoParameterInt", "class_ogre_1_1_r_t_shader_1_1_program.html#a14f456c00a198c026043492b74f5c695", null ],
     [ "resolveAutoParameterInt", "class_ogre_1_1_r_t_shader_1_1_program.html#af9ae3761783a43cdb7016b51c5a858bd", null ],
     [ "resolveParameter", "class_ogre_1_1_r_t_shader_1_1_program.html#a5587bc7123d7616527a4508706d7cc89", null ],
     [ "resolveParameter", "class_ogre_1_1_r_t_shader_1_1_program.html#a17a8d4a771e8ff07180beab4986da67d", null ],
@@ -25,5 +25,5 @@ var class_ogre_1_1_r_t_shader_1_1_program =
     [ "getUseColumnMajorMatrices", "class_ogre_1_1_r_t_shader_1_1_program.html#af543d4c8b9ec5dae89542310277f7435", null ],
     [ "addPreprocessorDefines", "class_ogre_1_1_r_t_shader_1_1_program.html#aed7fafc1019b4e9ea6d3e9db70339f0e", null ],
     [ "getPreprocessorDefines", "class_ogre_1_1_r_t_shader_1_1_program.html#a855d22b1c3cb9b2b28779b9cf9e59906", null ],
-    [ "ProgramManager", "class_ogre_1_1_r_t_shader_1_1_program.html#ae46e120edae3a1f22dc68ebde7fbcfca", null ]
+    [ "TargetRenderState", "class_ogre_1_1_r_t_shader_1_1_program.html#af6e59fb08a915c63d07d3e1a1a4f1092", null ]
 ];
\ No newline at end of file
