@@ -60,11 +60,11 @@ var group___cg_program_manager =
       [ "resetCompileError", "class_ogre_1_1_cg_program.html#a7ce0be99072f2ffd6055cd3bbd20b625", null ],
       [ "getSize", "class_ogre_1_1_cg_program.html#a65a86c6f911a8ac4b0c6d7366fb44f26", null ],
       [ "touch", "class_ogre_1_1_cg_program.html#aa448e3603f9f6cad8cfe40818888227a", null ],
-      [ "resolveCgIncludes", "class_ogre_1_1_cg_program.html#a0503809d1be7c3e0290262827e2d3773", null ],
       [ "getConstantDefinitions", "class_ogre_1_1_cg_program.html#ac281d547b47b872fe35e1e60fe07612a", null ],
       [ "calculateSize", "class_ogre_1_1_cg_program.html#a62ecd906ba236975ddec42c62d0b4e2b", null ],
       [ "setPreprocessorDefines", "class_ogre_1_1_cg_program.html#abf8f87f03e2d3b147b7f28c76c1307a7", null ],
       [ "getPreprocessorDefines", "class_ogre_1_1_cg_program.html#ad37956c9bababb03b8ce7aaf13d0f39b", null ],
+      [ "_resolveIncludes", "class_ogre_1_1_cg_program.html#a827096909b3c5ef1ff46b880e1606b76", null ],
       [ "getProgramTypeName", "class_ogre_1_1_cg_program.html#a74fe58cd0a7dcfcc55902fc3d9890b82", null ],
       [ "setSourceFile", "class_ogre_1_1_cg_program.html#a8d265ebc2472f77cf9675dec005a123a", null ],
       [ "setSource", "class_ogre_1_1_cg_program.html#af0194bcb85a757f23cd8681c4611a4fb", null ],
