@@ -20,15 +20,14 @@ var manual =
     ] ],
     [ "Scripts", "_scripts.html", "_scripts" ],
     [ "High-level Programs", "_high-level-_programs.html", [
+      [ "Preprocessor definitions", "_high-level-_programs.html#Preprocessor-definitions", null ],
       [ "Cg programs", "_high-level-_programs.html#Cg", null ],
       [ "DirectX9 HLSL", "_high-level-_programs.html#HLSL", null ],
       [ "OpenGL GLSL", "_high-level-_programs.html#GLSL", [
         [ "GLSL Texture Samplers", "_high-level-_programs.html#GLSL-Texture-Samplers", null ],
         [ "Matrix parameters", "_high-level-_programs.html#Matrix-parameters", null ],
-        [ "Accessing OpenGL states in GLSL", "_high-level-_programs.html#Accessing-OpenGL-states-in-GLSL", null ],
         [ "Binding vertex attributes", "_high-level-_programs.html#Binding-vertex-attributes", null ],
-        [ "Preprocessor definitions", "_high-level-_programs.html#Preprocessor-definitions", null ],
-        [ "GLSL Geometry shader specification", "_high-level-_programs.html#GLSL-Geometry-shader-specification", null ]
+        [ "Compatibility profile GLSL features", "_high-level-_programs.html#Legacy-GLSL-features", null ]
       ] ],
       [ "Unified High-level Programs", "_high-level-_programs.html#Unified-High_002dlevel-Programs", null ],
       [ "Using GPU Programs in a Pass", "_high-level-_programs.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass", [
