@@ -1,5 +1,28 @@
 var NAVTREEINDEX105 =
 {
+"class_ogre_1_1_ray_scene_query.html#aef129845061d1bdfb9cb92a75c531a63":[5,0,9,36,10],
+"class_ogre_1_1_ray_scene_query_listener.html":[5,0,9,37],
+"class_ogre_1_1_ray_scene_query_listener.html#a055ea5aff0165926892ad74289d2f73c":[5,0,9,37,0],
+"class_ogre_1_1_ray_scene_query_listener.html#a7c390bfdec4a3e7eaf0491d8cc7b6d3c":[5,0,9,37,2],
+"class_ogre_1_1_ray_scene_query_listener.html#ac3c09aba6b71ca28d721be30ed8f06ed":[5,0,9,37,1],
+"class_ogre_1_1_rectangle2_d.html":[5,0,9,39],
+"class_ogre_1_1_rectangle2_d.html#a015c3801632c98bca5dbb5aa3da1aa24":[5,0,9,39,84],
+"class_ogre_1_1_rectangle2_d.html#a01f48775e48b672d7796311f3ffe2930":[5,0,9,39,65],
+"class_ogre_1_1_rectangle2_d.html#a06f161ae0451be7eaa67e77c296d5631":[5,0,9,39,24],
+"class_ogre_1_1_rectangle2_d.html#a07264525cc9ddfed69ef46b87e33d16a":[5,0,9,39,43],
+"class_ogre_1_1_rectangle2_d.html#a0a0fe2643c8d7d52a18a8f013192064b":[5,0,9,39,37],
+"class_ogre_1_1_rectangle2_d.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,0,9,39,104],
+"class_ogre_1_1_rectangle2_d.html#a143cf58a9934cddb277bb3d1540b9c1b":[5,0,9,39,3],
+"class_ogre_1_1_rectangle2_d.html#a164483d42186628f7e14833b2df7a7a7":[5,0,9,39,47],
+"class_ogre_1_1_rectangle2_d.html#a19bf2951b97744064509c13068143f3d":[5,0,9,39,69],
+"class_ogre_1_1_rectangle2_d.html#a1ad93e3514b969971213ff4ae80103dc":[5,0,9,39,48],
+"class_ogre_1_1_rectangle2_d.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,0,9,39,66],
+"class_ogre_1_1_rectangle2_d.html#a29048e3cee8fa41f3129f79dc5f61988":[5,0,9,39,18],
+"class_ogre_1_1_rectangle2_d.html#a2b5b86e082a44769ae96ec2e48930b90":[5,0,9,39,25],
+"class_ogre_1_1_rectangle2_d.html#a2cc6be9f51e010a4977afdc5a7dff5cb":[5,0,9,39,92],
+"class_ogre_1_1_rectangle2_d.html#a2d718f6ed0b708495cc2a31eb653ad84":[5,0,9,39,87],
+"class_ogre_1_1_rectangle2_d.html#a2eb94fea5944cf0d33702a75cfa14a74":[5,0,9,39,71],
+"class_ogre_1_1_rectangle2_d.html#a2ed9a2f3c1decac6286f8af974ce2ffc":[5,0,9,39,54],
 "class_ogre_1_1_rectangle2_d.html#a2f770d6ba9b3d97bdc63ecf0e3888aab":[5,0,9,39,108],
 "class_ogre_1_1_rectangle2_d.html#a34f68e974e1b32656f192cee1ba848a4":[5,0,9,39,6],
 "class_ogre_1_1_rectangle2_d.html#a38cf564fe839d40a81ba5155d363b7aa":[5,0,9,39,57],
@@ -117,9 +140,9 @@ var NAVTREEINDEX105 =
 "class_ogre_1_1_region_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,0,9,40,8],
 "class_ogre_1_1_region_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,9,40,13],
 "class_ogre_1_1_region_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,9,40,10],
-"class_ogre_1_1_render_object_listener.html":[7,0,0,634],
-"class_ogre_1_1_render_object_listener.html#a5fc7de0f8ead61860e1125c539afd52b":[7,0,0,634,0],
-"class_ogre_1_1_render_object_listener.html#a99b1b17e89efbbce74756925a4acad38":[7,0,0,634,1],
+"class_ogre_1_1_render_object_listener.html":[7,0,0,635],
+"class_ogre_1_1_render_object_listener.html#a5fc7de0f8ead61860e1125c539afd52b":[7,0,0,635,0],
+"class_ogre_1_1_render_object_listener.html#a99b1b17e89efbbce74756925a4acad38":[7,0,0,635,1],
 "class_ogre_1_1_render_operation.html":[5,0,7,24],
 "class_ogre_1_1_render_operation.html#a21998ad8a9cb134420158dc8e2663eac":[5,0,7,24,1],
 "class_ogre_1_1_render_operation.html#a306c2ed3599abab29a027325e3d6d721":[5,0,7,24,2],
@@ -226,28 +249,5 @@ var NAVTREEINDEX105 =
 "class_ogre_1_1_render_queue_group.html#a180a462bafa9b9d472a59d044657e6ef":[5,0,7,27,9],
 "class_ogre_1_1_render_queue_group.html#a195e1d749ca78952f9e4c222d6a536c3":[5,0,7,27,15],
 "class_ogre_1_1_render_queue_group.html#a33650a9641d40269f18d44be60006d31":[5,0,7,27,0],
-"class_ogre_1_1_render_queue_group.html#a34dffe13210b7f61932a25fc042f404f":[5,0,7,27,2],
-"class_ogre_1_1_render_queue_group.html#a38216d5a4828871b53e5fbecdc8d4984":[5,0,7,27,1],
-"class_ogre_1_1_render_queue_group.html#a4eb48a76b7a69ed248578d6743f8e9b3":[5,0,7,27,17],
-"class_ogre_1_1_render_queue_group.html#a4fcd2c524232e0708786959bf74fe153":[5,0,7,27,14],
-"class_ogre_1_1_render_queue_group.html#a57dab1728addd478b2f1af27dc0e5db7":[5,0,7,27,6],
-"class_ogre_1_1_render_queue_group.html#a5c2e2f614fe51fb1e6954b28f4c3a366":[5,0,7,27,13],
-"class_ogre_1_1_render_queue_group.html#a9225e3493596e1701e583721d1846f24":[5,0,7,27,5],
-"class_ogre_1_1_render_queue_group.html#a9d53fac5486bb4379965858840900263":[5,0,7,27,12],
-"class_ogre_1_1_render_queue_group.html#aa8f83bb601e8344a255fc2aafbc958ee":[5,0,7,27,3],
-"class_ogre_1_1_render_queue_group.html#aa9136681bf8704ada4af84f2c30be7b3":[5,0,7,27,11],
-"class_ogre_1_1_render_queue_group.html#abf7136f736afc5af757616665410e952":[5,0,7,27,10],
-"class_ogre_1_1_render_queue_group.html#ac12bd8451907d485889812b0a6b6ceca":[5,0,7,27,4],
-"class_ogre_1_1_render_queue_group.html#aeeaaf69657b5425e8f294466f0061a41":[5,0,7,27,8],
-"class_ogre_1_1_render_queue_invocation.html":[5,0,7,28],
-"class_ogre_1_1_render_queue_invocation.html#a04e04fd603d74dc0d0d8389601991f7b":[5,0,7,28,2],
-"class_ogre_1_1_render_queue_invocation.html#a172bce72efdb82be1e20e0f0b228d151":[5,0,7,28,10],
-"class_ogre_1_1_render_queue_invocation.html#a22e4baf98518befdcd09e606f7edcc5a":[5,0,7,28,1],
-"class_ogre_1_1_render_queue_invocation.html#a27d41c4a90547ca4a976ac88c53fa3e6":[5,0,7,28,11],
-"class_ogre_1_1_render_queue_invocation.html#a302c6cd489bb9ff8cfe1027a26442fd6":[5,0,7,28,3],
-"class_ogre_1_1_render_queue_invocation.html#a31e8b643617ba8572ce2ec772060d164":[5,0,7,28,9],
-"class_ogre_1_1_render_queue_invocation.html#a3e176fcc247d84f0908e264d11c2d043":[5,0,7,28,7],
-"class_ogre_1_1_render_queue_invocation.html#a4d3821747ee0588c65bfc48982c7e37b":[5,0,7,28,8],
-"class_ogre_1_1_render_queue_invocation.html#a6a37071d01a609e279081a906a856dc1":[5,0,7,28,4],
-"class_ogre_1_1_render_queue_invocation.html#a835151b1f6cdf542b80cb2fe11e54c74":[5,0,7,28,5]
+"class_ogre_1_1_render_queue_group.html#a34dffe13210b7f61932a25fc042f404f":[5,0,7,27,2]
 };
