@@ -1,5 +1,28 @@
 var NAVTREEINDEX109 =
 {
+"class_ogre_1_1_resource_group_manager.html#acd4fe53cc4f0ab2800d7675fc4cba9b2":[5,0,8,27,66],
+"class_ogre_1_1_resource_group_manager.html#ad843c3889b80ebd8e01aed9cf81b3769":[5,0,8,27,6],
+"class_ogre_1_1_resource_group_manager.html#aded812a215c5be14bca70132f2eedaec":[5,0,8,27,33],
+"class_ogre_1_1_resource_group_manager.html#ae26eacec6d13149f46c47d88c7110625":[5,0,8,27,2],
+"class_ogre_1_1_resource_group_manager.html#ae7d6c2af0066f761a7c7e9ab17fe6bae":[5,0,8,27,27],
+"class_ogre_1_1_resource_group_manager.html#ae8b0855faf84539b7979775c37efd590":[5,0,8,27,31],
+"class_ogre_1_1_resource_group_manager.html#ae91a1f693e5f2954e4b352886ddde669":[5,0,8,27,63],
+"class_ogre_1_1_resource_group_manager.html#aebc185a7ef51b89887e941eed2cde64b":[5,0,8,27,22],
+"class_ogre_1_1_resource_group_manager.html#aee39a0d3e4ce64f698bf62240494f573":[5,0,8,27,65],
+"class_ogre_1_1_resource_group_manager.html#af58d1d8ed72fe78e7b6c9eaae15e360b":[5,0,8,27,34],
+"class_ogre_1_1_resource_group_manager.html#af5c901bfb116d7f70f4542bd828784f4":[5,0,8,27,9],
+"class_ogre_1_1_resource_group_manager.html#af875db11dc5aba6ab72ec40296af9a5c":[5,0,8,27,4],
+"class_ogre_1_1_resource_group_manager.html#af88e3d5af3a2f1234d5f0c57a63ff605":[5,0,8,27,24],
+"class_ogre_1_1_resource_group_manager.html#afd68888cf4b9fa0cb4a0de65fc1ae0ce":[5,0,8,27,56],
+"class_ogre_1_1_resource_group_manager.html#afdbf8437d285d89c7a6daae90228b87f":[5,0,8,27,61],
+"class_ogre_1_1_resource_group_manager.html#afdf17a57c9a47226e42625e8046f6b49":[5,0,8,27,64],
+"class_ogre_1_1_resource_loading_listener.html":[5,0,8,28],
+"class_ogre_1_1_resource_loading_listener.html#a62badbb7992a529cdfa35f23b9401141":[5,0,8,28,3],
+"class_ogre_1_1_resource_loading_listener.html#a7d80ca210ccc9243f737f5f1f3f48f67":[5,0,8,28,1],
+"class_ogre_1_1_resource_loading_listener.html#ab4624f7ad2c8c23ce489f6733c44aaa7":[5,0,8,28,0],
+"class_ogre_1_1_resource_loading_listener.html#af1856e826dd312b6ae86a83b57f28cc6":[5,0,8,28,2],
+"class_ogre_1_1_resource_manager.html":[5,0,8,29],
+"class_ogre_1_1_resource_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[5,0,8,29,43],
 "class_ogre_1_1_resource_manager.html#a0154dd3f0ed6e8665eecab30d2535101":[5,0,8,29,26],
 "class_ogre_1_1_resource_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[5,0,8,29,15],
 "class_ogre_1_1_resource_manager.html#a2514952116c93b5b5eba051492d2caa9":[5,0,8,29,14],
@@ -226,28 +249,5 @@ var NAVTREEINDEX109 =
 "class_ogre_1_1_ring_emitter.html#a0c27fc47afc5857aecf9558ee88bbc0b":[5,2,6,14,7],
 "class_ogre_1_1_ring_emitter.html#a0cdad11e98fe6af5c36ca88b83e439ac":[5,2,6,14,40],
 "class_ogre_1_1_ring_emitter.html#a0ddb2110884003fa74abc6eaab2682cc":[5,2,6,14,22],
-"class_ogre_1_1_ring_emitter.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,2,6,14,79],
-"class_ogre_1_1_ring_emitter.html#a123c22ed81e96c90b5cb096d11e26aae":[5,2,6,14,13],
-"class_ogre_1_1_ring_emitter.html#a12c7b04420ff5aa08741d114053daff8":[5,2,6,14,17],
-"class_ogre_1_1_ring_emitter.html#a13c3ad7a5e076316869eacbc89e95be9":[5,2,6,14,26],
-"class_ogre_1_1_ring_emitter.html#a18544aba1642ac02cd2d50847a3f35b9":[5,2,6,14,77],
-"class_ogre_1_1_ring_emitter.html#a1be2d46c4f3a8bd1d4118d347397e245":[5,2,6,14,57],
-"class_ogre_1_1_ring_emitter.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[5,2,6,14,85],
-"class_ogre_1_1_ring_emitter.html#a1c17e03466492e1983a439eb7e540e25":[5,2,6,14,2],
-"class_ogre_1_1_ring_emitter.html#a1c17e03466492e1983a439eb7e540e25a42e46625a50eb279c03f665fa715d749":[5,2,6,14,2,1],
-"class_ogre_1_1_ring_emitter.html#a1c17e03466492e1983a439eb7e540e25af72cab2ce3d47d8aa4ec32797372bd81":[5,2,6,14,2,0],
-"class_ogre_1_1_ring_emitter.html#a1c642db8ce58df3c61f431ebc9066277":[5,2,6,14,48],
-"class_ogre_1_1_ring_emitter.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[5,2,6,14,83],
-"class_ogre_1_1_ring_emitter.html#a1e9a8af81722473eb516e36a27e885bd":[5,2,6,14,60],
-"class_ogre_1_1_ring_emitter.html#a22a39275e9ef9e14d9d873acda400816":[5,2,6,14,11],
-"class_ogre_1_1_ring_emitter.html#a23a30a598c10f44f59ad4cfd78bf2a10":[5,2,6,14,45],
-"class_ogre_1_1_ring_emitter.html#a248869cbb1598a7518e191a063a4f89a":[5,2,6,14,21],
-"class_ogre_1_1_ring_emitter.html#a2644282dc91a1ad0525bebd46a47f519":[5,2,6,14,69],
-"class_ogre_1_1_ring_emitter.html#a27abb24bce18934c89568cb3e10dd08f":[5,2,6,14,67],
-"class_ogre_1_1_ring_emitter.html#a2ed1a99178ad112142f9ff9ac95c553e":[5,2,6,14,59],
-"class_ogre_1_1_ring_emitter.html#a2fc108cba4892f8ae091ffd70a65a150":[5,2,6,14,70],
-"class_ogre_1_1_ring_emitter.html#a3219c4a6ba77ef006ca2c89e143b568a":[5,2,6,14,3],
-"class_ogre_1_1_ring_emitter.html#a3287cdd56f081a2e7e8a43ad802530bb":[5,2,6,14,74],
-"class_ogre_1_1_ring_emitter.html#a32fb0fa2c3adb521e1f3728990472da3":[5,2,6,14,99],
-"class_ogre_1_1_ring_emitter.html#a334b3e2619d23844739a29bcad603e00":[5,2,6,14,27]
+"class_ogre_1_1_ring_emitter.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,2,6,14,79]
 };
