@@ -1,5 +1,28 @@
 var NAVTREEINDEX110 =
 {
+"class_ogre_1_1_ring_emitter.html#a123c22ed81e96c90b5cb096d11e26aae":[5,2,6,14,13],
+"class_ogre_1_1_ring_emitter.html#a12c7b04420ff5aa08741d114053daff8":[5,2,6,14,17],
+"class_ogre_1_1_ring_emitter.html#a13c3ad7a5e076316869eacbc89e95be9":[5,2,6,14,26],
+"class_ogre_1_1_ring_emitter.html#a18544aba1642ac02cd2d50847a3f35b9":[5,2,6,14,77],
+"class_ogre_1_1_ring_emitter.html#a1be2d46c4f3a8bd1d4118d347397e245":[5,2,6,14,57],
+"class_ogre_1_1_ring_emitter.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[5,2,6,14,85],
+"class_ogre_1_1_ring_emitter.html#a1c17e03466492e1983a439eb7e540e25":[5,2,6,14,2],
+"class_ogre_1_1_ring_emitter.html#a1c17e03466492e1983a439eb7e540e25a42e46625a50eb279c03f665fa715d749":[5,2,6,14,2,1],
+"class_ogre_1_1_ring_emitter.html#a1c17e03466492e1983a439eb7e540e25af72cab2ce3d47d8aa4ec32797372bd81":[5,2,6,14,2,0],
+"class_ogre_1_1_ring_emitter.html#a1c642db8ce58df3c61f431ebc9066277":[5,2,6,14,48],
+"class_ogre_1_1_ring_emitter.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[5,2,6,14,83],
+"class_ogre_1_1_ring_emitter.html#a1e9a8af81722473eb516e36a27e885bd":[5,2,6,14,60],
+"class_ogre_1_1_ring_emitter.html#a22a39275e9ef9e14d9d873acda400816":[5,2,6,14,11],
+"class_ogre_1_1_ring_emitter.html#a23a30a598c10f44f59ad4cfd78bf2a10":[5,2,6,14,45],
+"class_ogre_1_1_ring_emitter.html#a248869cbb1598a7518e191a063a4f89a":[5,2,6,14,21],
+"class_ogre_1_1_ring_emitter.html#a2644282dc91a1ad0525bebd46a47f519":[5,2,6,14,69],
+"class_ogre_1_1_ring_emitter.html#a27abb24bce18934c89568cb3e10dd08f":[5,2,6,14,67],
+"class_ogre_1_1_ring_emitter.html#a2ed1a99178ad112142f9ff9ac95c553e":[5,2,6,14,59],
+"class_ogre_1_1_ring_emitter.html#a2fc108cba4892f8ae091ffd70a65a150":[5,2,6,14,70],
+"class_ogre_1_1_ring_emitter.html#a3219c4a6ba77ef006ca2c89e143b568a":[5,2,6,14,3],
+"class_ogre_1_1_ring_emitter.html#a3287cdd56f081a2e7e8a43ad802530bb":[5,2,6,14,74],
+"class_ogre_1_1_ring_emitter.html#a32fb0fa2c3adb521e1f3728990472da3":[5,2,6,14,99],
+"class_ogre_1_1_ring_emitter.html#a334b3e2619d23844739a29bcad603e00":[5,2,6,14,27],
 "class_ogre_1_1_ring_emitter.html#a3d9141e9851a449cccf480e7a30826df":[5,2,6,14,51],
 "class_ogre_1_1_ring_emitter.html#a44700655800282c23c7f3f97debfacf7":[5,2,6,14,95],
 "class_ogre_1_1_ring_emitter.html#a47b1c383608e0aca4859c6ecd11d9ef5":[5,2,6,14,12],
@@ -80,10 +103,10 @@ var NAVTREEINDEX110 =
 "class_ogre_1_1_ring_emitter_1_1_cmd_inner_y.html":[5,2,6,14,1],
 "class_ogre_1_1_ring_emitter_1_1_cmd_inner_y.html#ae13ec40db52827a9ef5c638522ecfa8d":[5,2,6,14,1,1],
 "class_ogre_1_1_ring_emitter_1_1_cmd_inner_y.html#af60c394ee306c8578686151fb68374a1":[5,2,6,14,1,0],
-"class_ogre_1_1_ring_emitter_factory.html":[7,0,0,663],
-"class_ogre_1_1_ring_emitter_factory.html#a8ff6dc4038b3c8dfb646049f64c13d4f":[7,0,0,663,0],
-"class_ogre_1_1_ring_emitter_factory.html#adc0b5ab2657292efbdb4bc6e6e6a2462":[7,0,0,663,2],
-"class_ogre_1_1_ring_emitter_factory.html#add020512c1bc26113414c3af7277afa8":[7,0,0,663,1],
+"class_ogre_1_1_ring_emitter_factory.html":[7,0,0,664],
+"class_ogre_1_1_ring_emitter_factory.html#a8ff6dc4038b3c8dfb646049f64c13d4f":[7,0,0,664,0],
+"class_ogre_1_1_ring_emitter_factory.html#adc0b5ab2657292efbdb4bc6e6e6a2462":[7,0,0,664,2],
+"class_ogre_1_1_ring_emitter_factory.html#add020512c1bc26113414c3af7277afa8":[7,0,0,664,1],
 "class_ogre_1_1_root.html":[5,0,2,70],
 "class_ogre_1_1_root.html#a01d3244dcf290c2db36aea6b0c63616a":[5,0,2,70,61],
 "class_ogre_1_1_root.html#a06b786d8e0847dfe9cc15e1dea308fcd":[5,0,2,70,95],
@@ -218,36 +241,13 @@ var NAVTREEINDEX110 =
 "class_ogre_1_1_rotation_affector_1_1_cmd_rotation_speed_range_start.html":[5,2,6,15,3],
 "class_ogre_1_1_rotation_affector_1_1_cmd_rotation_speed_range_start.html#a0fd6875815da11f3bef9adb71d9bb668":[5,2,6,15,3,1],
 "class_ogre_1_1_rotation_affector_1_1_cmd_rotation_speed_range_start.html#a8613bc4e610c2fbad888dd496e615617":[5,2,6,15,3,0],
-"class_ogre_1_1_rotation_affector_factory.html":[7,0,0,666],
-"class_ogre_1_1_rotation_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,666,0],
+"class_ogre_1_1_rotation_affector_factory.html":[7,0,0,667],
+"class_ogre_1_1_rotation_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,667,0],
 "class_ogre_1_1_rotational_spline.html":[5,0,6,21],
 "class_ogre_1_1_rotational_spline.html#a40537aff8d0e9a31f2041bab0a6207e1":[5,0,6,21,3],
 "class_ogre_1_1_rotational_spline.html#a4fd498ecda341877bed16614f99513f3":[5,0,6,21,7],
 "class_ogre_1_1_rotational_spline.html#a50e4fac029abebe1f318a80da015f544":[5,0,6,21,8],
 "class_ogre_1_1_rotational_spline.html#a5ba4e31b2ec1aec5c6c2878440184709":[5,0,6,21,2],
 "class_ogre_1_1_rotational_spline.html#a8ee6d15c86ed31e61e04360d36f1fbf9":[5,0,6,21,6],
-"class_ogre_1_1_rotational_spline.html#a92446820612daa332226ab9bf18d7f6a":[5,0,6,21,4],
-"class_ogre_1_1_rotational_spline.html#a94645c3887ad1b0872bcea3897fae613":[5,0,6,21,9],
-"class_ogre_1_1_rotational_spline.html#a9eec1f4d7ee25b15d435e8c49c69c92a":[5,0,6,21,10],
-"class_ogre_1_1_rotational_spline.html#ac8596d691089c7be12d2879dc5595cea":[5,0,6,21,0],
-"class_ogre_1_1_rotational_spline.html#ad52da70d8d76c5c6d2203197e14b3520":[5,0,6,21,5],
-"class_ogre_1_1_rotational_spline.html#ae7c15794bdabda0d02fb2ce52b3e1ea9":[5,0,6,21,1],
-"class_ogre_1_1_runtime_assertion_exception.html":[5,0,2,71],
-"class_ogre_1_1_runtime_assertion_exception.html#a44cc73cf416eba0ef75a49d18d919664":[5,0,2,71,3],
-"class_ogre_1_1_runtime_assertion_exception.html#a501b957a641840f1dc06d7b8d4657d19":[5,0,2,71,6],
-"class_ogre_1_1_runtime_assertion_exception.html#a5323fd0394409fc11d86ac60491ea3e8":[5,0,2,71,7],
-"class_ogre_1_1_runtime_assertion_exception.html#a78036952769df04fdf2f051e506aa7bc":[5,0,2,71,5],
-"class_ogre_1_1_runtime_assertion_exception.html#a871fffb1a89b647d78c7581e539363e5":[5,0,2,71,1],
-"class_ogre_1_1_runtime_assertion_exception.html#a9ad9f9be38cc58f50079f8163feb2b0b":[5,0,2,71,4],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29b":[5,0,2,71,0],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba359c10b8abe9abf39f84550a903e4698":[5,0,2,71,0,2],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba55da7c9771a98e7c96c3900028f02703":[5,0,2,71,0,3],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba65ef64423bae408d90e0af0166bac152":[5,0,2,71,0,6],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba69f87eaf2ef88aabef0d5d11666b6705":[5,0,2,71,0,10],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba932168f4c4ae1a90391233de8a21ab1a":[5,0,2,71,0,4],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba946e7d147a09d8db65b6143d1d348c99":[5,0,2,71,0,7],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba9d61f90f76dd3e119d608876ea5f7957":[5,0,2,71,0,1],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba9e2cd2d2436678236e339e6a42887090":[5,0,2,71,0,9],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba9f57f8f4aefb7fae5fcd69fe155e7003":[5,0,2,71,0,5],
-"class_ogre_1_1_runtime_assertion_exception.html#a9bdf9b8a0a83b95818d676848beaa29baaeb75efe079b550f380d62d9a0954e71":[5,0,2,71,0,0]
+"class_ogre_1_1_rotational_spline.html#a92446820612daa332226ab9bf18d7f6a":[5,0,6,21,4]
 };
