@@ -1,5 +1,28 @@
 var NAVTREEINDEX113 =
 {
+"class_ogre_1_1_scene_node.html#a264df23a0763ef9f8879c97bcbba0f47":[5,0,9,46,55],
+"class_ogre_1_1_scene_node.html#a284464b0561a6f2915f04b0245b987f0":[5,0,9,46,125],
+"class_ogre_1_1_scene_node.html#a2e673500fba746b62c188771a78ff8d6":[5,0,9,46,89],
+"class_ogre_1_1_scene_node.html#a2fdf947d54d8b67b5fef19d68da899ae":[5,0,9,46,121],
+"class_ogre_1_1_scene_node.html#a2ff8d20961b48225690e1561bc39f993":[5,0,9,46,12],
+"class_ogre_1_1_scene_node.html#a307fe0438fb098be6748e044f66155b6":[5,0,9,46,58],
+"class_ogre_1_1_scene_node.html#a31de962a55b0455d7bb3851706073e95":[5,0,9,46,95],
+"class_ogre_1_1_scene_node.html#a37c8ec60f7539ac029c9c47b788b2629":[5,0,9,46,76],
+"class_ogre_1_1_scene_node.html#a3969475af6a52109883d7c7d44f35fec":[5,0,9,46,109],
+"class_ogre_1_1_scene_node.html#a398e7142b2fbadea2a63097d37d4112b":[5,0,9,46,104],
+"class_ogre_1_1_scene_node.html#a3afaaf0dfd3c7140342059a94788e341":[5,0,9,46,52],
+"class_ogre_1_1_scene_node.html#a3f64cc674aed856340df7a0507b90423":[5,0,9,46,13],
+"class_ogre_1_1_scene_node.html#a40baf1928d11cd3cd678445f5d3d7e45":[5,0,9,46,60],
+"class_ogre_1_1_scene_node.html#a45bb282556bc68d072b62097f3006221":[5,0,9,46,73],
+"class_ogre_1_1_scene_node.html#a4609e37d3a70cf4318c99e9e1fb8dfd9":[5,0,9,46,119],
+"class_ogre_1_1_scene_node.html#a4b467ba4a0c8b1e113ec8d31c2f1e641":[5,0,9,46,0],
+"class_ogre_1_1_scene_node.html#a4d0832b90b91afe9fd4154e12c8481a1":[5,0,9,46,14],
+"class_ogre_1_1_scene_node.html#a51052c58747a77a6cf7451b700e7eb87":[5,0,9,46,10],
+"class_ogre_1_1_scene_node.html#a515361d8231fc86d9b602ba55f714fa9":[5,0,9,46,105],
+"class_ogre_1_1_scene_node.html#a52652642857138f859291a88598877c9":[5,0,9,46,42],
+"class_ogre_1_1_scene_node.html#a553f4e76d2416bd2c514f82c2f6117b7":[5,0,9,46,110],
+"class_ogre_1_1_scene_node.html#a5541f6607ef566e07991a0642b0f70f9":[5,0,9,46,23],
+"class_ogre_1_1_scene_node.html#a559442664e8b83cb40ca1d2c68c5d01c":[5,0,9,46,37],
 "class_ogre_1_1_scene_node.html#a5595d0f506945c66795322b1878e16aa":[5,0,9,46,83],
 "class_ogre_1_1_scene_node.html#a57219459f45733699562ae3fd2abda24":[5,0,9,46,2],
 "class_ogre_1_1_scene_node.html#a5b9b0b08edc2984d41ad38520354a407":[5,0,9,46,113],
@@ -68,8 +91,8 @@ var NAVTREEINDEX113 =
 "class_ogre_1_1_scene_node.html#ae12f7409930e2c7ae1fb33c39f71d0ea":[5,0,9,46,48],
 "class_ogre_1_1_scene_node.html#ae1991a38daed956ca9edc635e418d6d8":[5,0,9,46,79],
 "class_ogre_1_1_scene_node.html#ae4c8588895d3623bbe0007ea157af1a4":[5,0,9,46,44],
-"class_ogre_1_1_scene_node.html#ae4f67c715bdbf4d0d543939939f110df":[5,0,9,46,118],
 "class_ogre_1_1_scene_node.html#ae4f67c715bdbf4d0d543939939f110df":[5,0,9,46,54],
+"class_ogre_1_1_scene_node.html#ae4f67c715bdbf4d0d543939939f110df":[5,0,9,46,118],
 "class_ogre_1_1_scene_node.html#ae6319b597c3c75a30c521d532466c4d9":[5,0,9,46,69],
 "class_ogre_1_1_scene_node.html#ae6c9109a64d2f1b3f5bbec7ca324aa6c":[5,0,9,46,86],
 "class_ogre_1_1_scene_node.html#ae7b72c066884d0021bd2b2a6693a66c3":[5,0,9,46,39],
@@ -105,21 +128,21 @@ var NAVTREEINDEX113 =
 "class_ogre_1_1_scene_query_listener.html#a70936d2cd7413dd284faef05528ddb92":[5,0,9,48,1],
 "class_ogre_1_1_scene_query_listener.html#ac17a072217f44693bb45ecbcd1623611":[5,0,9,48,2],
 "class_ogre_1_1_scene_query_listener.html#ad0ea5280ec1032a5170999eb7ae3fb2b":[5,0,9,48,0],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html":[7,0,0,683],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,683,4],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0cf2f9d97bc32d32674038b112b405d1":[7,0,0,683,7],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,683,5],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a60e9908806b839380729aae13b9a959a":[7,0,0,683,10],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a67c3bc6755c75d797e0478b3f226eb33":[7,0,0,683,1],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a6ffe63d24cfcaf5c0d6028fe61baa80e":[7,0,0,683,13],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a73d681b5f30d71ace485b8290eacd660":[7,0,0,683,0],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a780ff7dcf129a9fe0c4eaebf9eef88b3":[7,0,0,683,2],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a90deae1eca19d2dc5973b7d115f11c1c":[7,0,0,683,3],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab3a486ff7212d5175828e4fef82ca37c":[7,0,0,683,12],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ac2237491a332c7214c70648df44810ee":[7,0,0,683,8],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,683,11],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ae422502cd853439e1c61851f7029a5d2":[7,0,0,683,6],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ae7a96f04b4c52cbe332501ca87539b40":[7,0,0,683,9],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html":[7,0,0,684],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,684,4],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0cf2f9d97bc32d32674038b112b405d1":[7,0,0,684,7],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,684,5],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a60e9908806b839380729aae13b9a959a":[7,0,0,684,10],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a67c3bc6755c75d797e0478b3f226eb33":[7,0,0,684,1],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a6ffe63d24cfcaf5c0d6028fe61baa80e":[7,0,0,684,13],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a73d681b5f30d71ace485b8290eacd660":[7,0,0,684,0],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a780ff7dcf129a9fe0c4eaebf9eef88b3":[7,0,0,684,2],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a90deae1eca19d2dc5973b7d115f11c1c":[7,0,0,684,3],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab3a486ff7212d5175828e4fef82ca37c":[7,0,0,684,12],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ac2237491a332c7214c70648df44810ee":[7,0,0,684,8],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,684,11],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ae422502cd853439e1c61851f7029a5d2":[7,0,0,684,6],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ae7a96f04b4c52cbe332501ca87539b40":[7,0,0,684,9],
 "class_ogre_1_1_script_compiler.html":[5,0,2,74],
 "class_ogre_1_1_script_compiler.html#a0fb27db0a80a4243e9376702e402f469":[5,0,2,74,26],
 "class_ogre_1_1_script_compiler.html#a21710f3b93e73c61b0f625b819e4b15d":[5,0,2,74,32],
@@ -195,18 +218,18 @@ var NAVTREEINDEX113 =
 "class_ogre_1_1_script_translator_manager.html":[5,0,2,80],
 "class_ogre_1_1_script_translator_manager.html#a663a8643f1af286006bb1438697b2045":[5,0,2,80,1],
 "class_ogre_1_1_script_translator_manager.html#a88a25066a5f4dc5dab555753ee68dd1c":[5,0,2,80,0],
-"class_ogre_1_1_segment.html":[7,0,0,691],
-"class_ogre_1_1_segment.html#a44470ed7ead1affb566b776c1d771746":[7,0,0,691,1],
-"class_ogre_1_1_segment.html#a44850fd02064b0555e1ec782502032b0":[7,0,0,691,10],
-"class_ogre_1_1_segment.html#a4c26a34309f2ef27674caaa76128621d":[7,0,0,691,9],
-"class_ogre_1_1_segment.html#a505c8fb506a5998c49205215512da8a3":[7,0,0,691,0],
-"class_ogre_1_1_segment.html#a54a372be746c3665fa5db9091e9fc8ed":[7,0,0,691,3],
-"class_ogre_1_1_segment.html#a6e305c32bbf2be9f6541e56f6003eda9":[7,0,0,691,8],
-"class_ogre_1_1_segment.html#a8f2fc7eeb151ba60c9d1b770d7dfeed0":[7,0,0,691,6],
-"class_ogre_1_1_segment.html#aab7e3b6b12f17b430129883443f83cc0":[7,0,0,691,4],
-"class_ogre_1_1_segment.html#abc4c3bf90017fe83e602aa568545a65f":[7,0,0,691,7],
-"class_ogre_1_1_segment.html#ad0cb0efd8bac56a53b12bf044f6635a2":[7,0,0,691,2],
-"class_ogre_1_1_segment.html#adfd5cf89317589fbb08d315128a50f4e":[7,0,0,691,5],
+"class_ogre_1_1_segment.html":[7,0,0,692],
+"class_ogre_1_1_segment.html#a44470ed7ead1affb566b776c1d771746":[7,0,0,692,1],
+"class_ogre_1_1_segment.html#a44850fd02064b0555e1ec782502032b0":[7,0,0,692,10],
+"class_ogre_1_1_segment.html#a4c26a34309f2ef27674caaa76128621d":[7,0,0,692,9],
+"class_ogre_1_1_segment.html#a505c8fb506a5998c49205215512da8a3":[7,0,0,692,0],
+"class_ogre_1_1_segment.html#a54a372be746c3665fa5db9091e9fc8ed":[7,0,0,692,3],
+"class_ogre_1_1_segment.html#a6e305c32bbf2be9f6541e56f6003eda9":[7,0,0,692,8],
+"class_ogre_1_1_segment.html#a8f2fc7eeb151ba60c9d1b770d7dfeed0":[7,0,0,692,6],
+"class_ogre_1_1_segment.html#aab7e3b6b12f17b430129883443f83cc0":[7,0,0,692,4],
+"class_ogre_1_1_segment.html#abc4c3bf90017fe83e602aa568545a65f":[7,0,0,692,7],
+"class_ogre_1_1_segment.html#ad0cb0efd8bac56a53b12bf044f6635a2":[7,0,0,692,2],
+"class_ogre_1_1_segment.html#adfd5cf89317589fbb08d315128a50f4e":[7,0,0,692,5],
 "class_ogre_1_1_serializer.html":[5,0,2,81],
 "class_ogre_1_1_serializer.html#a3268ab522d56e98d88b604255b0f43d4":[5,0,2,81,1],
 "class_ogre_1_1_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39":[5,0,2,81,0],
@@ -215,39 +238,16 @@ var NAVTREEINDEX113 =
 "class_ogre_1_1_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39aed60ca999861d8939cf57f19090c70ef":[5,0,2,81,0,0],
 "class_ogre_1_1_serializer.html#a6e038a802f8d1f293e73b4d98f6e297d":[5,0,2,81,2],
 "class_ogre_1_1_shader_generator.html":[5,1,1,8],
-"class_ogre_1_1_shader_helper.html":[7,0,0,695],
-"class_ogre_1_1_shader_helper.html#a06fbed66aa6c6e1e76a029016a334449":[7,0,0,695,0],
-"class_ogre_1_1_shader_helper.html#a69243683a76bcb33cfa5010199cd8fb5":[7,0,0,695,5],
-"class_ogre_1_1_shader_helper.html#a88ad7bc700ad8f31cd8d3816ccc5263c":[7,0,0,695,2],
-"class_ogre_1_1_shader_helper.html#ace4fceb783350b53587a999a506e23bb":[7,0,0,695,4],
-"class_ogre_1_1_shader_helper.html#ae0260a80fc0eb977f5ba548f8637f623":[7,0,0,695,3],
-"class_ogre_1_1_shader_helper.html#ae4b8ef34dfa311c28e606ef02706c769":[7,0,0,695,1],
+"class_ogre_1_1_shader_helper.html":[7,0,0,696],
+"class_ogre_1_1_shader_helper.html#a06fbed66aa6c6e1e76a029016a334449":[7,0,0,696,0],
+"class_ogre_1_1_shader_helper.html#a69243683a76bcb33cfa5010199cd8fb5":[7,0,0,696,5],
+"class_ogre_1_1_shader_helper.html#a88ad7bc700ad8f31cd8d3816ccc5263c":[7,0,0,696,2],
+"class_ogre_1_1_shader_helper.html#ace4fceb783350b53587a999a506e23bb":[7,0,0,696,4],
+"class_ogre_1_1_shader_helper.html#ae0260a80fc0eb977f5ba548f8637f623":[7,0,0,696,3],
+"class_ogre_1_1_shader_helper.html#ae4b8ef34dfa311c28e606ef02706c769":[7,0,0,696,1],
 "class_ogre_1_1_shader_manager.html":[5,1,1,9],
 "class_ogre_1_1_shader_pieces_manager.html":[5,1,1,10],
 "class_ogre_1_1_shader_template.html":[5,1,1,11],
 "class_ogre_1_1_shadow_camera_setup.html":[5,0,9,50],
-"class_ogre_1_1_shadow_camera_setup.html#a790a06721a8e3c6f48218aa659c334ef":[5,0,9,50,0],
-"class_ogre_1_1_shadow_camera_setup.html#aef69374906ff048997e187101858f856":[5,0,9,50,1],
-"class_ogre_1_1_shadow_caster.html":[5,0,9,51],
-"class_ogre_1_1_shadow_caster.html#a35d47283265f36187263b2738e16c563":[5,0,9,51,3],
-"class_ogre_1_1_shadow_caster.html#a55f1de18b85d2d276b2ea38a138b4e3e":[5,0,9,51,10],
-"class_ogre_1_1_shadow_caster.html#a6ab7144efe1ca481a4a9a89365ed522d":[5,0,9,51,6],
-"class_ogre_1_1_shadow_caster.html#a7b0999d33e25db97d0449d6cf95cbecd":[5,0,9,51,1],
-"class_ogre_1_1_shadow_caster.html#a7f8a7e2e3a9876a8453e054335d7d23c":[5,0,9,51,12],
-"class_ogre_1_1_shadow_caster.html#a99cc616f547693f39fa354e6600368e6":[5,0,9,51,5],
-"class_ogre_1_1_shadow_caster.html#a9ec42d43470c2e2b0f6f05221371a786":[5,0,9,51,4],
-"class_ogre_1_1_shadow_caster.html#aa09c6e22f9879c123355bca19c1b7131":[5,0,9,51,2],
-"class_ogre_1_1_shadow_caster.html#aaa198e27c2c631a41f8f5f51ad7d7261":[5,0,9,51,8],
-"class_ogre_1_1_shadow_caster.html#ac7b3777c0e3521c021ec3a1c2c444039":[5,0,9,51,0],
-"class_ogre_1_1_shadow_caster.html#acae2215c051989d544f34083a0a9bfa2":[5,0,9,51,11],
-"class_ogre_1_1_shadow_caster.html#ad792b8137f18ea000c5bcbc5ae48814a":[5,0,9,51,7],
-"class_ogre_1_1_shadow_caster.html#afaf1dfad22f842b9b2cb2a0beaad98eb":[5,0,9,51,9],
-"class_ogre_1_1_shadow_renderable.html":[5,0,9,52],
-"class_ogre_1_1_shadow_renderable.html#a08ca1f26af48c8e5b6ac6e028d5eb761":[5,0,9,52,12],
-"class_ogre_1_1_shadow_renderable.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,0,9,52,24],
-"class_ogre_1_1_shadow_renderable.html#a2ed9a2f3c1decac6286f8af974ce2ffc":[5,0,9,52,32],
-"class_ogre_1_1_shadow_renderable.html#a2f770d6ba9b3d97bdc63ecf0e3888aab":[5,0,9,52,28],
-"class_ogre_1_1_shadow_renderable.html#a36d3d1a31ec2661d66faa4675391ed25":[5,0,9,52,5],
-"class_ogre_1_1_shadow_renderable.html#a3b9d5d4abdc4158e035c174816748305":[5,0,9,52,2],
-"class_ogre_1_1_shadow_renderable.html#a3d5e8933145d36977b8c2b64e307bc59":[5,0,9,52,22]
+"class_ogre_1_1_shadow_camera_setup.html#a790a06721a8e3c6f48218aa659c334ef":[5,0,9,50,0]
 };
