@@ -1,5 +1,28 @@
 var NAVTREEINDEX114 =
 {
+"class_ogre_1_1_shadow_camera_setup.html#aef69374906ff048997e187101858f856":[5,0,9,50,1],
+"class_ogre_1_1_shadow_caster.html":[5,0,9,51],
+"class_ogre_1_1_shadow_caster.html#a35d47283265f36187263b2738e16c563":[5,0,9,51,3],
+"class_ogre_1_1_shadow_caster.html#a55f1de18b85d2d276b2ea38a138b4e3e":[5,0,9,51,10],
+"class_ogre_1_1_shadow_caster.html#a6ab7144efe1ca481a4a9a89365ed522d":[5,0,9,51,6],
+"class_ogre_1_1_shadow_caster.html#a7b0999d33e25db97d0449d6cf95cbecd":[5,0,9,51,1],
+"class_ogre_1_1_shadow_caster.html#a7f8a7e2e3a9876a8453e054335d7d23c":[5,0,9,51,12],
+"class_ogre_1_1_shadow_caster.html#a99cc616f547693f39fa354e6600368e6":[5,0,9,51,5],
+"class_ogre_1_1_shadow_caster.html#a9ec42d43470c2e2b0f6f05221371a786":[5,0,9,51,4],
+"class_ogre_1_1_shadow_caster.html#aa09c6e22f9879c123355bca19c1b7131":[5,0,9,51,2],
+"class_ogre_1_1_shadow_caster.html#aaa198e27c2c631a41f8f5f51ad7d7261":[5,0,9,51,8],
+"class_ogre_1_1_shadow_caster.html#ac7b3777c0e3521c021ec3a1c2c444039":[5,0,9,51,0],
+"class_ogre_1_1_shadow_caster.html#acae2215c051989d544f34083a0a9bfa2":[5,0,9,51,11],
+"class_ogre_1_1_shadow_caster.html#ad792b8137f18ea000c5bcbc5ae48814a":[5,0,9,51,7],
+"class_ogre_1_1_shadow_caster.html#afaf1dfad22f842b9b2cb2a0beaad98eb":[5,0,9,51,9],
+"class_ogre_1_1_shadow_renderable.html":[5,0,9,52],
+"class_ogre_1_1_shadow_renderable.html#a08ca1f26af48c8e5b6ac6e028d5eb761":[5,0,9,52,12],
+"class_ogre_1_1_shadow_renderable.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,0,9,52,24],
+"class_ogre_1_1_shadow_renderable.html#a2ed9a2f3c1decac6286f8af974ce2ffc":[5,0,9,52,32],
+"class_ogre_1_1_shadow_renderable.html#a2f770d6ba9b3d97bdc63ecf0e3888aab":[5,0,9,52,28],
+"class_ogre_1_1_shadow_renderable.html#a36d3d1a31ec2661d66faa4675391ed25":[5,0,9,52,5],
+"class_ogre_1_1_shadow_renderable.html#a3b9d5d4abdc4158e035c174816748305":[5,0,9,52,2],
+"class_ogre_1_1_shadow_renderable.html#a3d5e8933145d36977b8c2b64e307bc59":[5,0,9,52,22],
 "class_ogre_1_1_shadow_renderable.html#a3dc69374127d00ea2c2f9f39cf2105bb":[5,0,9,52,35],
 "class_ogre_1_1_shadow_renderable.html#a3ec300ee9b2531c6f8a6330fd029e50b":[5,0,9,52,7],
 "class_ogre_1_1_shadow_renderable.html#a4136ce4b9d3add5203339327015d872d":[5,0,9,52,18],
@@ -30,21 +53,22 @@ var NAVTREEINDEX114 =
 "class_ogre_1_1_shadow_renderable.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,0,9,52,15],
 "class_ogre_1_1_shadow_renderable.html#afd48548fe3314d5d419c695c0788b278":[5,0,9,52,1],
 "class_ogre_1_1_shared_ptr.html":[5,0,2,82],
-"class_ogre_1_1_shared_ptr.html#a0102c9ce0678ec964b26e47b8a5310d1":[5,0,2,82,14],
-"class_ogre_1_1_shared_ptr.html#a058dfd1737dcf94ed8b049718475f816":[5,0,2,82,8],
-"class_ogre_1_1_shared_ptr.html#a119d4d068679964c64a79b2867dd5009":[5,0,2,82,1],
-"class_ogre_1_1_shared_ptr.html#a1b5e6d7a4cc4f7b96e9aa56ccdc982aa":[5,0,2,82,10],
-"class_ogre_1_1_shared_ptr.html#a25fe8dda941c616fde73f664209080e2":[5,0,2,82,2],
-"class_ogre_1_1_shared_ptr.html#a52d62f8b23524bac7b345fb12b8cf16e":[5,0,2,82,7],
-"class_ogre_1_1_shared_ptr.html#a564789e0743e9be6ccb5505057ed63b6":[5,0,2,82,12],
-"class_ogre_1_1_shared_ptr.html#a6dc65b8171394624d1bb43fd9d54a8f6":[5,0,2,82,0],
-"class_ogre_1_1_shared_ptr.html#a910badf7e570d9eae009af96e407acb1":[5,0,2,82,5],
-"class_ogre_1_1_shared_ptr.html#a9d1cf83ba2fc4626c23903678eb5d942":[5,0,2,82,11],
-"class_ogre_1_1_shared_ptr.html#a9ea46224e54b579a56ea769136e12e01":[5,0,2,82,13],
-"class_ogre_1_1_shared_ptr.html#ab1fae2b13ec9cb470b4616c56cb599d8":[5,0,2,82,3],
-"class_ogre_1_1_shared_ptr.html#ad2a6f405c94b4ec8e3f528f549ef74bf":[5,0,2,82,9],
-"class_ogre_1_1_shared_ptr.html#ad9ac8d216452366004f13221074ea906":[5,0,2,82,4],
-"class_ogre_1_1_shared_ptr.html#ade280794a40b2d9cb9686c9de5d7aacf":[5,0,2,82,6],
+"class_ogre_1_1_shared_ptr.html#a0102c9ce0678ec964b26e47b8a5310d1":[5,0,2,82,15],
+"class_ogre_1_1_shared_ptr.html#a058dfd1737dcf94ed8b049718475f816":[5,0,2,82,9],
+"class_ogre_1_1_shared_ptr.html#a119d4d068679964c64a79b2867dd5009":[5,0,2,82,2],
+"class_ogre_1_1_shared_ptr.html#a1b5e6d7a4cc4f7b96e9aa56ccdc982aa":[5,0,2,82,11],
+"class_ogre_1_1_shared_ptr.html#a25fe8dda941c616fde73f664209080e2":[5,0,2,82,3],
+"class_ogre_1_1_shared_ptr.html#a52d62f8b23524bac7b345fb12b8cf16e":[5,0,2,82,8],
+"class_ogre_1_1_shared_ptr.html#a564789e0743e9be6ccb5505057ed63b6":[5,0,2,82,13],
+"class_ogre_1_1_shared_ptr.html#a6dc65b8171394624d1bb43fd9d54a8f6":[5,0,2,82,1],
+"class_ogre_1_1_shared_ptr.html#a813261f2607ae4a407b90c903fd6f030":[5,0,2,82,0],
+"class_ogre_1_1_shared_ptr.html#a910badf7e570d9eae009af96e407acb1":[5,0,2,82,6],
+"class_ogre_1_1_shared_ptr.html#a9d1cf83ba2fc4626c23903678eb5d942":[5,0,2,82,12],
+"class_ogre_1_1_shared_ptr.html#a9ea46224e54b579a56ea769136e12e01":[5,0,2,82,14],
+"class_ogre_1_1_shared_ptr.html#ab1fae2b13ec9cb470b4616c56cb599d8":[5,0,2,82,4],
+"class_ogre_1_1_shared_ptr.html#ad2a6f405c94b4ec8e3f528f549ef74bf":[5,0,2,82,10],
+"class_ogre_1_1_shared_ptr.html#ad9ac8d216452366004f13221074ea906":[5,0,2,82,5],
+"class_ogre_1_1_shared_ptr.html#ade280794a40b2d9cb9686c9de5d7aacf":[5,0,2,82,7],
 "class_ogre_1_1_simple_page_content_collection.html":[5,1,4,17],
 "class_ogre_1_1_simple_page_content_collection.html#a0b5b0c76450d903eca5186a3e382a96b":[5,1,4,17,17],
 "class_ogre_1_1_simple_page_content_collection.html#a0c3b54e1542e9d973cc04e7506ea6dc7":[5,1,4,17,15],
@@ -225,29 +249,5 @@ var NAVTREEINDEX114 =
 "class_ogre_1_1_skeleton.html#a13423fa7944d7f2339e78b9de026c3be":[5,0,0,15,71],
 "class_ogre_1_1_skeleton.html#a15017c0c32eecca545bc00628e1afffd":[5,0,0,15,10],
 "class_ogre_1_1_skeleton.html#a162794b4b599410e395ad9ed0a7eac64":[5,0,0,15,39],
-"class_ogre_1_1_skeleton.html#a18ca8af5292ff53fb681bf5eb5225e4e":[5,0,0,15,19],
-"class_ogre_1_1_skeleton.html#a1a3a60c6a44517d3dc5c23c7fcb109bd":[5,0,0,15,35],
-"class_ogre_1_1_skeleton.html#a1aa750a4b994f2b1066220936cdfdb94":[5,0,0,15,6],
-"class_ogre_1_1_skeleton.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[5,0,0,15,6,1],
-"class_ogre_1_1_skeleton.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[5,0,0,15,6,2],
-"class_ogre_1_1_skeleton.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[5,0,0,15,6,0],
-"class_ogre_1_1_skeleton.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[5,0,0,15,6,4],
-"class_ogre_1_1_skeleton.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[5,0,0,15,6,3],
-"class_ogre_1_1_skeleton.html#a1ba4bc1ca45349f91345a736cd902cc3":[5,0,0,15,41],
-"class_ogre_1_1_skeleton.html#a1bde6f5490f1638bd5aab43651bd5612":[5,0,0,15,27],
-"class_ogre_1_1_skeleton.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[5,0,0,15,85],
-"class_ogre_1_1_skeleton.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[5,0,0,15,83],
-"class_ogre_1_1_skeleton.html#a1e90ade99935ef70ec5b199243bf995b":[5,0,0,15,62],
-"class_ogre_1_1_skeleton.html#a2298551707debaf774d577e643ee856a":[5,0,0,15,58],
-"class_ogre_1_1_skeleton.html#a289ef17351658e59d835601b55d7e560":[5,0,0,15,17],
-"class_ogre_1_1_skeleton.html#a2b38c5a2d4f634092906fd8c1e273ca9":[5,0,0,15,18],
-"class_ogre_1_1_skeleton.html#a2c9370f5a79002c9ebb7d66a5a0b39ef":[5,0,0,15,20],
-"class_ogre_1_1_skeleton.html#a350b287fa3e83a389221274f68760008":[5,0,0,15,49],
-"class_ogre_1_1_skeleton.html#a367f6fe60bb211cb4c32e3825ca67e4c":[5,0,0,15,65],
-"class_ogre_1_1_skeleton.html#a382919945c07a6a13136889ad3fbf578":[5,0,0,15,68],
-"class_ogre_1_1_skeleton.html#a397bf260ff70afd076cd7be9d163fc35":[5,0,0,15,16],
-"class_ogre_1_1_skeleton.html#a3af26f716731b64850ea50cfa4d2edef":[5,0,0,15,61],
-"class_ogre_1_1_skeleton.html#a3c49142f739ba8fb56d6e7b3db235fb7":[5,0,0,15,67],
-"class_ogre_1_1_skeleton.html#a3f7632e047bb6e65fff3c536612fedb7":[5,0,0,15,29],
-"class_ogre_1_1_skeleton.html#a4bbb64b4062dc27de0a62781b7d264c7":[5,0,0,15,33]
+"class_ogre_1_1_skeleton.html#a18ca8af5292ff53fb681bf5eb5225e4e":[5,0,0,15,19]
 };
