@@ -1,5 +1,6 @@
 var NAVTREEINDEX12 =
 {
+"class_ogre_1_1_animation_state_set.html#a49af4b5b62648c598fe631fda6984ea4":[5,0,0,6,7],
 "class_ogre_1_1_animation_state_set.html#a506078aa0b1b78cb3296f81d0641c82b":[5,0,0,6,15],
 "class_ogre_1_1_animation_state_set.html#a55b3e321b7cfcbccd56ca600407bfd19":[5,0,0,6,11],
 "class_ogre_1_1_animation_state_set.html#a5a3783be35f983e5cc923a5719ac69fb":[5,0,0,6,4],
@@ -248,6 +249,5 @@ var NAVTREEINDEX12 =
 "class_ogre_1_1_area_emitter.html":[5,2,6,0],
 "class_ogre_1_1_area_emitter.html#a02624afcd33a3c44995abefba379519f":[5,2,6,0,90],
 "class_ogre_1_1_area_emitter.html#a0675cd5508ed0a37fa6613ad5d0978c5":[5,2,6,0,14],
-"class_ogre_1_1_area_emitter.html#a08d117bf25f011f96d81f1f4ecb25113":[5,2,6,0,77],
-"class_ogre_1_1_area_emitter.html#a0cdad11e98fe6af5c36ca88b83e439ac":[5,2,6,0,35]
+"class_ogre_1_1_area_emitter.html#a08d117bf25f011f96d81f1f4ecb25113":[5,2,6,0,77]
 };
