@@ -1,5 +1,6 @@
 var NAVTREEINDEX13 =
 {
+"class_ogre_1_1_area_emitter.html#a0cdad11e98fe6af5c36ca88b83e439ac":[5,2,6,0,35],
 "class_ogre_1_1_area_emitter.html#a0ddb2110884003fa74abc6eaab2682cc":[5,2,6,0,17],
 "class_ogre_1_1_area_emitter.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,2,6,0,75],
 "class_ogre_1_1_area_emitter.html#a123c22ed81e96c90b5cb096d11e26aae":[5,2,6,0,8],
@@ -248,6 +249,5 @@ var NAVTREEINDEX13 =
 "class_ogre_1_1_axis_aligned_box.html#a2b18ee5edab3005f741e94e39740b50f":[5,0,6,2,7],
 "class_ogre_1_1_axis_aligned_box.html#a2ba95e1e5c7d3cf869e0144d4233d038":[5,0,6,2,30],
 "class_ogre_1_1_axis_aligned_box.html#a2e0be3251dbe51eec06999a0a9380359":[5,0,6,2,22],
-"class_ogre_1_1_axis_aligned_box.html#a3142685d30334a229535ae5265d65dd0":[5,0,6,2,13],
-"class_ogre_1_1_axis_aligned_box.html#a376f0d3333f8c5e84e679a981b2cc4dd":[5,0,6,2,5]
+"class_ogre_1_1_axis_aligned_box.html#a3142685d30334a229535ae5265d65dd0":[5,0,6,2,13]
 };
