@@ -1,5 +1,6 @@
 var NAVTREEINDEX14 =
 {
+"class_ogre_1_1_axis_aligned_box.html#a376f0d3333f8c5e84e679a981b2cc4dd":[5,0,6,2,5],
 "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443e":[5,0,6,2,1],
 "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443ea5046ce9384ab8647fb3c58e03d5446c9":[5,0,6,2,1,0],
 "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443ea549926fd8188d52a8a579673de7b93a2":[5,0,6,2,1,2],
@@ -248,6 +249,5 @@ var NAVTREEINDEX14 =
 "class_ogre_1_1_billboard_chain.html#a1ad93e3514b969971213ff4ae80103dc":[5,0,1,1,68],
 "class_ogre_1_1_billboard_chain.html#a1dcbc7ae7fd974fabccc83bf8f97bd31":[5,0,1,1,37],
 "class_ogre_1_1_billboard_chain.html#a21555a72ccbad1a4845c80529e2ebd1e":[5,0,1,1,38],
-"class_ogre_1_1_billboard_chain.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,0,1,1,82],
-"class_ogre_1_1_billboard_chain.html#a2b5b86e082a44769ae96ec2e48930b90":[5,0,1,1,44]
+"class_ogre_1_1_billboard_chain.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,0,1,1,82]
 };
