@@ -1,5 +1,29 @@
 var NAVTREEINDEX142 =
 {
+"rtss.html#rtss_custom_mat":[1,5,0,0],
+"rtss.html#rtss_indepth":[1,5,0,2],
+"rtss.html#rtss_overview":[1,5,0,1],
+"setup.html":[2,1],
+"setup.html#cmake":[2,1,0],
+"setup.html#skeleton":[2,1,1],
+"src_2_g_l_s_l_2include_2_ogre_g_l_s_l_ext_support_8h.html":[8,0,250],
+"src_2_g_l_s_l_2include_2_ogre_g_l_s_l_ext_support_8h.html#a288748bd2f8df037db03fa864e2ecaff":[8,0,250,1],
+"src_2_g_l_s_l_2include_2_ogre_g_l_s_l_ext_support_8h.html#a2d3acd2bf86281d58f43a006156a123c":[8,0,250,0],
+"src_2_g_l_s_l_2include_2_ogre_g_l_s_l_ext_support_8h.html#af7f7e123f60e128dcee954ef2ab64ed6":[8,0,250,2],
+"src_2_g_l_s_l_2include_2_ogre_g_l_s_l_program_8h.html":[8,0,257],
+"struct__finddata__t.html":[7,0,2],
+"struct__finddata__t.html#a4a50f070b61c49cc821864fa6bb7b599":[7,0,2,1],
+"struct__finddata__t.html#aa8b6c8443328752952e99f366254a6f8":[7,0,2,0],
+"struct__finddata__t.html#aacf50a90e0fa143ce6ff22628b8c58aa":[7,0,2,2],
+"struct_ogre_1_1_aligned_allocator.html":[5,0,2,1],
+"struct_ogre_1_1_aligned_allocator.html#a43862beb4c7cf42d4537d85f94bdf05c":[5,0,2,1,2],
+"struct_ogre_1_1_aligned_allocator.html#a4d0845f9e4a7559eebb30d2ca7c2fa2e":[5,0,2,1,4],
+"struct_ogre_1_1_aligned_allocator.html#a6b5516246b4c0bf36bc88d78c1661c1a":[5,0,2,1,5],
+"struct_ogre_1_1_aligned_allocator.html#a9a35293209acfd3fcb5d6e9e44229b9b":[5,0,2,1,3],
+"struct_ogre_1_1_aligned_allocator.html#aec0f4e93bb6df7da96d02e6a6aafadfd":[5,0,2,1,1],
+"struct_ogre_1_1_aligned_allocator_1_1rebind.html":[5,0,2,1,0],
+"struct_ogre_1_1_aligned_allocator_1_1rebind.html#ae2157f23d51da7c107f7a37e95dec785":[5,0,2,1,0,0],
+"struct_ogre_1_1_background_process_result.html":[5,0,8,4],
 "struct_ogre_1_1_background_process_result.html#a934afcd6516ef003331f5423ec485f1e":[5,0,8,4,0],
 "struct_ogre_1_1_background_process_result.html#aa6de3c8fdaefa3b4a3895948fc9c115b":[5,0,8,4,2],
 "struct_ogre_1_1_background_process_result.html#aebcd24f1d14c77fcb242aa937658c7f2":[5,0,8,4,1],
@@ -77,8 +101,8 @@ var NAVTREEINDEX142 =
 "struct_ogre_1_1_edge_data_1_1_triangle.html#a8bf63fc09c7508d4c4863168442520db":[5,0,6,7,2,2],
 "struct_ogre_1_1_edge_data_1_1_triangle.html#ac676a82255cafa821af2f4143160f2b1":[5,0,6,7,2,0],
 "struct_ogre_1_1_edge_data_1_1_triangle.html#af3610ee6a688cccc061392263bde1929":[5,0,6,7,2,3],
-"struct_ogre_1_1_element_translator.html":[7,0,0,213],
-"struct_ogre_1_1_element_translator.html#ab472de964103cf3fdc0ab8af92fda79c":[7,0,0,213,0],
+"struct_ogre_1_1_element_translator.html":[7,0,0,214],
+"struct_ogre_1_1_element_translator.html#ab472de964103cf3fdc0ab8af92fda79c":[7,0,0,214,0],
 "struct_ogre_1_1_entity_material_lod_changed_event.html":[5,0,4,3],
 "struct_ogre_1_1_entity_material_lod_changed_event.html#a0b03437c5c7d5e9948e413f776c83b24":[5,0,4,3,0],
 "struct_ogre_1_1_entity_material_lod_changed_event.html#a3cf406b5a0364410f0090013e41ed924":[5,0,4,3,4],
@@ -103,32 +127,32 @@ var NAVTREEINDEX142 =
 "struct_ogre_1_1_font_1_1_glyph_info.html#a4eec8222d9985bb3b15d886120fd1ae6":[5,1,3,4,0,3],
 "struct_ogre_1_1_font_1_1_glyph_info.html#a5df1a038d81fcf018ea7f5aac3181a62":[5,1,3,4,0,1],
 "struct_ogre_1_1_font_1_1_glyph_info.html#a8a6e99cee590d9723af63ac4a6db8849":[5,1,3,4,0,0],
-"struct_ogre_1_1_font_translator.html":[7,0,0,238],
-"struct_ogre_1_1_font_translator.html#a52af27869207d289a369d9b6c18f77a0":[7,0,0,238,1],
-"struct_ogre_1_1_font_translator.html#ac2564f3cbdd823615abc5e97c86028bf":[7,0,0,238,0],
+"struct_ogre_1_1_font_translator.html":[7,0,0,239],
+"struct_ogre_1_1_font_translator.html#a52af27869207d289a369d9b6c18f77a0":[7,0,0,239,1],
+"struct_ogre_1_1_font_translator.html#ac2564f3cbdd823615abc5e97c86028bf":[7,0,0,239,0],
 "struct_ogre_1_1_frame_event.html":[5,0,2,33],
 "struct_ogre_1_1_frame_event.html#ab772e995840b64e5f0bff08cdc29abd5":[5,0,2,33,0],
 "struct_ogre_1_1_frame_event.html#adf69bb72418f50afcbf5b55ce0745b31":[5,0,2,33,1],
-"struct_ogre_1_1_g_l_atomic_counter_reference.html":[7,0,0,270],
-"struct_ogre_1_1_g_l_atomic_counter_reference.html#a1a008191f53cb0b62b1e8a7085304da2":[7,0,0,270,1],
-"struct_ogre_1_1_g_l_atomic_counter_reference.html#a204d4053ddc8c2a0f8c5f5901e54cf07":[7,0,0,270,0],
-"struct_ogre_1_1_g_l_atomic_counter_reference.html#ac8ba3b4233ec2ec1582a9dc2e82c3fd4":[7,0,0,270,2],
-"struct_ogre_1_1_g_l_atomic_counter_reference.html#aed4e289a240d18f013e2d9678069e84d":[7,0,0,270,3],
-"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html":[7,0,0,319,0],
-"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#a399117971dbc3f195c0dba039c231e00":[7,0,0,319,0,4],
-"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#a4d7a865db8ebb4353e843d161b64b3b4":[7,0,0,319,0,1],
-"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#a75bc7d0082e14d93fca26f799d2b9d59":[7,0,0,319,0,3],
-"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#a790d21a761bdb3878fdf70475857c29a":[7,0,0,319,0,2],
-"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#af15d69f03ad6886c18b6963b97c40f01":[7,0,0,319,0,0],
-"struct_ogre_1_1_g_l_surface_desc.html":[7,0,0,343],
-"struct_ogre_1_1_g_l_surface_desc.html#a06710eae3716931ee6b6e2a796757177":[7,0,0,343,3],
-"struct_ogre_1_1_g_l_surface_desc.html#a17db8cb3634f2023f2f7cb7f92cd4389":[7,0,0,343,0],
-"struct_ogre_1_1_g_l_surface_desc.html#a1a6df7cf12b9965a7a77c2f82b81c687":[7,0,0,343,1],
-"struct_ogre_1_1_g_l_surface_desc.html#a1e8060781bc000aba03bcbf9bc198a4f":[7,0,0,343,2],
-"struct_ogre_1_1_g_l_uniform_reference.html":[7,0,0,349],
-"struct_ogre_1_1_g_l_uniform_reference.html#a218b13167824ca7e7ba1899759042f9d":[7,0,0,349,0],
-"struct_ogre_1_1_g_l_uniform_reference.html#a2d32db8791ed30e82ae3a73485ab0085":[7,0,0,349,1],
-"struct_ogre_1_1_g_l_uniform_reference.html#affbe925ee3fa4a580c3c0f0d5ce43a24":[7,0,0,349,2],
+"struct_ogre_1_1_g_l_atomic_counter_reference.html":[7,0,0,271],
+"struct_ogre_1_1_g_l_atomic_counter_reference.html#a1a008191f53cb0b62b1e8a7085304da2":[7,0,0,271,1],
+"struct_ogre_1_1_g_l_atomic_counter_reference.html#a204d4053ddc8c2a0f8c5f5901e54cf07":[7,0,0,271,0],
+"struct_ogre_1_1_g_l_atomic_counter_reference.html#ac8ba3b4233ec2ec1582a9dc2e82c3fd4":[7,0,0,271,2],
+"struct_ogre_1_1_g_l_atomic_counter_reference.html#aed4e289a240d18f013e2d9678069e84d":[7,0,0,271,3],
+"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html":[7,0,0,320,0],
+"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#a399117971dbc3f195c0dba039c231e00":[7,0,0,320,0,4],
+"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#a4d7a865db8ebb4353e843d161b64b3b4":[7,0,0,320,0,1],
+"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#a75bc7d0082e14d93fca26f799d2b9d59":[7,0,0,320,0,3],
+"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#a790d21a761bdb3878fdf70475857c29a":[7,0,0,320,0,2],
+"struct_ogre_1_1_g_l_render_system_common_1_1_video_mode.html#af15d69f03ad6886c18b6963b97c40f01":[7,0,0,320,0,0],
+"struct_ogre_1_1_g_l_surface_desc.html":[7,0,0,344],
+"struct_ogre_1_1_g_l_surface_desc.html#a06710eae3716931ee6b6e2a796757177":[7,0,0,344,3],
+"struct_ogre_1_1_g_l_surface_desc.html#a17db8cb3634f2023f2f7cb7f92cd4389":[7,0,0,344,0],
+"struct_ogre_1_1_g_l_surface_desc.html#a1a6df7cf12b9965a7a77c2f82b81c687":[7,0,0,344,1],
+"struct_ogre_1_1_g_l_surface_desc.html#a1e8060781bc000aba03bcbf9bc198a4f":[7,0,0,344,2],
+"struct_ogre_1_1_g_l_uniform_reference.html":[7,0,0,350],
+"struct_ogre_1_1_g_l_uniform_reference.html#a218b13167824ca7e7ba1899759042f9d":[7,0,0,350,0],
+"struct_ogre_1_1_g_l_uniform_reference.html#a2d32db8791ed30e82ae3a73485ab0085":[7,0,0,350,1],
+"struct_ogre_1_1_g_l_uniform_reference.html#affbe925ee3fa4a580c3c0f0d5ce43a24":[7,0,0,350,2],
 "struct_ogre_1_1_gpu_constant_definition.html":[5,0,5,4],
 "struct_ogre_1_1_gpu_constant_definition.html#a134c40a7f7baddf559a6a771c0cd9149":[5,0,5,4,5],
 "struct_ogre_1_1_gpu_constant_definition.html#a13ed935cc299f0b4bfdd2b308e96e459":[5,0,5,4,2],
@@ -197,20 +221,20 @@ var NAVTREEINDEX142 =
 "struct_ogre_1_1_hardware_buffer_lock_guard.html#ac91557604cdd46df51157fbeabb750ef":[5,0,7,10,6],
 "struct_ogre_1_1_hardware_buffer_lock_guard.html#acf8b2f43970159df11e417defb4926f1":[5,0,7,10,4],
 "struct_ogre_1_1_hardware_buffer_lock_guard.html#af49d98668e31dad8d1633d7d3e1a4a3c":[5,0,7,10,10],
-"struct_ogre_1_1_id_string.html":[7,0,0,388],
-"struct_ogre_1_1_id_string.html#a02823d57b43db3704ad4d8f8b1527e46":[7,0,0,388,8],
-"struct_ogre_1_1_id_string.html#a1975a7a2705e2ff8b15c3143636addec":[7,0,0,388,4],
-"struct_ogre_1_1_id_string.html#a34d6188685e991789d904b1151d16f07":[7,0,0,388,11],
-"struct_ogre_1_1_id_string.html#a37ea40cc268d6cdacf235c09d0d48720":[7,0,0,388,2],
-"struct_ogre_1_1_id_string.html#a3f65ef76705bbe55689dd4affed6df06":[7,0,0,388,3],
-"struct_ogre_1_1_id_string.html#a54eeffe30aae07b2f4b7bf7a8cf10d27":[7,0,0,388,12],
-"struct_ogre_1_1_id_string.html#a56caa2838bf509872f4595c183e2fe6f":[7,0,0,388,1],
-"struct_ogre_1_1_id_string.html#a58af7942c44e5907144fa4efe18c84a9":[7,0,0,388,9],
-"struct_ogre_1_1_id_string.html#aa879e3cd371deb2979f1f5d4b8977d44":[7,0,0,388,6],
-"struct_ogre_1_1_id_string.html#aafe0decfa1fbd2be4d46609ffc5647d5":[7,0,0,388,0],
-"struct_ogre_1_1_id_string.html#ad8d64faf790e160a7dc4f1ed61598df1":[7,0,0,388,7],
-"struct_ogre_1_1_id_string.html#aedc10c2eb528fe8c1d8d2ab415500d7b":[7,0,0,388,10],
-"struct_ogre_1_1_id_string.html#afbe35aa8a428bd10ca8588921891860f":[7,0,0,388,5],
+"struct_ogre_1_1_id_string.html":[7,0,0,389],
+"struct_ogre_1_1_id_string.html#a02823d57b43db3704ad4d8f8b1527e46":[7,0,0,389,8],
+"struct_ogre_1_1_id_string.html#a1975a7a2705e2ff8b15c3143636addec":[7,0,0,389,4],
+"struct_ogre_1_1_id_string.html#a34d6188685e991789d904b1151d16f07":[7,0,0,389,11],
+"struct_ogre_1_1_id_string.html#a37ea40cc268d6cdacf235c09d0d48720":[7,0,0,389,2],
+"struct_ogre_1_1_id_string.html#a3f65ef76705bbe55689dd4affed6df06":[7,0,0,389,3],
+"struct_ogre_1_1_id_string.html#a54eeffe30aae07b2f4b7bf7a8cf10d27":[7,0,0,389,12],
+"struct_ogre_1_1_id_string.html#a56caa2838bf509872f4595c183e2fe6f":[7,0,0,389,1],
+"struct_ogre_1_1_id_string.html#a58af7942c44e5907144fa4efe18c84a9":[7,0,0,389,9],
+"struct_ogre_1_1_id_string.html#aa879e3cd371deb2979f1f5d4b8977d44":[7,0,0,389,6],
+"struct_ogre_1_1_id_string.html#aafe0decfa1fbd2be4d46609ffc5647d5":[7,0,0,389,0],
+"struct_ogre_1_1_id_string.html#ad8d64faf790e160a7dc4f1ed61598df1":[7,0,0,389,7],
+"struct_ogre_1_1_id_string.html#aedc10c2eb528fe8c1d8d2ab415500d7b":[7,0,0,389,10],
+"struct_ogre_1_1_id_string.html#afbe35aa8a428bd10ca8588921891860f":[7,0,0,389,5],
 "struct_ogre_1_1_illumination_pass.html":[5,0,5,13],
 "struct_ogre_1_1_illumination_pass.html#a6931df999c8161fb6f91d121b0553577":[5,0,5,13,4],
 "struct_ogre_1_1_illumination_pass.html#ab5f7c941a2c79525fa9077eb358c628b":[5,0,5,13,2],
@@ -225,29 +249,5 @@ var NAVTREEINDEX142 =
 "struct_ogre_1_1_linked_skeleton_animation_source.html#a18367921f5c2e7eddaf14a54dacd3484":[5,0,0,10,2],
 "struct_ogre_1_1_linked_skeleton_animation_source.html#a79bb4debcd21595087623b9a8d17d121":[5,0,0,10,4],
 "struct_ogre_1_1_linked_skeleton_animation_source.html#a7a01cb43456b193136f19dd60e9ec7f2":[5,0,0,10,0],
-"struct_ogre_1_1_linked_skeleton_animation_source.html#ad04b9f46242d6c0f8226f423274a3c40":[5,0,0,10,1],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html":[7,0,0,436,0],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a21e8b0e3c009ccb5d96dfa9e0a1c1bdeac6983abf66e01db92591f25e5fb5131a":[7,0,0,436,0,0],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a320e05f6a3d088c4fcfee4d2f362acc2":[7,0,0,436,0,7],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a433c84c8a42109d4f1e0987c063b0eee":[7,0,0,436,0,8],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a5bbe0b22b07477f9c3c85386ddc92ea4":[7,0,0,436,0,4],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a8f6afddc2684f600eecf1b7e3b54cde2":[7,0,0,436,0,1],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a9260f2150cfaf077b464264a0ed1ff3d":[7,0,0,436,0,6],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#acaec158cb30ee047996b3c28014354bf":[7,0,0,436,0,5],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#ae5ec1345c756136361e8007598c838c1":[7,0,0,436,0,3],
-"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#aea6d9b276a12912bcde04f0d19337485":[7,0,0,436,0,2],
-"struct_ogre_1_1_lod_config.html":[5,1,2,2],
-"struct_ogre_1_1_lod_config.html#a01a003f9abfe3c9fb7a737fb656ebc9c":[5,1,2,2,9],
-"struct_ogre_1_1_lod_config.html#a0253402aeaebecece55a8ebf9aa977cd":[5,1,2,2,2],
-"struct_ogre_1_1_lod_config.html#a197e4bbdc17c5645e9775d0ea1863c4d":[5,1,2,2,5],
-"struct_ogre_1_1_lod_config.html#a5e92bc54de6971b64807d83f41532d21":[5,1,2,2,4],
-"struct_ogre_1_1_lod_config.html#a791dec38cc670f9bf9fa1e6ac5230a08":[5,1,2,2,6],
-"struct_ogre_1_1_lod_config.html#a7eecc87589b5a3eacfa363850c2fe4c0":[5,1,2,2,8],
-"struct_ogre_1_1_lod_config.html#a9634e8bfa3c423b7a2ad130f5db9ca61":[5,1,2,2,7],
-"struct_ogre_1_1_lod_config.html#aa70b6cf68e01fe84a5b01fe5af5839da":[5,1,2,2,1],
-"struct_ogre_1_1_lod_config.html#ae2ae0ac3ec6f97efcaeb586dcf3b4d89":[5,1,2,2,3],
-"struct_ogre_1_1_lod_config_1_1_advanced.html":[5,1,2,2,0],
-"struct_ogre_1_1_lod_config_1_1_advanced.html#a170e01ea28652c19ec4d610c0b491ab7":[5,1,2,2,0,2],
-"struct_ogre_1_1_lod_config_1_1_advanced.html#a8aae61afbddb7ac0e5f6666d953b973d":[5,1,2,2,0,6],
-"struct_ogre_1_1_lod_config_1_1_advanced.html#a9ce3a02176658acb95c60bc98d9c189c":[5,1,2,2,0,5]
+"struct_ogre_1_1_linked_skeleton_animation_source.html#ad04b9f46242d6c0f8226f423274a3c40":[5,0,0,10,1]
 };
