@@ -1,5 +1,29 @@
 var NAVTREEINDEX143 =
 {
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html":[7,0,0,437,0],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a21e8b0e3c009ccb5d96dfa9e0a1c1bdeac6983abf66e01db92591f25e5fb5131a":[7,0,0,437,0,0],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a320e05f6a3d088c4fcfee4d2f362acc2":[7,0,0,437,0,7],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a433c84c8a42109d4f1e0987c063b0eee":[7,0,0,437,0,8],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a5bbe0b22b07477f9c3c85386ddc92ea4":[7,0,0,437,0,4],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a8f6afddc2684f600eecf1b7e3b54cde2":[7,0,0,437,0,1],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#a9260f2150cfaf077b464264a0ed1ff3d":[7,0,0,437,0,6],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#acaec158cb30ee047996b3c28014354bf":[7,0,0,437,0,5],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#ae5ec1345c756136361e8007598c838c1":[7,0,0,437,0,3],
+"struct_ogre_1_1_lod0_stripifier_1_1_remap_info.html#aea6d9b276a12912bcde04f0d19337485":[7,0,0,437,0,2],
+"struct_ogre_1_1_lod_config.html":[5,1,2,2],
+"struct_ogre_1_1_lod_config.html#a01a003f9abfe3c9fb7a737fb656ebc9c":[5,1,2,2,9],
+"struct_ogre_1_1_lod_config.html#a0253402aeaebecece55a8ebf9aa977cd":[5,1,2,2,2],
+"struct_ogre_1_1_lod_config.html#a197e4bbdc17c5645e9775d0ea1863c4d":[5,1,2,2,5],
+"struct_ogre_1_1_lod_config.html#a5e92bc54de6971b64807d83f41532d21":[5,1,2,2,4],
+"struct_ogre_1_1_lod_config.html#a791dec38cc670f9bf9fa1e6ac5230a08":[5,1,2,2,6],
+"struct_ogre_1_1_lod_config.html#a7eecc87589b5a3eacfa363850c2fe4c0":[5,1,2,2,8],
+"struct_ogre_1_1_lod_config.html#a9634e8bfa3c423b7a2ad130f5db9ca61":[5,1,2,2,7],
+"struct_ogre_1_1_lod_config.html#aa70b6cf68e01fe84a5b01fe5af5839da":[5,1,2,2,1],
+"struct_ogre_1_1_lod_config.html#ae2ae0ac3ec6f97efcaeb586dcf3b4d89":[5,1,2,2,3],
+"struct_ogre_1_1_lod_config_1_1_advanced.html":[5,1,2,2,0],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#a170e01ea28652c19ec4d610c0b491ab7":[5,1,2,2,0,2],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#a8aae61afbddb7ac0e5f6666d953b973d":[5,1,2,2,0,6],
+"struct_ogre_1_1_lod_config_1_1_advanced.html#a9ce3a02176658acb95c60bc98d9c189c":[5,1,2,2,0,5],
 "struct_ogre_1_1_lod_config_1_1_advanced.html#a9f051724cc2c50cb6fc84a749c3bd26f":[5,1,2,2,0,0],
 "struct_ogre_1_1_lod_config_1_1_advanced.html#aa510662a645fab3ef85ef4b1cde1a7a2":[5,1,2,2,0,3],
 "struct_ogre_1_1_lod_config_1_1_advanced.html#ac81a8e65cff66d461b2c884d35662f85":[5,1,2,2,0,4],
@@ -102,13 +126,13 @@ var NAVTREEINDEX143 =
 "struct_ogre_1_1_lod_vertex_buffer.html#a26ef0460f2b0ac0ec0c6994bce586f37":[5,1,2,9,3],
 "struct_ogre_1_1_lod_vertex_buffer.html#a2ece4a3fd9118aa7e15124f3e1203643":[5,1,2,9,2],
 "struct_ogre_1_1_lod_vertex_buffer.html#a65b447865940664a91f87609c881bd7b":[5,1,2,9,1],
-"struct_ogre_1_1_lod_work_queue_request.html":[7,0,0,465],
-"struct_ogre_1_1_lod_work_queue_request.html#a1dd4c036f38b55a48ad5178e892d164d":[7,0,0,465,5],
-"struct_ogre_1_1_lod_work_queue_request.html#a4599170ec029f39b688ea9a465d3136a":[7,0,0,465,3],
-"struct_ogre_1_1_lod_work_queue_request.html#a745815864dce15ecf7c8a710aa4145da":[7,0,0,465,1],
-"struct_ogre_1_1_lod_work_queue_request.html#a7996a702b24ff93fd5cb615a913c3aff":[7,0,0,465,2],
-"struct_ogre_1_1_lod_work_queue_request.html#a7b36867cf35d5bbfc3c43c00c7bf3884":[7,0,0,465,4],
-"struct_ogre_1_1_lod_work_queue_request.html#a9f6f9198f8a9057cbb148139deb43f5d":[7,0,0,465,0],
+"struct_ogre_1_1_lod_work_queue_request.html":[7,0,0,466],
+"struct_ogre_1_1_lod_work_queue_request.html#a1dd4c036f38b55a48ad5178e892d164d":[7,0,0,466,5],
+"struct_ogre_1_1_lod_work_queue_request.html#a4599170ec029f39b688ea9a465d3136a":[7,0,0,466,3],
+"struct_ogre_1_1_lod_work_queue_request.html#a745815864dce15ecf7c8a710aa4145da":[7,0,0,466,1],
+"struct_ogre_1_1_lod_work_queue_request.html#a7996a702b24ff93fd5cb615a913c3aff":[7,0,0,466,2],
+"struct_ogre_1_1_lod_work_queue_request.html#a7b36867cf35d5bbfc3c43c00c7bf3884":[7,0,0,466,4],
+"struct_ogre_1_1_lod_work_queue_request.html#a9f6f9198f8a9057cbb148139deb43f5d":[7,0,0,466,0],
 "struct_ogre_1_1_log_1_1_stream_1_1_flush.html":[5,0,2,45,0,0],
 "struct_ogre_1_1_mesh_lod_usage.html":[5,0,8,20],
 "struct_ogre_1_1_mesh_lod_usage.html#a114e1bc321b7b64f5bc931a30fea4dfe":[5,0,8,20,1],
@@ -120,8 +144,8 @@ var NAVTREEINDEX143 =
 "struct_ogre_1_1_movable_object_lod_changed_event.html":[5,0,4,8],
 "struct_ogre_1_1_movable_object_lod_changed_event.html#af1634e44ab330c287488365219d7f4bd":[5,0,4,8,0],
 "struct_ogre_1_1_movable_object_lod_changed_event.html#af49dc1c7f039fa4d999e9621bfdf72de":[5,0,4,8,1],
-"struct_ogre_1_1_overlay_translator.html":[7,0,0,526],
-"struct_ogre_1_1_overlay_translator.html#a5c5b3d59284fa3459e3565a16496230c":[7,0,0,526,0],
+"struct_ogre_1_1_overlay_translator.html":[7,0,0,527],
+"struct_ogre_1_1_overlay_translator.html#a5c5b3d59284fa3459e3565a16496230c":[7,0,0,527,0],
 "struct_ogre_1_1_pass_1_1_hash_func.html":[5,0,5,18,0],
 "struct_ogre_1_1_pass_1_1_hash_func.html#a01cf55085247cf9db23648dcc3be4daa":[5,0,5,18,0,0],
 "struct_ogre_1_1_pass_1_1_hash_func.html#a400b09fb165aef788325d193a7c3d2a0":[5,0,5,18,0,1],
@@ -225,29 +249,5 @@ var NAVTREEINDEX143 =
 "struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#a0dcf1f5c90e9bd2491aeafca5f609178":[5,1,6,26,0,4],
 "struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#a3d2c3fcc3d4dff6f8906a16b6f4a2f5d":[5,1,6,26,0,2],
 "struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#a60022622e013703f03f9b99d03d2bcf4":[5,1,6,26,0,0],
-"struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#a65dbf98e67e3eb018af44c73b5e5e7be":[5,1,6,26,0,3],
-"struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#a6d13e5c4155d45fd63128d98a8a2fd6f":[5,1,6,26,0,5],
-"struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#abc3f8c1b2e470eb7e6a39bccd1b44097":[5,1,6,26,0,6],
-"struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#acad590d1c409f6ce5b37231cd98b8009":[5,1,6,26,0,1],
-"struct_ogre_1_1_r_t_shader_1_1_in.html":[5,1,6,31],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a0bb486f15c8095ff4184ec23c3d6c1dc":[5,1,6,31,25],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a0ca5992904d58fc9b98d03fe94482e75":[5,1,6,31,24],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a187d31923cfbeb9ac7c45783182fb703":[5,1,6,31,7],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a2007ac06f75325112ebb941b9bba8d95":[5,1,6,31,11],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a3ea5c96b29a25591d8eb41f6fb87837f":[5,1,6,31,9],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a3fa7920e9a098183a2b379438104065c":[5,1,6,31,14],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a40eb42be68c9386737976d317aa0e147":[5,1,6,31,16],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a4475c49e149afb5eb9fbc3c11a96dd3c":[5,1,6,31,6],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a50ab83cea566b55ad9c66d0d93ea7e7a":[5,1,6,31,0],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a50ab83cea566b55ad9c66d0d93ea7e7aa06f81dc0c627f8bdf5cc7862a2d41a03":[5,1,6,31,0,0],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a50ab83cea566b55ad9c66d0d93ea7e7aaa9c91fcd27840fa199f466c9aa479c7a":[5,1,6,31,0,1],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a50ab83cea566b55ad9c66d0d93ea7e7aab762072f828e74fe1d0d8f750dedb26d":[5,1,6,31,0,2],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a52ee4c5af1cee5eab499103be67a76f0":[5,1,6,31,5],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a543726cd5a47b3c485dcc44626099d64":[5,1,6,31,20],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a59e826de6bff9489739e53d8f571bed9":[5,1,6,31,2],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a5d75c1cbf7a5cc290b62935e4b85ba0d":[5,1,6,31,21],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a672dbe7a638e3fd75161f1102efa7616":[5,1,6,31,12],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a6cfcd96508bbaa607882bc9fed665110":[5,1,6,31,19],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a775b1b466c9d9072e718c56eb9d8d9ad":[5,1,6,31,1],
-"struct_ogre_1_1_r_t_shader_1_1_in.html#a775b1b466c9d9072e718c56eb9d8d9ada10ab1af28f557c540fbf5c55cdcfd21b":[5,1,6,31,1,13]
+"struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#a65dbf98e67e3eb018af44c73b5e5e7be":[5,1,6,26,0,3]
 };
