@@ -1,5 +1,29 @@
 var NAVTREEINDEX144 =
 {
+"struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#a6d13e5c4155d45fd63128d98a8a2fd6f":[5,1,6,26,0,5],
+"struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#abc3f8c1b2e470eb7e6a39bccd1b44097":[5,1,6,26,0,6],
+"struct_ogre_1_1_r_t_shader_1_1_hardware_skinning_1_1_skinning_data.html#acad590d1c409f6ce5b37231cd98b8009":[5,1,6,26,0,1],
+"struct_ogre_1_1_r_t_shader_1_1_in.html":[5,1,6,31],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a0bb486f15c8095ff4184ec23c3d6c1dc":[5,1,6,31,25],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a0ca5992904d58fc9b98d03fe94482e75":[5,1,6,31,24],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a187d31923cfbeb9ac7c45783182fb703":[5,1,6,31,7],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a2007ac06f75325112ebb941b9bba8d95":[5,1,6,31,11],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a3ea5c96b29a25591d8eb41f6fb87837f":[5,1,6,31,9],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a3fa7920e9a098183a2b379438104065c":[5,1,6,31,14],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a40eb42be68c9386737976d317aa0e147":[5,1,6,31,16],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a4475c49e149afb5eb9fbc3c11a96dd3c":[5,1,6,31,6],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a50ab83cea566b55ad9c66d0d93ea7e7a":[5,1,6,31,0],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a50ab83cea566b55ad9c66d0d93ea7e7aa06f81dc0c627f8bdf5cc7862a2d41a03":[5,1,6,31,0,0],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a50ab83cea566b55ad9c66d0d93ea7e7aaa9c91fcd27840fa199f466c9aa479c7a":[5,1,6,31,0,1],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a50ab83cea566b55ad9c66d0d93ea7e7aab762072f828e74fe1d0d8f750dedb26d":[5,1,6,31,0,2],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a52ee4c5af1cee5eab499103be67a76f0":[5,1,6,31,5],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a543726cd5a47b3c485dcc44626099d64":[5,1,6,31,20],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a59e826de6bff9489739e53d8f571bed9":[5,1,6,31,2],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a5d75c1cbf7a5cc290b62935e4b85ba0d":[5,1,6,31,21],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a672dbe7a638e3fd75161f1102efa7616":[5,1,6,31,12],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a6cfcd96508bbaa607882bc9fed665110":[5,1,6,31,19],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a775b1b466c9d9072e718c56eb9d8d9ad":[5,1,6,31,1],
+"struct_ogre_1_1_r_t_shader_1_1_in.html#a775b1b466c9d9072e718c56eb9d8d9ada10ab1af28f557c540fbf5c55cdcfd21b":[5,1,6,31,1,13],
 "struct_ogre_1_1_r_t_shader_1_1_in.html#a775b1b466c9d9072e718c56eb9d8d9ada367b59ffbc3bda50ac3d7fb948b8f2a3":[5,1,6,31,1,4],
 "struct_ogre_1_1_r_t_shader_1_1_in.html#a775b1b466c9d9072e718c56eb9d8d9ada379afe25193c60cff5f73bc02758ab40":[5,1,6,31,1,12],
 "struct_ogre_1_1_r_t_shader_1_1_in.html#a775b1b466c9d9072e718c56eb9d8d9ada3c641c6bd99295e563b69473a0a08cf7":[5,1,6,31,1,9],
@@ -215,39 +239,15 @@ var NAVTREEINDEX144 =
 "struct_ogre_1_1_scene_query_result.html":[5,0,9,49],
 "struct_ogre_1_1_scene_query_result.html#a2224618a99dc451317e56082697b1ffa":[5,0,9,49,0],
 "struct_ogre_1_1_scene_query_result.html#a8157783aec3ca4d9566a9a6bfe08fee0":[5,0,9,49,1],
-"struct_ogre_1_1_shader_helper_cg.html":[7,0,0,696],
-"struct_ogre_1_1_shader_helper_cg.html#a69243683a76bcb33cfa5010199cd8fb5":[7,0,0,696,4],
-"struct_ogre_1_1_shader_helper_cg.html#a74ffb5c45f107f75898169d7db0a4655":[7,0,0,696,0],
-"struct_ogre_1_1_shader_helper_cg.html#a88ad7bc700ad8f31cd8d3816ccc5263c":[7,0,0,696,1],
-"struct_ogre_1_1_shader_helper_cg.html#ace4fceb783350b53587a999a506e23bb":[7,0,0,696,3],
-"struct_ogre_1_1_shader_helper_cg.html#ae0260a80fc0eb977f5ba548f8637f623":[7,0,0,696,2],
-"struct_ogre_1_1_shader_helper_g_l_s_l.html":[7,0,0,697],
-"struct_ogre_1_1_shader_helper_g_l_s_l.html#a5e96572a7623c5d7b0240efe3c83eb7a":[7,0,0,697,0],
-"struct_ogre_1_1_shader_helper_g_l_s_l.html#a69243683a76bcb33cfa5010199cd8fb5":[7,0,0,697,4],
-"struct_ogre_1_1_shader_helper_g_l_s_l.html#a88ad7bc700ad8f31cd8d3816ccc5263c":[7,0,0,697,1],
-"struct_ogre_1_1_shader_helper_g_l_s_l.html#ace4fceb783350b53587a999a506e23bb":[7,0,0,697,3],
-"struct_ogre_1_1_shader_helper_g_l_s_l.html#ae0260a80fc0eb977f5ba548f8637f623":[7,0,0,697,2],
-"struct_ogre_1_1_shadow_texture_config.html":[5,0,9,53],
-"struct_ogre_1_1_shadow_texture_config.html#a0c27fe5c351d3697932ead1893ddf16d":[5,0,9,53,2],
-"struct_ogre_1_1_shadow_texture_config.html#a1572e06277a6253f88d16891a3a8aa25":[5,0,9,53,0],
-"struct_ogre_1_1_shadow_texture_config.html#a7babac3b47c252bb20167395eabaccad":[5,0,9,53,4],
-"struct_ogre_1_1_shadow_texture_config.html#a90f0b94c8b385c5df3cd1b39fd5b0e56":[5,0,9,53,1],
-"struct_ogre_1_1_shadow_texture_config.html#abeaa5079ee032be898755c74bdd6ec10":[5,0,9,53,3],
-"struct_ogre_1_1_shadow_texture_config.html#adff6099049e80aea87663b51d7e3659b":[5,0,9,53,5],
-"struct_ogre_1_1_static_face_group.html":[5,0,9,57],
-"struct_ogre_1_1_static_face_group.html#a09215495af768e8a68b20cf1a937af3a":[5,0,9,57,3],
-"struct_ogre_1_1_static_face_group.html#a11792f9b5cabecab726972024952f157":[5,0,9,57,0],
-"struct_ogre_1_1_static_face_group.html#a2dba19f0f06565cd111206a4a673239c":[5,0,9,57,6],
-"struct_ogre_1_1_static_face_group.html#a3f73219edf1201e9a3c769f9ccc672bf":[5,0,9,57,5],
-"struct_ogre_1_1_static_face_group.html#a42cad07e5dea1a57a10304dcd7b7810b":[5,0,9,57,9],
-"struct_ogre_1_1_static_face_group.html#a4b1e2bb83673099b9d2459a1bb67f429":[5,0,9,57,4],
-"struct_ogre_1_1_static_face_group.html#a5589803da362b70859d96857ba2d88c5":[5,0,9,57,7],
-"struct_ogre_1_1_static_face_group.html#aa58eb0dbf0fdf7e625c80e7dbb0e76f9":[5,0,9,57,2],
-"struct_ogre_1_1_static_face_group.html#abc91f43284e36aa2376f4d54078f0480":[5,0,9,57,1],
-"struct_ogre_1_1_static_face_group.html#ad258e1806394cbd8b2efe7f39d3a7296":[5,0,9,57,8],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html":[5,0,9,58,4],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#a1a9af1b18aec22c5a9f39d487c859a0b":[5,0,9,58,4,2],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#a6ea20308c6c2919a63c24d1273f21f03":[5,0,9,58,4,1],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#ac16c7a7bff4440f883c31c85f7bf7bd2":[5,0,9,58,4,0],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#af13765fe72f89bd33db5feec0beec29b":[5,0,9,58,4,3]
+"struct_ogre_1_1_shader_helper_cg.html":[7,0,0,697],
+"struct_ogre_1_1_shader_helper_cg.html#a69243683a76bcb33cfa5010199cd8fb5":[7,0,0,697,4],
+"struct_ogre_1_1_shader_helper_cg.html#a74ffb5c45f107f75898169d7db0a4655":[7,0,0,697,0],
+"struct_ogre_1_1_shader_helper_cg.html#a88ad7bc700ad8f31cd8d3816ccc5263c":[7,0,0,697,1],
+"struct_ogre_1_1_shader_helper_cg.html#ace4fceb783350b53587a999a506e23bb":[7,0,0,697,3],
+"struct_ogre_1_1_shader_helper_cg.html#ae0260a80fc0eb977f5ba548f8637f623":[7,0,0,697,2],
+"struct_ogre_1_1_shader_helper_g_l_s_l.html":[7,0,0,698],
+"struct_ogre_1_1_shader_helper_g_l_s_l.html#a5e96572a7623c5d7b0240efe3c83eb7a":[7,0,0,698,0],
+"struct_ogre_1_1_shader_helper_g_l_s_l.html#a69243683a76bcb33cfa5010199cd8fb5":[7,0,0,698,4],
+"struct_ogre_1_1_shader_helper_g_l_s_l.html#a88ad7bc700ad8f31cd8d3816ccc5263c":[7,0,0,698,1],
+"struct_ogre_1_1_shader_helper_g_l_s_l.html#ace4fceb783350b53587a999a506e23bb":[7,0,0,698,3]
 };
