@@ -1,5 +1,29 @@
 var NAVTREEINDEX145 =
 {
+"struct_ogre_1_1_shader_helper_g_l_s_l.html#ae0260a80fc0eb977f5ba548f8637f623":[7,0,0,698,2],
+"struct_ogre_1_1_shadow_texture_config.html":[5,0,9,53],
+"struct_ogre_1_1_shadow_texture_config.html#a0c27fe5c351d3697932ead1893ddf16d":[5,0,9,53,2],
+"struct_ogre_1_1_shadow_texture_config.html#a1572e06277a6253f88d16891a3a8aa25":[5,0,9,53,0],
+"struct_ogre_1_1_shadow_texture_config.html#a7babac3b47c252bb20167395eabaccad":[5,0,9,53,4],
+"struct_ogre_1_1_shadow_texture_config.html#a90f0b94c8b385c5df3cd1b39fd5b0e56":[5,0,9,53,1],
+"struct_ogre_1_1_shadow_texture_config.html#abeaa5079ee032be898755c74bdd6ec10":[5,0,9,53,3],
+"struct_ogre_1_1_shadow_texture_config.html#adff6099049e80aea87663b51d7e3659b":[5,0,9,53,5],
+"struct_ogre_1_1_static_face_group.html":[5,0,9,57],
+"struct_ogre_1_1_static_face_group.html#a09215495af768e8a68b20cf1a937af3a":[5,0,9,57,3],
+"struct_ogre_1_1_static_face_group.html#a11792f9b5cabecab726972024952f157":[5,0,9,57,0],
+"struct_ogre_1_1_static_face_group.html#a2dba19f0f06565cd111206a4a673239c":[5,0,9,57,6],
+"struct_ogre_1_1_static_face_group.html#a3f73219edf1201e9a3c769f9ccc672bf":[5,0,9,57,5],
+"struct_ogre_1_1_static_face_group.html#a42cad07e5dea1a57a10304dcd7b7810b":[5,0,9,57,9],
+"struct_ogre_1_1_static_face_group.html#a4b1e2bb83673099b9d2459a1bb67f429":[5,0,9,57,4],
+"struct_ogre_1_1_static_face_group.html#a5589803da362b70859d96857ba2d88c5":[5,0,9,57,7],
+"struct_ogre_1_1_static_face_group.html#aa58eb0dbf0fdf7e625c80e7dbb0e76f9":[5,0,9,57,2],
+"struct_ogre_1_1_static_face_group.html#abc91f43284e36aa2376f4d54078f0480":[5,0,9,57,1],
+"struct_ogre_1_1_static_face_group.html#ad258e1806394cbd8b2efe7f39d3a7296":[5,0,9,57,8],
+"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html":[5,0,9,58,4],
+"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#a1a9af1b18aec22c5a9f39d487c859a0b":[5,0,9,58,4,2],
+"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#a6ea20308c6c2919a63c24d1273f21f03":[5,0,9,58,4,1],
+"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#ac16c7a7bff4440f883c31c85f7bf7bd2":[5,0,9,58,4,0],
+"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#af13765fe72f89bd33db5feec0beec29b":[5,0,9,58,4,3],
 "struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html":[5,0,9,58,5],
 "struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#a641f30e3a07966271a727f113a1ae529":[5,0,9,58,5,4],
 "struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#a6a73cc0fc7d1205b8bddcddf8b5a7ec8":[5,0,9,58,5,0],
@@ -215,39 +239,15 @@ var NAVTREEINDEX145 =
 "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ac3d942ae568cc586e83f0ea4415bad64":[5,0,6,31,10],
 "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#acc9850939655c34aaf332ec311b79068":[5,0,6,31,5],
 "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ad1269630b80565f80da462630bd7d5ad":[5,0,6,31,1],
-"struct_ogre_1_1_vector_set.html":[7,0,0,783],
-"struct_ogre_1_1_vector_set.html#a031182e52c76c98b41e3e6e7bc084a7e":[7,0,0,783,55],
-"struct_ogre_1_1_vector_set.html#a07042d1d8ec08f3055174fc0f386b7ab":[7,0,0,783,1],
-"struct_ogre_1_1_vector_set.html#a08824b7e26c3523829deba7da659b7dc":[7,0,0,783,19],
-"struct_ogre_1_1_vector_set.html#a08f0d82975d336032f922f602ac0f35f":[7,0,0,783,40],
-"struct_ogre_1_1_vector_set.html#a0c2eb072dfec3dd4b21519915f6eea62":[7,0,0,783,41],
-"struct_ogre_1_1_vector_set.html#a1bc36fd4f486783f4a5255e911c4178c":[7,0,0,783,24],
-"struct_ogre_1_1_vector_set.html#a29f4c0677b9a04a1f137adc07be5be3a":[7,0,0,783,54],
-"struct_ogre_1_1_vector_set.html#a30c1c165d5ea9aa46fb67bec11548ade":[7,0,0,783,9],
-"struct_ogre_1_1_vector_set.html#a392fb5f8f5fc3603478b621b8d3972b0":[7,0,0,783,37],
-"struct_ogre_1_1_vector_set.html#a3e4105820c0f20b850e06ce43eadb92f":[7,0,0,783,49],
-"struct_ogre_1_1_vector_set.html#a3e7a18d63d341d3b421bfcd49becebb8":[7,0,0,783,21],
-"struct_ogre_1_1_vector_set.html#a3f415ae6de28aa261e1d160d7577a3f7":[7,0,0,783,5],
-"struct_ogre_1_1_vector_set.html#a40bfd177bea1ec263d342c9973d0721d":[7,0,0,783,30],
-"struct_ogre_1_1_vector_set.html#a44c80d4f7bcd71b7cc02038fd13356de":[7,0,0,783,48],
-"struct_ogre_1_1_vector_set.html#a44df44ffd7810c9f1bdc301fc28fc22b":[7,0,0,783,32],
-"struct_ogre_1_1_vector_set.html#a47551a30a8aa43cc51650f69e7eb35bf":[7,0,0,783,12],
-"struct_ogre_1_1_vector_set.html#a4b86aea9ff25e7749483c2431e02db41":[7,0,0,783,3],
-"struct_ogre_1_1_vector_set.html#a4b9389769eb5d2244297e13bea92205f":[7,0,0,783,11],
-"struct_ogre_1_1_vector_set.html#a4df1045f716602fb6718df3dda8c2187":[7,0,0,783,31],
-"struct_ogre_1_1_vector_set.html#a4e98041c1a76abf808becf450f43e5c7":[7,0,0,783,42],
-"struct_ogre_1_1_vector_set.html#a53872aabbaa3c28ff90c0fdd4458f101":[7,0,0,783,34],
-"struct_ogre_1_1_vector_set.html#a5958110a680cbacf2fa7de13c596505f":[7,0,0,783,38],
-"struct_ogre_1_1_vector_set.html#a60eb6558693ab2020fba03c8ea5038c5":[7,0,0,783,2],
-"struct_ogre_1_1_vector_set.html#a615a2a0b15043d64f5ccd8aeb938b021":[7,0,0,783,17],
-"struct_ogre_1_1_vector_set.html#a67f552cb7d9bf5fa06ba95d24e124949":[7,0,0,783,22],
-"struct_ogre_1_1_vector_set.html#a69fe902553d7da5e96a8b74df3714e22":[7,0,0,783,14],
-"struct_ogre_1_1_vector_set.html#a6f3019eb35333a8ca4e10f14923298d4":[7,0,0,783,43],
-"struct_ogre_1_1_vector_set.html#a7049c5387498c49d046222cf2ce9e16c":[7,0,0,783,13],
-"struct_ogre_1_1_vector_set.html#a726e02e5ed3fb393ddab4970b92e3906":[7,0,0,783,50],
-"struct_ogre_1_1_vector_set.html#a72a6de6e4343bb9c090400aa05edc234":[7,0,0,783,39],
-"struct_ogre_1_1_vector_set.html#a7f0236907f0642a16747cdbd9a5418c0":[7,0,0,783,15],
-"struct_ogre_1_1_vector_set.html#a7f6c13429c1adbcbcddbf33a5a8b3fe8":[7,0,0,783,59],
-"struct_ogre_1_1_vector_set.html#a81cd6f176685ef34fe34dec50991ef2e":[7,0,0,783,26],
-"struct_ogre_1_1_vector_set.html#a87ee5ad0c88dbd163e58835d7990ef32":[7,0,0,783,46]
+"struct_ogre_1_1_vector_set.html":[7,0,0,784],
+"struct_ogre_1_1_vector_set.html#a031182e52c76c98b41e3e6e7bc084a7e":[7,0,0,784,55],
+"struct_ogre_1_1_vector_set.html#a07042d1d8ec08f3055174fc0f386b7ab":[7,0,0,784,1],
+"struct_ogre_1_1_vector_set.html#a08824b7e26c3523829deba7da659b7dc":[7,0,0,784,19],
+"struct_ogre_1_1_vector_set.html#a08f0d82975d336032f922f602ac0f35f":[7,0,0,784,40],
+"struct_ogre_1_1_vector_set.html#a0c2eb072dfec3dd4b21519915f6eea62":[7,0,0,784,41],
+"struct_ogre_1_1_vector_set.html#a1bc36fd4f486783f4a5255e911c4178c":[7,0,0,784,24],
+"struct_ogre_1_1_vector_set.html#a29f4c0677b9a04a1f137adc07be5be3a":[7,0,0,784,54],
+"struct_ogre_1_1_vector_set.html#a30c1c165d5ea9aa46fb67bec11548ade":[7,0,0,784,9],
+"struct_ogre_1_1_vector_set.html#a392fb5f8f5fc3603478b621b8d3972b0":[7,0,0,784,37],
+"struct_ogre_1_1_vector_set.html#a3e4105820c0f20b850e06ce43eadb92f":[7,0,0,784,49]
 };
