@@ -1,5 +1,6 @@
 var NAVTREEINDEX15 =
 {
+"class_ogre_1_1_billboard_chain.html#a2b5b86e082a44769ae96ec2e48930b90":[5,0,1,1,44],
 "class_ogre_1_1_billboard_chain.html#a2cc6be9f51e010a4977afdc5a7dff5cb":[5,0,1,1,108],
 "class_ogre_1_1_billboard_chain.html#a2d718f6ed0b708495cc2a31eb653ad84":[5,0,1,1,103],
 "class_ogre_1_1_billboard_chain.html#a2eb94fea5944cf0d33702a75cfa14a74":[5,0,1,1,87],
@@ -248,6 +249,5 @@ var NAVTREEINDEX15 =
 "class_ogre_1_1_billboard_set.html#a472c926a6d05d05752fc195c8d606a85":[5,0,1,5,155],
 "class_ogre_1_1_billboard_set.html#a47508d27a6c799998047c50ec43e9897":[5,0,1,5,139],
 "class_ogre_1_1_billboard_set.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7":[5,0,1,5,93],
-"class_ogre_1_1_billboard_set.html#a4ed9ff92bf8c72f9ace52e823553ef7b":[5,0,1,5,23],
-"class_ogre_1_1_billboard_set.html#a4fbc0296b902a113376688aff724d02d":[5,0,1,5,117]
+"class_ogre_1_1_billboard_set.html#a4ed9ff92bf8c72f9ace52e823553ef7b":[5,0,1,5,23]
 };
