@@ -1,5 +1,6 @@
 var NAVTREEINDEX16 =
 {
+"class_ogre_1_1_billboard_set.html#a4fbc0296b902a113376688aff724d02d":[5,0,1,5,117],
 "class_ogre_1_1_billboard_set.html#a504e2192036f75007c51e157315e1548":[5,0,1,5,111],
 "class_ogre_1_1_billboard_set.html#a51eb7d8dea98e3187ca216a4d6ca8487":[5,0,1,5,78],
 "class_ogre_1_1_billboard_set.html#a5456ecd630d55c91b2fd1b19969d29f5":[5,0,1,5,119],
@@ -248,6 +249,5 @@ var NAVTREEINDEX16 =
 "class_ogre_1_1_border_panel_overlay_element.html#a0d5508d74e0d742ed04ba5ba6c1a7113":[5,1,3,1,108],
 "class_ogre_1_1_border_panel_overlay_element.html#a0e3fe5ec8406c5824cd4e4fa25f9e783":[5,1,3,1,127],
 "class_ogre_1_1_border_panel_overlay_element.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,1,3,1,136],
-"class_ogre_1_1_border_panel_overlay_element.html#a142c71975a49dc2712e71b7a15bb6ad6":[5,1,3,1,76],
-"class_ogre_1_1_border_panel_overlay_element.html#a149ed9dba547535540a515c0936cc1f2":[5,1,3,1,112]
+"class_ogre_1_1_border_panel_overlay_element.html#a142c71975a49dc2712e71b7a15bb6ad6":[5,1,3,1,76]
 };
