@@ -1,5 +1,6 @@
 var NAVTREEINDEX17 =
 {
+"class_ogre_1_1_border_panel_overlay_element.html#a149ed9dba547535540a515c0936cc1f2":[5,1,3,1,112],
 "class_ogre_1_1_border_panel_overlay_element.html#a14e63d4c3d587b01ea94904a9e4d1c6b":[5,1,3,1,88],
 "class_ogre_1_1_border_panel_overlay_element.html#a153af53d919497af7340413866470613":[5,1,3,1,84],
 "class_ogre_1_1_border_panel_overlay_element.html#a1548c9c20d0c4e4ff2c73590681dbddb":[5,1,3,1,106],
@@ -248,6 +249,5 @@ var NAVTREEINDEX17 =
 "class_ogre_1_1_box_emitter.html#a595cb72cb60c6566bee7204ef7d92ebd":[5,2,6,1,16],
 "class_ogre_1_1_box_emitter.html#a5aef511f7bcbada271780f42ccfe717e":[5,2,6,1,96],
 "class_ogre_1_1_box_emitter.html#a5b7e2e8dd8e695736a1038588c382fbe":[5,2,6,1,31],
-"class_ogre_1_1_box_emitter.html#a64d38a64642017c5ca73213b129aa8d8":[5,2,6,1,69],
-"class_ogre_1_1_box_emitter.html#a659edec094aae09a7f1325e7e8fbc29a":[5,2,6,1,23]
+"class_ogre_1_1_box_emitter.html#a64d38a64642017c5ca73213b129aa8d8":[5,2,6,1,69]
 };
