@@ -1,5 +1,6 @@
 var NAVTREEINDEX18 =
 {
+"class_ogre_1_1_box_emitter.html#a659edec094aae09a7f1325e7e8fbc29a":[5,2,6,1,23],
 "class_ogre_1_1_box_emitter.html#a6607b5a35ab594e8e5e01df766cd5462":[5,2,6,1,37],
 "class_ogre_1_1_box_emitter.html#a666a8c8c660ffc55ff338b59a416f682":[5,2,6,1,43],
 "class_ogre_1_1_box_emitter.html#a674566db12d25f32513a382a4118b5da":[5,2,6,1,42],
@@ -248,6 +249,5 @@ var NAVTREEINDEX18 =
 "class_ogre_1_1_bsp_scene_manager.html#a260738557c9a32aed8d5ca14c28d300f":[5,2,0,5,1],
 "class_ogre_1_1_bsp_scene_manager.html#a272d1a76e7854e51f824f0099a4910cf":[5,2,0,5,300],
 "class_ogre_1_1_bsp_scene_manager.html#a29772b72321f0f9ffc7f2fb0b46bcbad":[5,2,0,5,65],
-"class_ogre_1_1_bsp_scene_manager.html#a29ba8a2cad151d307d04781f749e7e84":[5,2,0,5,113],
-"class_ogre_1_1_bsp_scene_manager.html#a2a86925fa4cbbb667f29473d5fd4a4c2":[5,2,0,5,159]
+"class_ogre_1_1_bsp_scene_manager.html#a29ba8a2cad151d307d04781f749e7e84":[5,2,0,5,113]
 };
