@@ -1,5 +1,6 @@
 var NAVTREEINDEX20 =
 {
+"class_ogre_1_1_bsp_scene_manager.html#aea949bdea7d1547fe4316af3579b836e":[5,2,0,5,81],
 "class_ogre_1_1_bsp_scene_manager.html#aeaff7cf546903bc22c4113c1ae4a7ee4":[5,2,0,5,137],
 "class_ogre_1_1_bsp_scene_manager.html#aebb644c23f059b8bfa3702356d19c6be":[5,2,0,5,118],
 "class_ogre_1_1_bsp_scene_manager.html#aec115af3cb3741397c4bdbf468cb010b":[5,2,0,5,88],
@@ -248,6 +249,5 @@ var NAVTREEINDEX20 =
 "class_ogre_1_1_camera.html#a4d5b3cac0c09c3cc37e36a957dcc7797":[5,0,9,2,22],
 "class_ogre_1_1_camera.html#a4fbc0296b902a113376688aff724d02d":[5,0,9,2,195],
 "class_ogre_1_1_camera.html#a4fe3e4231262486405e531f58ed96866":[5,0,9,2,34],
-"class_ogre_1_1_camera.html#a504e2192036f75007c51e157315e1548":[5,0,9,2,189],
-"class_ogre_1_1_camera.html#a51eb7d8dea98e3187ca216a4d6ca8487":[5,0,9,2,153]
+"class_ogre_1_1_camera.html#a504e2192036f75007c51e157315e1548":[5,0,9,2,189]
 };
