@@ -1,5 +1,6 @@
 var NAVTREEINDEX22 =
 {
+"class_ogre_1_1_cg_program.html#a827096909b3c5ef1ff46b880e1606b76":[5,2,1,1,32],
 "class_ogre_1_1_cg_program.html#a843c706f65d219c1d04b8aeacc4bd3c8":[5,2,1,1,43],
 "class_ogre_1_1_cg_program.html#a848bf4164963cf8c0435c972eb717e0f":[5,2,1,1,44],
 "class_ogre_1_1_cg_program.html#a84c3904bfaeeb1166dbca41e0c9f3b29":[5,2,1,1,49],
@@ -248,6 +249,5 @@ var NAVTREEINDEX22 =
 "class_ogre_1_1_colour_value.html#a13fbd050af26b8bd549ccb46aa699e07":[5,0,2,9,39],
 "class_ogre_1_1_colour_value.html#a14d1ddd5186e7322466ea3d9c89c3f9d":[5,0,2,9,18],
 "class_ogre_1_1_colour_value.html#a170729634175d1cea8bd8c882bdde71e":[5,0,2,9,5],
-"class_ogre_1_1_colour_value.html#a1cf6b673afb17fe889e4255a938c3cbb":[5,0,2,9,6],
-"class_ogre_1_1_colour_value.html#a21875c1d92c3ad0cba9cafd5776f42a0":[5,0,2,9,11]
+"class_ogre_1_1_colour_value.html#a1cf6b673afb17fe889e4255a938c3cbb":[5,0,2,9,6]
 };
