@@ -1,5 +1,6 @@
 var NAVTREEINDEX23 =
 {
+"class_ogre_1_1_colour_value.html#a21875c1d92c3ad0cba9cafd5776f42a0":[5,0,2,9,11],
 "class_ogre_1_1_colour_value.html#a27b26fbfa1098376c47e337192d04f27":[5,0,2,9,4],
 "class_ogre_1_1_colour_value.html#a3595487122e676dae5786151b169e213":[5,0,2,9,8],
 "class_ogre_1_1_colour_value.html#a3d17eedbff96cef8dbd4414183e15cb3":[5,0,2,9,26],
@@ -248,6 +249,5 @@ var NAVTREEINDEX23 =
 "class_ogre_1_1_compositor.html#a66446a9477813c7aba01f7f5792539da":[5,0,1,10,6],
 "class_ogre_1_1_compositor.html#a699d1c851f494a8d5d23d23b695ceb47":[5,0,1,10,20],
 "class_ogre_1_1_compositor.html#a6aad43a583eb72dc24b479b3138c7277":[5,0,1,10,16],
-"class_ogre_1_1_compositor.html#a74138c0203835513613af73cdb08890d":[5,0,1,10,30],
-"class_ogre_1_1_compositor.html#a78ac5745673e6e9f44a866ef016710cd":[5,0,1,10,5]
+"class_ogre_1_1_compositor.html#a74138c0203835513613af73cdb08890d":[5,0,1,10,30]
 };
