@@ -1,5 +1,6 @@
 var NAVTREEINDEX24 =
 {
+"class_ogre_1_1_compositor.html#a78ac5745673e6e9f44a866ef016710cd":[5,0,1,10,5],
 "class_ogre_1_1_compositor.html#a792451bc7c47f826ce03538b4060a527":[5,0,1,10,17],
 "class_ogre_1_1_compositor.html#a7e248a1cca0662418d4ab3f63c2e7cf6":[5,0,1,10,42],
 "class_ogre_1_1_compositor.html#a8eb34a9034aab62fd537c021a79e3366":[5,0,1,10,22],
@@ -248,6 +249,5 @@ var NAVTREEINDEX24 =
 "class_ogre_1_1_const_vector_iterator.html#adc1cbc2e629b20b8a959646eddb720c5":[7,0,0,92,6],
 "class_ogre_1_1_controller.html":[5,0,2,15],
 "class_ogre_1_1_controller.html#a3fb917fd69fdc9d6799913970039652b":[5,0,2,15,0],
-"class_ogre_1_1_controller.html#a4b16ce7b5a436c3f895bea7960bdcb07":[5,0,2,15,10],
-"class_ogre_1_1_controller.html#a5432e56160bfd643bdcc0348ad191e11":[5,0,2,15,2]
+"class_ogre_1_1_controller.html#a4b16ce7b5a436c3f895bea7960bdcb07":[5,0,2,15,10]
 };
