@@ -1,5 +1,6 @@
 var NAVTREEINDEX25 =
 {
+"class_ogre_1_1_controller.html#a5432e56160bfd643bdcc0348ad191e11":[5,0,2,15,2],
 "class_ogre_1_1_controller.html#a677899554232e1380c6fed84e27a0120":[5,0,2,15,6],
 "class_ogre_1_1_controller.html#a69ed3f511be30a83b2cb353d6b401c45":[5,0,2,15,5],
 "class_ogre_1_1_controller.html#a780a6566e4af4b23e760863f3de02028":[5,0,2,15,7],
@@ -248,6 +249,5 @@ var NAVTREEINDEX25 =
 "class_ogre_1_1_d3_d11_device.html":[7,0,0,109],
 "class_ogre_1_1_d3_d11_device.html#a0795f202077b6d65db6f0eb208d17213":[7,0,0,109,1],
 "class_ogre_1_1_d3_d11_device.html#a0c0587b80f6c468b5b21bd46832eb755":[7,0,0,109,2],
-"class_ogre_1_1_d3_d11_device.html#a10e2175b80344a1a481588f1306a01a1":[7,0,0,109,23],
-"class_ogre_1_1_d3_d11_device.html#a14b403c6913876281b89a8304256db11":[7,0,0,109,6]
+"class_ogre_1_1_d3_d11_device.html#a10e2175b80344a1a481588f1306a01a1":[7,0,0,109,23]
 };
