@@ -1,5 +1,6 @@
 var NAVTREEINDEX26 =
 {
+"class_ogre_1_1_d3_d11_device.html#a14b403c6913876281b89a8304256db11":[7,0,0,109,6],
 "class_ogre_1_1_d3_d11_device.html#a159a829700006ea04b00b6fdd355c797":[7,0,0,109,16],
 "class_ogre_1_1_d3_d11_device.html#a23a2c2821e100a2330ece16e8b1a1791":[7,0,0,109,13],
 "class_ogre_1_1_d3_d11_device.html#a2624f7e7b7dcba2d0cf183df824b8f3f":[7,0,0,109,17],
@@ -248,6 +249,5 @@ var NAVTREEINDEX26 =
 "class_ogre_1_1_d3_d11_hardware_buffer_manager.html#a37ea5e1e281a95e180c930e8b5f68366":[7,0,0,115,4],
 "class_ogre_1_1_d3_d11_hardware_buffer_manager.html#a380063fef4a4563c90d45a03ac196dc7":[7,0,0,115,9],
 "class_ogre_1_1_d3_d11_hardware_buffer_manager.html#a3f4c7f49c287f4b9be96fe55393d7f5c":[7,0,0,115,3],
-"class_ogre_1_1_d3_d11_hardware_buffer_manager.html#a45fe3ad0964310d9b150d45eaddf67d3":[7,0,0,115,26],
-"class_ogre_1_1_d3_d11_hardware_buffer_manager.html#a4c952da88aa1bba59c607fee6207ec7a":[7,0,0,115,2]
+"class_ogre_1_1_d3_d11_hardware_buffer_manager.html#a45fe3ad0964310d9b150d45eaddf67d3":[7,0,0,115,26]
 };
