@@ -1,99 +1,117 @@
 var NAVTREEINDEX37 =
 {
-"class_ogre_1_1_d3_d9_texture_manager.html#a6d9424ed93bc679b5543ddc9fc9fe41b":[7,0,0,170,3],
-"class_ogre_1_1_d3_d9_texture_manager.html#a6f62363053ac50af65f3762c4f1cc498":[7,0,0,170,7],
-"class_ogre_1_1_d3_d9_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[7,0,0,170,52],
-"class_ogre_1_1_d3_d9_texture_manager.html#a700088a63eabb0f6cb1fac96686db464":[7,0,0,170,37],
-"class_ogre_1_1_d3_d9_texture_manager.html#a711218e2968d7e52b1114cced356c8e8":[7,0,0,170,34],
-"class_ogre_1_1_d3_d9_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[7,0,0,170,26],
-"class_ogre_1_1_d3_d9_texture_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,170,70],
-"class_ogre_1_1_d3_d9_texture_manager.html#a82b76280229c498b8d66f64b2a848447":[7,0,0,170,65],
-"class_ogre_1_1_d3_d9_texture_manager.html#a849d25862f43feec07252f0ae139c3e4":[7,0,0,170,1],
-"class_ogre_1_1_d3_d9_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[7,0,0,170,46],
-"class_ogre_1_1_d3_d9_texture_manager.html#a91734962d27d948eaa9ce6dac0b771a6":[7,0,0,170,12],
-"class_ogre_1_1_d3_d9_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[7,0,0,170,44],
-"class_ogre_1_1_d3_d9_texture_manager.html#a9ef8419603b3aad6ce7545682ee12c7c":[7,0,0,170,33],
-"class_ogre_1_1_d3_d9_texture_manager.html#aa5effb36ddd157b7b137cccd120ea55a":[7,0,0,170,16],
-"class_ogre_1_1_d3_d9_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[7,0,0,170,68],
-"class_ogre_1_1_d3_d9_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[7,0,0,170,45],
-"class_ogre_1_1_d3_d9_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[7,0,0,170,24],
-"class_ogre_1_1_d3_d9_texture_manager.html#aac423b67b8c1aa00cd6a3f91e73bfcec":[7,0,0,170,23],
-"class_ogre_1_1_d3_d9_texture_manager.html#aacb0663130a096fcf49e5dbedbcca92c":[7,0,0,170,10],
-"class_ogre_1_1_d3_d9_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[7,0,0,170,20],
-"class_ogre_1_1_d3_d9_texture_manager.html#aafa494d2704fdff05708db9db4bac3a0":[7,0,0,170,22],
-"class_ogre_1_1_d3_d9_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[7,0,0,170,55],
-"class_ogre_1_1_d3_d9_texture_manager.html#ab3d834cb2b240988c4fa8663763e444c":[7,0,0,170,6],
-"class_ogre_1_1_d3_d9_texture_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[7,0,0,170,72],
-"class_ogre_1_1_d3_d9_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[7,0,0,170,30],
-"class_ogre_1_1_d3_d9_texture_manager.html#abc20acc2d57fd224b218a07d802e8c1a":[7,0,0,170,64],
-"class_ogre_1_1_d3_d9_texture_manager.html#abd807a5a8f5754af45fc60db40b455d5":[7,0,0,170,39],
-"class_ogre_1_1_d3_d9_texture_manager.html#ac380e4c615bcd2546bf961354f4ebda2":[7,0,0,170,5],
-"class_ogre_1_1_d3_d9_texture_manager.html#ac3f365e1d71fbe328637a681171d7acd":[7,0,0,170,14],
-"class_ogre_1_1_d3_d9_texture_manager.html#ac3f365e1d71fbe328637a681171d7acd":[7,0,0,170,15],
-"class_ogre_1_1_d3_d9_texture_manager.html#ac401b57afcc205728a3821065aef6238":[7,0,0,170,40],
-"class_ogre_1_1_d3_d9_texture_manager.html#ac6fb858ee86f3b7b75de32e3e04ee5c8":[7,0,0,170,35],
-"class_ogre_1_1_d3_d9_texture_manager.html#ad18cc3f0a4b3e0553cfe715204f15359":[7,0,0,170,67],
-"class_ogre_1_1_d3_d9_texture_manager.html#ae071093e2681923ddf1d661087b44e4d":[7,0,0,170,66],
-"class_ogre_1_1_d3_d9_texture_manager.html#ae63b06c1fd6d1266b4c5dacc35e521b4":[7,0,0,170,11],
-"class_ogre_1_1_d3_d9_texture_manager.html#aea812804e59454cd29ee531ebab56b1b":[7,0,0,170,50],
-"class_ogre_1_1_d3_d9_texture_manager.html#aeaa1410333b7bcea14b00c360112a528":[7,0,0,170,47],
-"class_ogre_1_1_d3_d9_texture_manager.html#aec8fc8fae795d7410867f72f00813c79":[7,0,0,170,31],
-"class_ogre_1_1_d3_d9_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[7,0,0,170,59],
-"class_ogre_1_1_d3_d9_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[7,0,0,170,28],
-"class_ogre_1_1_d3_d9_texture_manager.html#af30b8543978558d0a083778790f1fab2":[7,0,0,170,32],
-"class_ogre_1_1_d3_d9_texture_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[7,0,0,170,0],
-"class_ogre_1_1_d3_d9_vertex_declaration.html":[7,0,0,171],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a1049733c9da2b8a49590b1f942c1b4ae":[7,0,0,171,26],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a12fad67983499876ffe66bc087cd7d0b":[7,0,0,171,17],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a130fa715330d23d0e9d2feef630b460c":[7,0,0,171,12],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a1bc75972c04228ebf539e242d57b7203":[7,0,0,171,7],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a260ecb704cfc32b82f248e382a53be47":[7,0,0,171,11],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a3c1091f7ece9bbc4e4f847484fd75a37":[7,0,0,171,24],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a3c71e39ce3fe6007e797744c8ef2f339":[7,0,0,171,19],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a43113eabfb0d8a80a79a8c7413ad139c":[7,0,0,171,16],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a469bd849411d3f152d700772fab64501":[7,0,0,171,20],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a4f99e40285b5c122843b681477983ab1":[7,0,0,171,23],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a5a91d9a841eca45392494b2444968029":[7,0,0,171,4],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a60080b97acb5b645bf3524152d75cc5d":[7,0,0,171,0],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a670466fe9bcfc426ccefb5395a3a82ef":[7,0,0,171,6],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a69505e015a422c94a15831fdfbf87770":[7,0,0,171,18],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a6e35239737da934f62f69fad4c3bd290":[7,0,0,171,2],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a6fc9c0ebe4a4c559b172f25f3b5dc9d8":[7,0,0,171,30],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a842f42e52d16d44819abb342fc182cad":[7,0,0,171,1],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a8b1a5f5fe0b7306da4c8b17357d45fac":[7,0,0,171,14],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a8d55f1d5ce61a1b796d8d86dd3c69fdb":[7,0,0,171,27],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a9008da922e8b8762ac284cc1f08a0749":[7,0,0,171,28],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a9673b478f78c55754cf410b223c5a06a":[7,0,0,171,8],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a98cce285a45ba6f4cf817dcf46bfb588":[7,0,0,171,10],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#aa6da7c9f1902145e0725e348cb522699":[7,0,0,171,5],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#aa8323ecd73a854f8c72fd6ac2618e3ee":[7,0,0,171,25],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#aa97afae987b0c0f16c3e232a7317fad5":[7,0,0,171,29],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#ad34cfa2c7ebdadfb5101ce751e6ab039":[7,0,0,171,22],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#ada92fbc9ee87b04f8a3c389c71904ce6":[7,0,0,171,21],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#adb0dd4e0b21379635c0c54f37ef90e1d":[7,0,0,171,15],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#ae8e81e6e6209774c203a0edf44032e65":[7,0,0,171,13],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#aed9f1ba13a68148ce730fafdb4834ba5":[7,0,0,171,9],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#afe9b5394456063cae5b95d512cc54cc0":[7,0,0,171,3],
-"class_ogre_1_1_d3_d9_video_mode.html":[7,0,0,172],
-"class_ogre_1_1_d3_d9_video_mode.html#a055a751c6ab62e8f68f55d34d074f4b9":[7,0,0,172,11],
-"class_ogre_1_1_d3_d9_video_mode.html#a2993d0fefdcad771e9649e5283d85270":[7,0,0,172,5],
-"class_ogre_1_1_d3_d9_video_mode.html#a3092cd96e44807a629e3ac45f05c683c":[7,0,0,172,1],
-"class_ogre_1_1_d3_d9_video_mode.html#a327c0921f5f515d59b9f01de46e08b88":[7,0,0,172,8],
-"class_ogre_1_1_d3_d9_video_mode.html#a349726fc8e0cf1e82dba2c831dc8bc0c":[7,0,0,172,6],
-"class_ogre_1_1_d3_d9_video_mode.html#a34a77a0c52fb29311ec6181ac8bee754":[7,0,0,172,0],
-"class_ogre_1_1_d3_d9_video_mode.html#a3f7dd41242c7c00188aad2e8489f41b8":[7,0,0,172,7],
-"class_ogre_1_1_d3_d9_video_mode.html#a4024d30689e34f0c9022cef516405028":[7,0,0,172,9],
-"class_ogre_1_1_d3_d9_video_mode.html#a70e53fa440e95ed17b85015a1e5643a6":[7,0,0,172,4],
-"class_ogre_1_1_d3_d9_video_mode.html#a84bc6e2cc34253b99afc560176038b4c":[7,0,0,172,10],
-"class_ogre_1_1_d3_d9_video_mode.html#ac4d2913efac422ca4a93ab0771373431":[7,0,0,172,2],
-"class_ogre_1_1_d3_d9_video_mode.html#af819f89d3ecd9236d1c0f9f91a71d0ba":[7,0,0,172,3],
-"class_ogre_1_1_d3_d9_video_mode_list.html":[7,0,0,173],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a0f4081d0603745659096c636a4e63b2c":[7,0,0,173,5],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a2cd7b9abf98533d646fcbe3c74b370e4":[7,0,0,173,2],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a413ec33c53b844739d33dadc357d45b0":[7,0,0,173,4],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a537516c036db7310614aa3011325f8db":[7,0,0,173,1],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a5bd29e9754803f1e0ae73ddefd24f170":[7,0,0,173,3],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a80ca3ca66b3445380b26aa3bb35ff990":[7,0,0,173,0],
+"class_ogre_1_1_d3_d9_texture_manager.html#a3a55789d982b34bdd9daa27650360653":[7,0,0,171,36],
+"class_ogre_1_1_d3_d9_texture_manager.html#a3ae7c3ae5494fc088fa8a17e736fef6b":[7,0,0,171,63],
+"class_ogre_1_1_d3_d9_texture_manager.html#a3fdbd35468f69e6f6662bae7ec84af21":[7,0,0,171,56],
+"class_ogre_1_1_d3_d9_texture_manager.html#a406e3deba98785c0183d9e87271078d2":[7,0,0,171,13],
+"class_ogre_1_1_d3_d9_texture_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,171,58],
+"class_ogre_1_1_d3_d9_texture_manager.html#a4173c940f4c67e8a2dc1a5c4b6de62f6":[7,0,0,171,8],
+"class_ogre_1_1_d3_d9_texture_manager.html#a4350b30d83790f208a9fdd1197ce9c95":[7,0,0,171,17],
+"class_ogre_1_1_d3_d9_texture_manager.html#a49a47b8919269342243265df3bd1e1fc":[7,0,0,171,25],
+"class_ogre_1_1_d3_d9_texture_manager.html#a4d3289d4636168230da11c1c9794db59":[7,0,0,171,71],
+"class_ogre_1_1_d3_d9_texture_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[7,0,0,171,48],
+"class_ogre_1_1_d3_d9_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[7,0,0,171,4],
+"class_ogre_1_1_d3_d9_texture_manager.html#a532e96fbeac065b4a7866b4302a90618":[7,0,0,171,38],
+"class_ogre_1_1_d3_d9_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[7,0,0,171,60],
+"class_ogre_1_1_d3_d9_texture_manager.html#a62ddf3760bd9871b25ca016732e149d1":[7,0,0,171,41],
+"class_ogre_1_1_d3_d9_texture_manager.html#a65730ea50a81401518b4cbf6bb6a0a73":[7,0,0,171,29],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6871e913a62e1b419438e3169bc72bd3":[7,0,0,171,51],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6a58b96feb67c25e123ccc3b287fcd2c":[7,0,0,171,57],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[7,0,0,171,53],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6d9424ed93bc679b5543ddc9fc9fe41b":[7,0,0,171,3],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6f62363053ac50af65f3762c4f1cc498":[7,0,0,171,7],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[7,0,0,171,52],
+"class_ogre_1_1_d3_d9_texture_manager.html#a700088a63eabb0f6cb1fac96686db464":[7,0,0,171,37],
+"class_ogre_1_1_d3_d9_texture_manager.html#a711218e2968d7e52b1114cced356c8e8":[7,0,0,171,34],
+"class_ogre_1_1_d3_d9_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[7,0,0,171,26],
+"class_ogre_1_1_d3_d9_texture_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,171,70],
+"class_ogre_1_1_d3_d9_texture_manager.html#a82b76280229c498b8d66f64b2a848447":[7,0,0,171,65],
+"class_ogre_1_1_d3_d9_texture_manager.html#a849d25862f43feec07252f0ae139c3e4":[7,0,0,171,1],
+"class_ogre_1_1_d3_d9_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[7,0,0,171,46],
+"class_ogre_1_1_d3_d9_texture_manager.html#a91734962d27d948eaa9ce6dac0b771a6":[7,0,0,171,12],
+"class_ogre_1_1_d3_d9_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[7,0,0,171,44],
+"class_ogre_1_1_d3_d9_texture_manager.html#a9ef8419603b3aad6ce7545682ee12c7c":[7,0,0,171,33],
+"class_ogre_1_1_d3_d9_texture_manager.html#aa5effb36ddd157b7b137cccd120ea55a":[7,0,0,171,16],
+"class_ogre_1_1_d3_d9_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[7,0,0,171,68],
+"class_ogre_1_1_d3_d9_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[7,0,0,171,45],
+"class_ogre_1_1_d3_d9_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[7,0,0,171,24],
+"class_ogre_1_1_d3_d9_texture_manager.html#aac423b67b8c1aa00cd6a3f91e73bfcec":[7,0,0,171,23],
+"class_ogre_1_1_d3_d9_texture_manager.html#aacb0663130a096fcf49e5dbedbcca92c":[7,0,0,171,10],
+"class_ogre_1_1_d3_d9_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[7,0,0,171,20],
+"class_ogre_1_1_d3_d9_texture_manager.html#aafa494d2704fdff05708db9db4bac3a0":[7,0,0,171,22],
+"class_ogre_1_1_d3_d9_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[7,0,0,171,55],
+"class_ogre_1_1_d3_d9_texture_manager.html#ab3d834cb2b240988c4fa8663763e444c":[7,0,0,171,6],
+"class_ogre_1_1_d3_d9_texture_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[7,0,0,171,72],
+"class_ogre_1_1_d3_d9_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[7,0,0,171,30],
+"class_ogre_1_1_d3_d9_texture_manager.html#abc20acc2d57fd224b218a07d802e8c1a":[7,0,0,171,64],
+"class_ogre_1_1_d3_d9_texture_manager.html#abd807a5a8f5754af45fc60db40b455d5":[7,0,0,171,39],
+"class_ogre_1_1_d3_d9_texture_manager.html#ac380e4c615bcd2546bf961354f4ebda2":[7,0,0,171,5],
+"class_ogre_1_1_d3_d9_texture_manager.html#ac3f365e1d71fbe328637a681171d7acd":[7,0,0,171,14],
+"class_ogre_1_1_d3_d9_texture_manager.html#ac3f365e1d71fbe328637a681171d7acd":[7,0,0,171,15],
+"class_ogre_1_1_d3_d9_texture_manager.html#ac401b57afcc205728a3821065aef6238":[7,0,0,171,40],
+"class_ogre_1_1_d3_d9_texture_manager.html#ac6fb858ee86f3b7b75de32e3e04ee5c8":[7,0,0,171,35],
+"class_ogre_1_1_d3_d9_texture_manager.html#ad18cc3f0a4b3e0553cfe715204f15359":[7,0,0,171,67],
+"class_ogre_1_1_d3_d9_texture_manager.html#ae071093e2681923ddf1d661087b44e4d":[7,0,0,171,66],
+"class_ogre_1_1_d3_d9_texture_manager.html#ae63b06c1fd6d1266b4c5dacc35e521b4":[7,0,0,171,11],
+"class_ogre_1_1_d3_d9_texture_manager.html#aea812804e59454cd29ee531ebab56b1b":[7,0,0,171,50],
+"class_ogre_1_1_d3_d9_texture_manager.html#aeaa1410333b7bcea14b00c360112a528":[7,0,0,171,47],
+"class_ogre_1_1_d3_d9_texture_manager.html#aec8fc8fae795d7410867f72f00813c79":[7,0,0,171,31],
+"class_ogre_1_1_d3_d9_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[7,0,0,171,59],
+"class_ogre_1_1_d3_d9_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[7,0,0,171,28],
+"class_ogre_1_1_d3_d9_texture_manager.html#af30b8543978558d0a083778790f1fab2":[7,0,0,171,32],
+"class_ogre_1_1_d3_d9_texture_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[7,0,0,171,0],
+"class_ogre_1_1_d3_d9_vertex_declaration.html":[7,0,0,172],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a1049733c9da2b8a49590b1f942c1b4ae":[7,0,0,172,26],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a12fad67983499876ffe66bc087cd7d0b":[7,0,0,172,17],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a130fa715330d23d0e9d2feef630b460c":[7,0,0,172,12],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a1bc75972c04228ebf539e242d57b7203":[7,0,0,172,7],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a260ecb704cfc32b82f248e382a53be47":[7,0,0,172,11],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a3c1091f7ece9bbc4e4f847484fd75a37":[7,0,0,172,24],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a3c71e39ce3fe6007e797744c8ef2f339":[7,0,0,172,19],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a43113eabfb0d8a80a79a8c7413ad139c":[7,0,0,172,16],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a469bd849411d3f152d700772fab64501":[7,0,0,172,20],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a4f99e40285b5c122843b681477983ab1":[7,0,0,172,23],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a5a91d9a841eca45392494b2444968029":[7,0,0,172,4],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a60080b97acb5b645bf3524152d75cc5d":[7,0,0,172,0],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a670466fe9bcfc426ccefb5395a3a82ef":[7,0,0,172,6],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a69505e015a422c94a15831fdfbf87770":[7,0,0,172,18],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a6e35239737da934f62f69fad4c3bd290":[7,0,0,172,2],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a6fc9c0ebe4a4c559b172f25f3b5dc9d8":[7,0,0,172,30],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a842f42e52d16d44819abb342fc182cad":[7,0,0,172,1],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a8b1a5f5fe0b7306da4c8b17357d45fac":[7,0,0,172,14],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a8d55f1d5ce61a1b796d8d86dd3c69fdb":[7,0,0,172,27],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a9008da922e8b8762ac284cc1f08a0749":[7,0,0,172,28],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a9673b478f78c55754cf410b223c5a06a":[7,0,0,172,8],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a98cce285a45ba6f4cf817dcf46bfb588":[7,0,0,172,10],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#aa6da7c9f1902145e0725e348cb522699":[7,0,0,172,5],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#aa8323ecd73a854f8c72fd6ac2618e3ee":[7,0,0,172,25],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#aa97afae987b0c0f16c3e232a7317fad5":[7,0,0,172,29],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#ad34cfa2c7ebdadfb5101ce751e6ab039":[7,0,0,172,22],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#ada92fbc9ee87b04f8a3c389c71904ce6":[7,0,0,172,21],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#adb0dd4e0b21379635c0c54f37ef90e1d":[7,0,0,172,15],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#ae8e81e6e6209774c203a0edf44032e65":[7,0,0,172,13],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#aed9f1ba13a68148ce730fafdb4834ba5":[7,0,0,172,9],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#afe9b5394456063cae5b95d512cc54cc0":[7,0,0,172,3],
+"class_ogre_1_1_d3_d9_video_mode.html":[7,0,0,173],
+"class_ogre_1_1_d3_d9_video_mode.html#a055a751c6ab62e8f68f55d34d074f4b9":[7,0,0,173,11],
+"class_ogre_1_1_d3_d9_video_mode.html#a2993d0fefdcad771e9649e5283d85270":[7,0,0,173,5],
+"class_ogre_1_1_d3_d9_video_mode.html#a3092cd96e44807a629e3ac45f05c683c":[7,0,0,173,1],
+"class_ogre_1_1_d3_d9_video_mode.html#a327c0921f5f515d59b9f01de46e08b88":[7,0,0,173,8],
+"class_ogre_1_1_d3_d9_video_mode.html#a349726fc8e0cf1e82dba2c831dc8bc0c":[7,0,0,173,6],
+"class_ogre_1_1_d3_d9_video_mode.html#a34a77a0c52fb29311ec6181ac8bee754":[7,0,0,173,0],
+"class_ogre_1_1_d3_d9_video_mode.html#a3f7dd41242c7c00188aad2e8489f41b8":[7,0,0,173,7],
+"class_ogre_1_1_d3_d9_video_mode.html#a4024d30689e34f0c9022cef516405028":[7,0,0,173,9],
+"class_ogre_1_1_d3_d9_video_mode.html#a70e53fa440e95ed17b85015a1e5643a6":[7,0,0,173,4],
+"class_ogre_1_1_d3_d9_video_mode.html#a84bc6e2cc34253b99afc560176038b4c":[7,0,0,173,10],
+"class_ogre_1_1_d3_d9_video_mode.html#ac4d2913efac422ca4a93ab0771373431":[7,0,0,173,2],
+"class_ogre_1_1_d3_d9_video_mode.html#af819f89d3ecd9236d1c0f9f91a71d0ba":[7,0,0,173,3],
+"class_ogre_1_1_d3_d9_video_mode_list.html":[7,0,0,174],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a0f4081d0603745659096c636a4e63b2c":[7,0,0,174,5],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a2cd7b9abf98533d646fcbe3c74b370e4":[7,0,0,174,2],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a413ec33c53b844739d33dadc357d45b0":[7,0,0,174,4],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a537516c036db7310614aa3011325f8db":[7,0,0,174,1],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a5bd29e9754803f1e0ae73ddefd24f170":[7,0,0,174,3],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a80ca3ca66b3445380b26aa3bb35ff990":[7,0,0,174,0],
 "class_ogre_1_1_d_d_s_codec.html":[5,0,3,1],
 "class_ogre_1_1_d_d_s_codec.html#a033bc39aab1445bb54e509bcc0ce5408":[5,0,3,1,4],
 "class_ogre_1_1_d_d_s_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,0,3,1,1],
@@ -231,23 +249,5 @@ var NAVTREEINDEX37 =
 "class_ogre_1_1_default_hardware_counter_buffer.html#a7c874c6b30c39aa38ae0d6abe2ba42bc":[5,0,7,2,18],
 "class_ogre_1_1_default_hardware_counter_buffer.html#a9194c7e8b536f4825b15b9e6a6912ce8":[5,0,7,2,14],
 "class_ogre_1_1_default_hardware_counter_buffer.html#a93b204642190e611bc226ea08d29160e":[5,0,7,2,10],
-"class_ogre_1_1_default_hardware_counter_buffer.html#a9c5ee6468dcb269e422e213b82726e4f":[5,0,7,2,15],
-"class_ogre_1_1_default_hardware_counter_buffer.html#aa0106887fa02d52596d77b601ebc0859":[5,0,7,2,7],
-"class_ogre_1_1_default_hardware_counter_buffer.html#aac34930556f611928ec9157c04bd1b0f":[5,0,7,2,1],
-"class_ogre_1_1_default_hardware_counter_buffer.html#aac34930556f611928ec9157c04bd1b0fa176ad39ac15fc0a6028d820a6fe228ae":[5,0,7,2,1,1],
-"class_ogre_1_1_default_hardware_counter_buffer.html#aac34930556f611928ec9157c04bd1b0fa32a2f7b1c3430cc9c3f0f665934d0c4a":[5,0,7,2,1,3],
-"class_ogre_1_1_default_hardware_counter_buffer.html#aac34930556f611928ec9157c04bd1b0faa364c1511514cd4d7ee1e7092eb41288":[5,0,7,2,1,2],
-"class_ogre_1_1_default_hardware_counter_buffer.html#aac34930556f611928ec9157c04bd1b0fae11601d29cd56aad7ea7a1b23a688b0e":[5,0,7,2,1,0],
-"class_ogre_1_1_default_hardware_counter_buffer.html#aac34930556f611928ec9157c04bd1b0faf4acad29e302c7c02ce72c3fce8990df":[5,0,7,2,1,4],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ace0a8558644446eb744a1b5d6d4dbea9":[5,0,7,2,4],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ad7bf06975ac3feef907f925645bd5ae3":[5,0,7,2,3],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae43f3b7c77ab4168d925de59d6865425":[5,0,7,2,2],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae51f5970d879af736e4cf53e1ec46630":[5,0,7,2,0],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae51f5970d879af736e4cf53e1ec46630a246699879ba7647973a2d8ed86acf76f":[5,0,7,2,0,3],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae51f5970d879af736e4cf53e1ec46630a29ff2e0fd2b408359e84291b27282516":[5,0,7,2,0,6],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae51f5970d879af736e4cf53e1ec46630a2fe20ff00e9acb928a2d9680f0c505e2":[5,0,7,2,0,2],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae51f5970d879af736e4cf53e1ec46630a5ffbb339becd31435c5f616be4c28996":[5,0,7,2,0,4],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae51f5970d879af736e4cf53e1ec46630a6f26f67ab31d60248314c9c6c77c9edb":[5,0,7,2,0,0],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae51f5970d879af736e4cf53e1ec46630aa0c82d1b27d6cc04e4b5f6d47a22a74c":[5,0,7,2,0,5],
-"class_ogre_1_1_default_hardware_counter_buffer.html#ae51f5970d879af736e4cf53e1ec46630abec61c14b13652a06566a79afd6f7518":[5,0,7,2,0,1]
+"class_ogre_1_1_default_hardware_counter_buffer.html#a9c5ee6468dcb269e422e213b82726e4f":[5,0,7,2,15]
 };
