@@ -1,5 +1,23 @@
 var NAVTREEINDEX42 =
 {
+"class_ogre_1_1_edge_data.html#a06f4e92565a4b5334aafc92dd923bd12":[5,0,6,7,10],
+"class_ogre_1_1_edge_data.html#a325ca9f8c825077c2ce6e67d11fd0558":[5,0,6,7,12],
+"class_ogre_1_1_edge_data.html#a40386af98df21e634c60b85d4434684b":[5,0,6,7,4],
+"class_ogre_1_1_edge_data.html#a64e153ea58ec4f80064986f2d9db201d":[5,0,6,7,3],
+"class_ogre_1_1_edge_data.html#a846bb6792590b4a3dc9c9f03845feef3":[5,0,6,7,15],
+"class_ogre_1_1_edge_data.html#a85e8278c626ea184a00081f199d14959":[5,0,6,7,17],
+"class_ogre_1_1_edge_data.html#a87c571c8ebe68b3ca039a003ffbe07ad":[5,0,6,7,16],
+"class_ogre_1_1_edge_data.html#a98e91393c7d803ddc96ba3c6b36625ef":[5,0,6,7,11],
+"class_ogre_1_1_edge_data.html#aa25f4ff55b3a62137c8d74b417a2e127":[5,0,6,7,6],
+"class_ogre_1_1_edge_data.html#abc392e96ecd65467b7e17e56f5b6751d":[5,0,6,7,9],
+"class_ogre_1_1_edge_data.html#aca13bc3f48d35cacaac6fb72834ab649":[5,0,6,7,8],
+"class_ogre_1_1_edge_data.html#ad171b0cbf84c2266e90ccb093485ea9b":[5,0,6,7,14],
+"class_ogre_1_1_edge_data.html#adcd3d9c03ce2bf3a8634b12fe78a9677":[5,0,6,7,13],
+"class_ogre_1_1_edge_data.html#aead5d3649daa5415ad9418859ba1b20d":[5,0,6,7,7],
+"class_ogre_1_1_edge_data.html#afaf35a82abd84227e184cf35be1255b6":[5,0,6,7,5],
+"class_ogre_1_1_edge_list_builder.html":[5,0,6,8],
+"class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186":[5,0,6,8,4],
+"class_ogre_1_1_edge_list_builder.html#a7233d617fe953b3b6c74035636f1d9f0":[5,0,6,8,3],
 "class_ogre_1_1_edge_list_builder.html#a9845e2f91660819164a627c661f5d107":[5,0,6,8,1],
 "class_ogre_1_1_edge_list_builder.html#acf52bd519947f6f8305df1bec3247dd2":[5,0,6,8,0],
 "class_ogre_1_1_edge_list_builder.html#ae4af3550dfe4948680078a087377bfbf":[5,0,6,8,2],
@@ -104,10 +122,10 @@ var NAVTREEINDEX42 =
 "class_ogre_1_1_ellipsoid_emitter.html#af46071e47818d84449ee0c8e73737fa5":[5,2,6,10,80],
 "class_ogre_1_1_ellipsoid_emitter.html#af91680375665bc911d80b76262882e8b":[5,2,6,10,22],
 "class_ogre_1_1_ellipsoid_emitter.html#aface49e7023832dda41e44b26f048843":[5,2,6,10,46],
-"class_ogre_1_1_ellipsoid_emitter_factory.html":[7,0,0,215],
-"class_ogre_1_1_ellipsoid_emitter_factory.html#a31306cb9ce96ba953129ebb23caf5024":[7,0,0,215,1],
-"class_ogre_1_1_ellipsoid_emitter_factory.html#a910cdd2bbbdd37e379d9cf596538ecab":[7,0,0,215,0],
-"class_ogre_1_1_ellipsoid_emitter_factory.html#adc0b5ab2657292efbdb4bc6e6e6a2462":[7,0,0,215,2],
+"class_ogre_1_1_ellipsoid_emitter_factory.html":[7,0,0,216],
+"class_ogre_1_1_ellipsoid_emitter_factory.html#a31306cb9ce96ba953129ebb23caf5024":[7,0,0,216,1],
+"class_ogre_1_1_ellipsoid_emitter_factory.html#a910cdd2bbbdd37e379d9cf596538ecab":[7,0,0,216,0],
+"class_ogre_1_1_ellipsoid_emitter_factory.html#adc0b5ab2657292efbdb4bc6e6e6a2462":[7,0,0,216,2],
 "class_ogre_1_1_embedded_zip_archive_factory.html":[5,0,8,7],
 "class_ogre_1_1_embedded_zip_archive_factory.html#a29c98713d1e9463bc3ab19d17be5635c":[5,0,8,7,8],
 "class_ogre_1_1_embedded_zip_archive_factory.html#a29c98713d1e9463bc3ab19d17be5635c":[5,0,8,7,9],
@@ -231,23 +249,5 @@ var NAVTREEINDEX42 =
 "class_ogre_1_1_entity.html#aaac5bf65835f733433f3338132f2f01f":[5,0,9,11,111],
 "class_ogre_1_1_entity.html#aac7bf4b7ac8cc153af4beb6b0f7f02bb":[5,0,9,11,70],
 "class_ogre_1_1_entity.html#aad51b9e34ec0124512eee4e849d40944":[5,0,9,11,42],
-"class_ogre_1_1_entity.html#ab0754ac06112f69fe759a192763a4b8a":[5,0,9,11,56],
-"class_ogre_1_1_entity.html#ab2cfac9af1b0d71c780ec969166b3585":[5,0,9,11,144],
-"class_ogre_1_1_entity.html#ab3d3d4e4aef1e2831572c2c052d29aec":[5,0,9,11,46],
-"class_ogre_1_1_entity.html#ab55eab7ca8e96a3bbb3f69a4095bf067":[5,0,9,11,127],
-"class_ogre_1_1_entity.html#ab5ddc32fa1b9e150dc8348aeef66d273":[5,0,9,11,58],
-"class_ogre_1_1_entity.html#abbd832fa10445f3f47900304be5a44d8":[5,0,9,11,133],
-"class_ogre_1_1_entity.html#abf738e5449c79b27c9a4863a32002d7e":[5,0,9,11,2],
-"class_ogre_1_1_entity.html#ac0af4df522b7f0a902a2eb74c0af9340":[5,0,9,11,14],
-"class_ogre_1_1_entity.html#ac1b4a0d834f7a21423c934e83cb7511e":[5,0,9,11,85],
-"class_ogre_1_1_entity.html#ac2904cb122ab8c8d5066abefb29dfa96":[5,0,9,11,125],
-"class_ogre_1_1_entity.html#ac4678687199f3f849a9b973346bc36d3":[5,0,9,11,12],
-"class_ogre_1_1_entity.html#ac7b3777c0e3521c021ec3a1c2c444039":[5,0,9,11,5],
-"class_ogre_1_1_entity.html#acaa798ac114550b95d04fb0798ba1d94":[5,0,9,11,139],
-"class_ogre_1_1_entity.html#acabf6919ae8c5e612c467b5176916564":[5,0,9,11,34],
-"class_ogre_1_1_entity.html#acae2215c051989d544f34083a0a9bfa2":[5,0,9,11,142],
-"class_ogre_1_1_entity.html#acbfc4840224e8b6ed6e27849d3341675":[5,0,9,11,135],
-"class_ogre_1_1_entity.html#ace3cc1b94dc305fe5e4aba949a144201":[5,0,9,11,31],
-"class_ogre_1_1_entity.html#ad35ffbcce1d3074cdb6f23fdd54bebaa":[5,0,9,11,29],
-"class_ogre_1_1_entity.html#ad360dc0a37b481749bb149f61b45bb04":[5,0,9,11,33]
+"class_ogre_1_1_entity.html#ab0754ac06112f69fe759a192763a4b8a":[5,0,9,11,56]
 };
