@@ -1,54 +1,73 @@
 var NAVTREEINDEX44 =
 {
+"class_ogre_1_1_font.html#a104d9db8bfcff1f37b29157bbe070f7a":[5,1,3,4,72],
+"class_ogre_1_1_font.html#a1248de6416ef53ce06eaf69bbb20a576":[5,1,3,4,10],
+"class_ogre_1_1_font.html#a13423fa7944d7f2339e78b9de026c3be":[5,1,3,4,56],
+"class_ogre_1_1_font.html#a17ebc3668a45365c1243a83f36a512ef":[5,1,3,4,2],
+"class_ogre_1_1_font.html#a1aa750a4b994f2b1066220936cdfdb94":[5,1,3,4,6],
+"class_ogre_1_1_font.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[5,1,3,4,6,1],
+"class_ogre_1_1_font.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[5,1,3,4,6,2],
+"class_ogre_1_1_font.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[5,1,3,4,6,0],
+"class_ogre_1_1_font.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[5,1,3,4,6,4],
+"class_ogre_1_1_font.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[5,1,3,4,6,3],
+"class_ogre_1_1_font.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[5,1,3,4,70],
+"class_ogre_1_1_font.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[5,1,3,4,68],
+"class_ogre_1_1_font.html#a1e90ade99935ef70ec5b199243bf995b":[5,1,3,4,47],
+"class_ogre_1_1_font.html#a2184210a132f13a445a267165d571e19":[5,1,3,4,22],
+"class_ogre_1_1_font.html#a2298551707debaf774d577e643ee856a":[5,1,3,4,43],
+"class_ogre_1_1_font.html#a242776c92b41e51d0dbce17ba9fec747":[5,1,3,4,15],
+"class_ogre_1_1_font.html#a278117d7414d69dbaed6e7290e842991":[5,1,3,4,31],
+"class_ogre_1_1_font.html#a350b287fa3e83a389221274f68760008":[5,1,3,4,34],
 "class_ogre_1_1_font.html#a354eac639a3afd4bfe797a208f6c90ce":[5,1,3,4,29],
-"class_ogre_1_1_font.html#a367f6fe60bb211cb4c32e3825ca67e4c":[5,1,3,4,49],
-"class_ogre_1_1_font.html#a382919945c07a6a13136889ad3fbf578":[5,1,3,4,52],
-"class_ogre_1_1_font.html#a3af26f716731b64850ea50cfa4d2edef":[5,1,3,4,45],
+"class_ogre_1_1_font.html#a367f6fe60bb211cb4c32e3825ca67e4c":[5,1,3,4,50],
+"class_ogre_1_1_font.html#a382919945c07a6a13136889ad3fbf578":[5,1,3,4,53],
+"class_ogre_1_1_font.html#a3af26f716731b64850ea50cfa4d2edef":[5,1,3,4,46],
 "class_ogre_1_1_font.html#a3b754bb7b6d6b9be27d76d7c3a70fc7e":[5,1,3,4,4],
-"class_ogre_1_1_font.html#a3c49142f739ba8fb56d6e7b3db235fb7":[5,1,3,4,51],
+"class_ogre_1_1_font.html#a3c49142f739ba8fb56d6e7b3db235fb7":[5,1,3,4,52],
 "class_ogre_1_1_font.html#a3cd25330533cd4155bcc4dee9e468370":[5,1,3,4,20],
+"class_ogre_1_1_font.html#a44e60ba33fb4a583d0239cc5cc9c849f":[5,1,3,4,33],
 "class_ogre_1_1_font.html#a466bb6a4fcc47a2b36115f4046490f5b":[5,1,3,4,24],
-"class_ogre_1_1_font.html#a5016aec1762b026997ddd346775879ef":[5,1,3,4,35],
-"class_ogre_1_1_font.html#a5513ffce404b14cff72846318b018d32":[5,1,3,4,50],
-"class_ogre_1_1_font.html#a60ce96525ac730a0f7b466ed287beef3":[5,1,3,4,47],
+"class_ogre_1_1_font.html#a5016aec1762b026997ddd346775879ef":[5,1,3,4,36],
+"class_ogre_1_1_font.html#a5513ffce404b14cff72846318b018d32":[5,1,3,4,51],
+"class_ogre_1_1_font.html#a60ce96525ac730a0f7b466ed287beef3":[5,1,3,4,48],
 "class_ogre_1_1_font.html#a64b16b4bf7d41c25824780599b4c4f81":[5,1,3,4,12],
 "class_ogre_1_1_font.html#a68ba192b84cc956d76b5d5f463b2f6b2":[5,1,3,4,19],
-"class_ogre_1_1_font.html#a699d1c851f494a8d5d23d23b695ceb47":[5,1,3,4,34],
+"class_ogre_1_1_font.html#a699d1c851f494a8d5d23d23b695ceb47":[5,1,3,4,35],
 "class_ogre_1_1_font.html#a6ca4172a3f554f07752997b1a25278c0":[5,1,3,4,30],
-"class_ogre_1_1_font.html#a74138c0203835513613af73cdb08890d":[5,1,3,4,44],
-"class_ogre_1_1_font.html#a7b4afd007622d165efbcc362e5566922":[5,1,3,4,70],
-"class_ogre_1_1_font.html#a7e248a1cca0662418d4ab3f63c2e7cf6":[5,1,3,4,56],
+"class_ogre_1_1_font.html#a74138c0203835513613af73cdb08890d":[5,1,3,4,45],
+"class_ogre_1_1_font.html#a7b4afd007622d165efbcc362e5566922":[5,1,3,4,71],
+"class_ogre_1_1_font.html#a7e248a1cca0662418d4ab3f63c2e7cf6":[5,1,3,4,57],
 "class_ogre_1_1_font.html#a84c9f4e4a5d536fc6660c8f9fc37db66":[5,1,3,4,27],
-"class_ogre_1_1_font.html#a8eb34a9034aab62fd537c021a79e3366":[5,1,3,4,36],
-"class_ogre_1_1_font.html#a8f541900f7e1f73f4c313a732199029a":[5,1,3,4,37],
+"class_ogre_1_1_font.html#a8eb34a9034aab62fd537c021a79e3366":[5,1,3,4,37],
+"class_ogre_1_1_font.html#a8f541900f7e1f73f4c313a732199029a":[5,1,3,4,38],
 "class_ogre_1_1_font.html#a97480c17800578be97dc6a432983d3f2":[5,1,3,4,21],
 "class_ogre_1_1_font.html#a9915203be62b8bd2feda436cc9f08cb0":[5,1,3,4,7],
-"class_ogre_1_1_font.html#a9aac32f93bd149a34b809a57a9f01f8f":[5,1,3,4,66],
+"class_ogre_1_1_font.html#a9aac32f93bd149a34b809a57a9f01f8f":[5,1,3,4,67],
 "class_ogre_1_1_font.html#a9de80ee5fde8a6cd4ddf1633f77b7b4d":[5,1,3,4,28],
-"class_ogre_1_1_font.html#aa31bef1bfaa87731622e56f11b548e27":[5,1,3,4,38],
+"class_ogre_1_1_font.html#aa31bef1bfaa87731622e56f11b548e27":[5,1,3,4,39],
 "class_ogre_1_1_font.html#aa455a399457bd458852555c696b28f6a":[5,1,3,4,3],
-"class_ogre_1_1_font.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[5,1,3,4,53],
-"class_ogre_1_1_font.html#aa68664db6b8723dc198beef3d21d4ef5":[5,1,3,4,59],
+"class_ogre_1_1_font.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[5,1,3,4,54],
+"class_ogre_1_1_font.html#aa68664db6b8723dc198beef3d21d4ef5":[5,1,3,4,60],
 "class_ogre_1_1_font.html#aa80b463afd8a361e240a5a6856e892e3":[5,1,3,4,23],
-"class_ogre_1_1_font.html#aad68d8b18faad14e8286a67527094654":[5,1,3,4,68],
-"class_ogre_1_1_font.html#aaf3746937cd11864f53bc1c3b4437541":[5,1,3,4,61],
-"class_ogre_1_1_font.html#aaf63d096584ac7d97fe1d1b0226c9561":[5,1,3,4,60],
+"class_ogre_1_1_font.html#aad68d8b18faad14e8286a67527094654":[5,1,3,4,69],
+"class_ogre_1_1_font.html#aaf3746937cd11864f53bc1c3b4437541":[5,1,3,4,62],
+"class_ogre_1_1_font.html#aaf63d096584ac7d97fe1d1b0226c9561":[5,1,3,4,61],
 "class_ogre_1_1_font.html#ab68fc068d526a83163bf305acdc6c732":[5,1,3,4,13],
-"class_ogre_1_1_font.html#ab6e377a3964d566ea112fe63bf1d7678":[5,1,3,4,54],
+"class_ogre_1_1_font.html#ab6e377a3964d566ea112fe63bf1d7678":[5,1,3,4,55],
 "class_ogre_1_1_font.html#ab89abe298177153acda383de2d7823ca":[5,1,3,4,9],
 "class_ogre_1_1_font.html#abfa4659b19ef3052676ccf8a64181e6f":[5,1,3,4,16],
 "class_ogre_1_1_font.html#ac2c1fba5ad2d610ecc78b1e1a6a1b8dc":[5,1,3,4,25],
 "class_ogre_1_1_font.html#ad48cf05dd479e7c8f1d7a97221d933b1":[5,1,3,4,1],
-"class_ogre_1_1_font.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[5,1,3,4,64],
+"class_ogre_1_1_font.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[5,1,3,4,65],
 "class_ogre_1_1_font.html#ad68729fd75b27236a4174a5e5013c448":[5,1,3,4,17],
 "class_ogre_1_1_font.html#ad9fb35dcaf249ea1d86a3fe849422e2d":[5,1,3,4,32],
-"class_ogre_1_1_font.html#ade85e4d5579519e4117a84789c0ae8fd":[5,1,3,4,57],
+"class_ogre_1_1_font.html#ade85e4d5579519e4117a84789c0ae8fd":[5,1,3,4,58],
 "class_ogre_1_1_font.html#adfdd689e89e023ae144207da8b82487a":[5,1,3,4,18],
-"class_ogre_1_1_font.html#ae0a0007de944eb3c2f933a372a752b35":[5,1,3,4,48],
-"class_ogre_1_1_font.html#ae229b1f58092109adef55bfc6f864d79":[5,1,3,4,40],
-"class_ogre_1_1_font.html#ae3e13925bde11db245f6c9bbf5031a93":[5,1,3,4,62],
+"class_ogre_1_1_font.html#ae0a0007de944eb3c2f933a372a752b35":[5,1,3,4,49],
+"class_ogre_1_1_font.html#ae229b1f58092109adef55bfc6f864d79":[5,1,3,4,41],
+"class_ogre_1_1_font.html#ae3e13925bde11db245f6c9bbf5031a93":[5,1,3,4,63],
 "class_ogre_1_1_font.html#af055e465763f6328d3d5685eb30b0b30":[5,1,3,4,14],
-"class_ogre_1_1_font.html#afcb4a61b965600a67ca2c2f060821db9":[5,1,3,4,58],
+"class_ogre_1_1_font.html#afcb4a61b965600a67ca2c2f060821db9":[5,1,3,4,59],
 "class_ogre_1_1_font.html#aff75a40e8ca00a64f19c265e90c61733":[5,1,3,4,26],
 "class_ogre_1_1_font_manager.html":[5,1,3,5],
 "class_ogre_1_1_font_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[5,1,3,5,46],
@@ -230,24 +249,5 @@ var NAVTREEINDEX44 =
 "class_ogre_1_1_frustum.html#a77198e02dd65dd368ea4e6af88a93fda":[5,0,6,9,105],
 "class_ogre_1_1_frustum.html#a77230eea8136b7c296cc0a5db1dba9ee":[5,0,6,9,140],
 "class_ogre_1_1_frustum.html#a774753927eb2a42a9d8f5492cd2ced1a":[5,0,6,9,104],
-"class_ogre_1_1_frustum.html#a7b0999d33e25db97d0449d6cf95cbecd":[5,0,6,9,1],
-"class_ogre_1_1_frustum.html#a7bc8b601d85642059f23e739fb4438bb":[5,0,6,9,7],
-"class_ogre_1_1_frustum.html#a7c1b2e8c0c2a0845d43cb6da44bcd39b":[5,0,6,9,23],
-"class_ogre_1_1_frustum.html#a7ceea76d4e6245d2d5b48d53e494a44c":[5,0,6,9,70],
-"class_ogre_1_1_frustum.html#a7edabdda7a22df8dcd6d4366b9f26268":[5,0,6,9,29],
-"class_ogre_1_1_frustum.html#a8043bede518f35c709880e4f3248a026":[5,0,6,9,158],
-"class_ogre_1_1_frustum.html#a812d3b0f5df694b92084a98387d8f215":[5,0,6,9,149],
-"class_ogre_1_1_frustum.html#a82b518c593a2777525a02fac1e0028eb":[5,0,6,9,131],
-"class_ogre_1_1_frustum.html#a855def6097624986a528a35dbb93f7cc":[5,0,6,9,31],
-"class_ogre_1_1_frustum.html#a869e7226c48fbff5dafef92b2b929b5e":[5,0,6,9,145],
-"class_ogre_1_1_frustum.html#a88785bbad8a09ea5ae404a5fbd8a6501":[5,0,6,9,98],
-"class_ogre_1_1_frustum.html#a898aacf695cb611e4e05495c0c12fb23":[5,0,6,9,55],
-"class_ogre_1_1_frustum.html#a8cfd78c1f87c5941dea4c380e140ad22":[5,0,6,9,50],
-"class_ogre_1_1_frustum.html#a8f2627b8d1658838a7c79c82148c6303":[5,0,6,9,130],
-"class_ogre_1_1_frustum.html#a9228f6fc5b864a209dd6d8b25d145065":[5,0,6,9,79],
-"class_ogre_1_1_frustum.html#a9732242c49670bc3633f7346a4b7038b":[5,0,6,9,40],
-"class_ogre_1_1_frustum.html#a98fe88f82f86eafa19308074495db809":[5,0,6,9,106],
-"class_ogre_1_1_frustum.html#a9ae36ffd83edd59637523cd2af02c54e":[5,0,6,9,28],
-"class_ogre_1_1_frustum.html#a9bec8bfd7117c1ebe1da2c79e0805933":[5,0,6,9,38],
-"class_ogre_1_1_frustum.html#a9cf204a5b5df75c8c745560551657358":[5,0,6,9,155]
+"class_ogre_1_1_frustum.html#a7b0999d33e25db97d0449d6cf95cbecd":[5,0,6,9,1]
 };
