@@ -1,5 +1,24 @@
 var NAVTREEINDEX67 =
 {
+"class_ogre_1_1_hardware_buffer_manager_base.html#a830cd072c0e063e729b67201f04492a1":[5,0,7,12,5],
+"class_ogre_1_1_hardware_buffer_manager_base.html#a876ce18832783cd168f4e55d989c3f1c":[5,0,7,12,18],
+"class_ogre_1_1_hardware_buffer_manager_base.html#a88f21df1e7ee330033812ddeba4a08fa":[5,0,7,12,0],
+"class_ogre_1_1_hardware_buffer_manager_base.html#a88f21df1e7ee330033812ddeba4a08faa372ccf538e8a6022bba092d2b47f4fdb":[5,0,7,12,0,0],
+"class_ogre_1_1_hardware_buffer_manager_base.html#a88f21df1e7ee330033812ddeba4a08faa994cf0191de83556e3c1e6cf30cd6acb":[5,0,7,12,0,1],
+"class_ogre_1_1_hardware_buffer_manager_base.html#a8cd2588a1b57f4b417d6816f7ddb5584":[5,0,7,12,19],
+"class_ogre_1_1_hardware_buffer_manager_base.html#aa12ae6a67af715b2be80182bd05abb46":[5,0,7,12,21],
+"class_ogre_1_1_hardware_buffer_manager_base.html#aa1f5ef725fdeacc6018e1dee3b7eded5":[5,0,7,12,1],
+"class_ogre_1_1_hardware_buffer_manager_base.html#ab717df387ec6c1e119ed2ac0e2c9a54b":[5,0,7,12,15],
+"class_ogre_1_1_hardware_buffer_manager_base.html#abc50f8bac0fad6710aa205d0c4e295c4":[5,0,7,12,2],
+"class_ogre_1_1_hardware_buffer_manager_base.html#abe3ea209174c3a40286dde425addb814":[5,0,7,12,8],
+"class_ogre_1_1_hardware_buffer_manager_base.html#acbde393716ec1057024cdff4d3282913":[5,0,7,12,10],
+"class_ogre_1_1_hardware_buffer_manager_base.html#acca9ea14315ef17d74f6ab972d9a1ec8":[5,0,7,12,14],
+"class_ogre_1_1_hardware_buffer_manager_base.html#ad19793152eef356380827edb755c613e":[5,0,7,12,22],
+"class_ogre_1_1_hardware_buffer_manager_base.html#adeb459425f647d9b9077bbea77a43f27":[5,0,7,12,6],
+"class_ogre_1_1_hardware_buffer_manager_base.html#ae3b729879133ff816e15f73e921c3b18":[5,0,7,12,9],
+"class_ogre_1_1_hardware_buffer_manager_base.html#ae46262b1cc1e8bfe136e9bb203894c41":[5,0,7,12,4],
+"class_ogre_1_1_hardware_buffer_manager_base.html#aec7eea2d5d1853ea29b412f43986140b":[5,0,7,12,7],
+"class_ogre_1_1_hardware_counter_buffer.html":[5,0,7,13],
 "class_ogre_1_1_hardware_counter_buffer.html#a0bf3147b1f99a81dd84fb7b978c4686d":[5,0,7,13,12],
 "class_ogre_1_1_hardware_counter_buffer.html#a0e1881a6106c59d5aae27589ca1bca5d":[5,0,7,13,16],
 "class_ogre_1_1_hardware_counter_buffer.html#a344c52f2214eaff097d5fbc390e7684b":[5,0,7,13,13],
@@ -230,24 +249,5 @@ var NAVTREEINDEX67 =
 "class_ogre_1_1_hashed_vector.html#a9700cee4608a9bd76c872c156fb06ba6":[5,0,2,36,13],
 "class_ogre_1_1_hashed_vector.html#a9e1f2a609eb5a7be9cc3d51b49f755df":[5,0,2,36,7],
 "class_ogre_1_1_hashed_vector.html#aa0b7d89231b3ebf5944562ef7db7d83b":[5,0,2,36,4],
-"class_ogre_1_1_hashed_vector.html#aa2ecbc6ad493ebc5c003e9e8b6363cfa":[5,0,2,36,29],
-"class_ogre_1_1_hashed_vector.html#aa48ea0c4375e6d83e286824e891603c4":[5,0,2,36,12],
-"class_ogre_1_1_hashed_vector.html#aba664c4d307e5dd9ac7ba03252fbe167":[5,0,2,36,8],
-"class_ogre_1_1_hashed_vector.html#ac0511ced14665359e65d2fc13215e748":[5,0,2,36,51],
-"class_ogre_1_1_hashed_vector.html#ac47cb9541d822b017804c828a13d961c":[5,0,2,36,50],
-"class_ogre_1_1_hashed_vector.html#ac527f3aa4ac341a45abc720cd457f021":[5,0,2,36,38],
-"class_ogre_1_1_hashed_vector.html#ace139bbc4ce2c45d0102edea246468a4":[5,0,2,36,2],
-"class_ogre_1_1_hashed_vector.html#ad0c2cbcf91d469bb12ef2907e1c053de":[5,0,2,36,33],
-"class_ogre_1_1_hashed_vector.html#ad793202b7a2ea15d6826fdc5f4488480":[5,0,2,36,22],
-"class_ogre_1_1_hashed_vector.html#ae58c9b49af378fbedd6c717369435135":[5,0,2,36,37],
-"class_ogre_1_1_hashed_vector.html#ae7fdb654452068fba22b734e095e99c4":[5,0,2,36,45],
-"class_ogre_1_1_hashed_vector.html#aef2c968d6705c0fdd5f50a70983e8314":[5,0,2,36,35],
-"class_ogre_1_1_hashed_vector.html#af0b04cbf9823c57128855d112f3581e4":[5,0,2,36,5],
-"class_ogre_1_1_high_level_gpu_program.html":[5,0,8,14],
-"class_ogre_1_1_high_level_gpu_program.html#a04675a861df66c30e431f95aa84320f5":[5,0,8,14,34],
-"class_ogre_1_1_high_level_gpu_program.html#a0617d9f04ca03bd25f4bde201e6ac13b":[5,0,8,14,52],
-"class_ogre_1_1_high_level_gpu_program.html#a0646fba8aa0242c6b389d73f47ebe41b":[5,0,8,14,54],
-"class_ogre_1_1_high_level_gpu_program.html#a0779c46df96234b6619a5f57fbb36078":[5,0,8,14,56],
-"class_ogre_1_1_high_level_gpu_program.html#a07e619aa09d3bc6789a6667cb4fc572c":[5,0,8,14,0],
-"class_ogre_1_1_high_level_gpu_program.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1":[5,0,8,14,0,4]
+"class_ogre_1_1_hashed_vector.html#aa2ecbc6ad493ebc5c003e9e8b6363cfa":[5,0,2,36,29]
 };
