@@ -1,5 +1,24 @@
 var NAVTREEINDEX69 =
 {
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#a98d3f921cd9061414149636172557d71":[5,2,6,11,39],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#a9aac32f93bd149a34b809a57a9f01f8f":[5,2,6,11,85],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#a9d26a5cb04855bc93abe837dc7cb83ac":[5,2,6,11,57],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#aa0784075820b4bdf48c687986ac77117":[5,2,6,11,21],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#aa4cc84bb842666d1a69d25375dac5d12":[5,2,6,11,42],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#aa4df69c38e5bd02eea6cd9439f9da04a":[5,2,6,11,105],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#aa9d9846fd83ec7e272d3e5b663270800":[5,2,6,11,76],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#aad68d8b18faad14e8286a67527094654":[5,2,6,11,87],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#aae174ed689d7748e3047bb4242440993":[5,2,6,11,23],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#ab39d2d327c694ef553fc3159b680d1db":[5,2,6,11,37],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#ab477389178da76c28a12e07d1191bef4":[5,2,6,11,38],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#ab616bda74c451b4617cb222f726656c8":[5,2,6,11,5],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#ab8a04670adcf78d5341c1ad9029ee269":[5,2,6,11,4],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#abfea8fc856e37f26eb5901e930c7b21f":[5,2,6,11,93],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#abff726acd08f87c5be8a77c2e7d0b9eb":[5,2,6,11,45],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#ac18d85d72526f7c20a5a04547cd90c30":[5,2,6,11,75],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#ac4a7e742d6abd51a9dceaec92eb0e23a":[5,2,6,11,99],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#ac68363d8d8a4605d845ca6198296fd2a":[5,2,6,11,12],
+"class_ogre_1_1_hollow_ellipsoid_emitter.html#ac6faac35cb62e861b8b0803e04ceed13":[5,2,6,11,27],
 "class_ogre_1_1_hollow_ellipsoid_emitter.html#ac9741b2623435c312819c9d3903c915e":[5,2,6,11,104],
 "class_ogre_1_1_hollow_ellipsoid_emitter.html#acb690da52c45571e198e39857b6a6d89":[5,2,6,11,40],
 "class_ogre_1_1_hollow_ellipsoid_emitter.html#ad072fea486991d4efa92f9e062ea84b1":[5,2,6,11,13],
@@ -28,10 +47,10 @@ var NAVTREEINDEX69 =
 "class_ogre_1_1_hollow_ellipsoid_emitter_1_1_cmd_inner_z.html":[5,2,6,11,2],
 "class_ogre_1_1_hollow_ellipsoid_emitter_1_1_cmd_inner_z.html#a838af007c81860399f6c4abf242009e3":[5,2,6,11,2,1],
 "class_ogre_1_1_hollow_ellipsoid_emitter_1_1_cmd_inner_z.html#aea3316dbdd0e023ac03153f705c3f276":[5,2,6,11,2,0],
-"class_ogre_1_1_hollow_ellipsoid_emitter_factory.html":[7,0,0,385],
-"class_ogre_1_1_hollow_ellipsoid_emitter_factory.html#a0a150f462944dcacb8ad2696b1e3220e":[7,0,0,385,1],
-"class_ogre_1_1_hollow_ellipsoid_emitter_factory.html#adc0b5ab2657292efbdb4bc6e6e6a2462":[7,0,0,385,2],
-"class_ogre_1_1_hollow_ellipsoid_emitter_factory.html#ae7e462bb537bbd1e075d9b05d8a65fc7":[7,0,0,385,0],
+"class_ogre_1_1_hollow_ellipsoid_emitter_factory.html":[7,0,0,386],
+"class_ogre_1_1_hollow_ellipsoid_emitter_factory.html#a0a150f462944dcacb8ad2696b1e3220e":[7,0,0,386,1],
+"class_ogre_1_1_hollow_ellipsoid_emitter_factory.html#adc0b5ab2657292efbdb4bc6e6e6a2462":[7,0,0,386,2],
+"class_ogre_1_1_hollow_ellipsoid_emitter_factory.html#ae7e462bb537bbd1e075d9b05d8a65fc7":[7,0,0,386,0],
 "class_ogre_1_1_i_o_exception.html":[5,0,2,42],
 "class_ogre_1_1_i_o_exception.html#a44cc73cf416eba0ef75a49d18d919664":[5,0,2,42,3],
 "class_ogre_1_1_i_o_exception.html#a501b957a641840f1dc06d7b8d4657d19":[5,0,2,42,6],
@@ -52,14 +71,14 @@ var NAVTREEINDEX69 =
 "class_ogre_1_1_i_o_exception.html#a9bdf9b8a0a83b95818d676848beaa29bae8c10c1472a5d4005d1c25adb5e2764d":[5,0,2,42,0,8],
 "class_ogre_1_1_i_o_exception.html#a9cb13ae6d95e203689c43dfe194cf0c7":[5,0,2,42,1],
 "class_ogre_1_1_i_o_exception.html#af6e85a048732d785797152da81a2706c":[5,0,2,42,2],
-"class_ogre_1_1_id.html":[7,0,0,386],
-"class_ogre_1_1_id.html#a73f0ff39b60e9635f373257aac3b0918":[7,0,0,386,0],
-"class_ogre_1_1_id_object.html":[7,0,0,387],
-"class_ogre_1_1_id_object.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[7,0,0,387,2],
-"class_ogre_1_1_id_object.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,387,3],
-"class_ogre_1_1_id_object.html#a7884ec3abf1ed8c1b1514d3bda918370":[7,0,0,387,0],
-"class_ogre_1_1_id_object.html#aad76afcc63d308b18fe15fa45b9520f9":[7,0,0,387,4],
-"class_ogre_1_1_id_object.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,387,1],
+"class_ogre_1_1_id.html":[7,0,0,387],
+"class_ogre_1_1_id.html#a73f0ff39b60e9635f373257aac3b0918":[7,0,0,387,0],
+"class_ogre_1_1_id_object.html":[7,0,0,388],
+"class_ogre_1_1_id_object.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[7,0,0,388,2],
+"class_ogre_1_1_id_object.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,388,3],
+"class_ogre_1_1_id_object.html#a7884ec3abf1ed8c1b1514d3bda918370":[7,0,0,388,0],
+"class_ogre_1_1_id_object.html#aad76afcc63d308b18fe15fa45b9520f9":[7,0,0,388,4],
+"class_ogre_1_1_id_object.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,388,1],
 "class_ogre_1_1_image.html":[5,0,3,5],
 "class_ogre_1_1_image.html#a03cc0979349f9bc0265a5874b57ea184":[5,0,3,5,18],
 "class_ogre_1_1_image.html#a064e61e5225c5405d838e2e96a45beed":[5,0,3,5,24],
@@ -230,24 +249,5 @@ var NAVTREEINDEX69 =
 "class_ogre_1_1_instance_batch.html#acaa798ac114550b95d04fb0798ba1d94":[5,0,9,14,125],
 "class_ogre_1_1_instance_batch.html#acae2215c051989d544f34083a0a9bfa2":[5,0,9,14,128],
 "class_ogre_1_1_instance_batch.html#acbfc4840224e8b6ed6e27849d3341675":[5,0,9,14,120],
-"class_ogre_1_1_instance_batch.html#acd842f7e93eec273ae0f6f6b39caae4e":[5,0,9,14,81],
-"class_ogre_1_1_instance_batch.html#ad563191e86e4d119c62ea9acfc2a90d5":[5,0,9,14,82],
-"class_ogre_1_1_instance_batch.html#ad66149b7a6f5ba1cd5c58fbd69f0446a":[5,0,9,14,100],
-"class_ogre_1_1_instance_batch.html#ad8db1f22329b2a96f2aed7260d565944":[5,0,9,14,101],
-"class_ogre_1_1_instance_batch.html#adc7212015bff66546a8a351355d7b5fb":[5,0,9,14,2],
-"class_ogre_1_1_instance_batch.html#ae2a149aa0e0c9f3fb57f22d5f649247a":[5,0,9,14,80],
-"class_ogre_1_1_instance_batch.html#ae307c64b6e130191e45d48df0e2c5961":[5,0,9,14,79],
-"class_ogre_1_1_instance_batch.html#ae3ad78c8e756ea5fb43d7830462abb1f":[5,0,9,14,55],
-"class_ogre_1_1_instance_batch.html#ae53cff42a16304f582ef83ad3017d614":[5,0,9,14,49],
-"class_ogre_1_1_instance_batch.html#ae944917873dd68126c129f05e51622d3":[5,0,9,14,58],
-"class_ogre_1_1_instance_batch.html#aeb13418fe2740ed8ebc52cd9667fca41":[5,0,9,14,75],
-"class_ogre_1_1_instance_batch.html#aec8de75364ba934510a7c1d0e8cb6471":[5,0,9,14,110],
-"class_ogre_1_1_instance_batch.html#aef2a2634077942a2939514a6c1114d32":[5,0,9,14,76],
-"class_ogre_1_1_instance_batch.html#af19ca18abcd6ca7bceb2f55a814e1c1b":[5,0,9,14,83],
-"class_ogre_1_1_instance_batch.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[5,0,9,14,48],
-"class_ogre_1_1_instance_batch.html#af6788ed3697ab34c561c0afcf39ac8c3":[5,0,9,14,86],
-"class_ogre_1_1_instance_batch.html#af730ac3ee4a51ee69f4221298f933e8a":[5,0,9,14,67],
-"class_ogre_1_1_instance_batch.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,0,9,14,43],
-"class_ogre_1_1_instance_batch.html#afe1f2a1009e3f14f36e1bcc9b1b9557e":[5,0,9,14,85],
-"class_ogre_1_1_instance_batch_h_w.html":[5,0,9,15]
+"class_ogre_1_1_instance_batch.html#acd842f7e93eec273ae0f6f6b39caae4e":[5,0,9,14,81]
 };
