@@ -1,5 +1,24 @@
 var NAVTREEINDEX72 =
 {
+"class_ogre_1_1_instance_batch_v_t_f.html#ga2eb1a9ee689ebae91819e9ed81c12b54":[5,0,9,18,19],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga2f3b53c770793546d08f40afedb167f5":[5,0,9,18,49],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga3de0cec85d8506862c964e5980553496":[5,0,9,18,20],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga44d78b230b026f76fae1ef3ca248d97f":[5,0,9,18,32],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga4524a2e65d6f52411d8b5f31ef056771":[5,0,9,18,21],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga57dfa1e8c4c45896da46f19cca27ced5":[5,0,9,18,13],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga594f79fee334537c1e64abe4777d77fa":[5,0,9,18,47],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga595dea7ab487def43e80c26715cb8591":[5,0,9,18,25],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga5bcd3f7c4a1280df27cdec94c5f18cb1":[5,0,9,18,12],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga61b8f8dd2a76aefe958083ad37d364fd":[5,0,9,18,14],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga62ac297aa71e017ec1ab97929c06e036":[5,0,9,18,40],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga6603588204263c7d16173169a5e327e7":[5,0,9,18,38],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga669f14748bd5c2cf8c8559c83371bdf5":[5,0,9,18,46],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga6acd24f5b5aa6ea29d1d3baf57603dd2":[5,0,9,18,37],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga707b7dc9f29486a9ad3f07f9c96665f7":[5,0,9,18,33],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga76e03f1dfd14df9dcb57cbb7eb089777":[5,0,9,18,50],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga7c7e77b52df342b78e04d0294f741df2":[5,0,9,18,27],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga8073edd16937723e2b2db8ba51672dc1":[5,0,9,18,26],
+"class_ogre_1_1_instance_batch_v_t_f.html#ga810d6dd7b95994be19c0b49d2f1f4267":[5,0,9,18,23],
 "class_ogre_1_1_instance_batch_v_t_f.html#ga8de1d6bc736ed16039fc4feed1054ad1":[5,0,9,18,17],
 "class_ogre_1_1_instance_batch_v_t_f.html#ga90f980cad52ceec8bd2fc56ae515e016":[5,0,9,18,51],
 "class_ogre_1_1_instance_batch_v_t_f.html#ga9e6dfe915b52c9463a503d690ae7da4f":[5,0,9,18,34],
@@ -212,17 +231,17 @@ var NAVTREEINDEX72 =
 "class_ogre_1_1_item_identity_exception.html#a9bdf9b8a0a83b95818d676848beaa29bae8c10c1472a5d4005d1c25adb5e2764d":[5,0,2,43,0,8],
 "class_ogre_1_1_item_identity_exception.html#ae98c4a38b709e81ef21722be30db5060":[5,0,2,43,1],
 "class_ogre_1_1_item_identity_exception.html#af6e85a048732d785797152da81a2706c":[5,0,2,43,2],
-"class_ogre_1_1_iterator_wrapper.html":[7,0,0,425],
-"class_ogre_1_1_iterator_wrapper.html#a0fd0df9bbfe0fc16939600b37de81739":[7,0,0,425,9],
-"class_ogre_1_1_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[7,0,0,425,2],
-"class_ogre_1_1_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[7,0,0,425,3],
-"class_ogre_1_1_iterator_wrapper.html#a72bb580445cd26d668677e159b692d4f":[7,0,0,425,1],
-"class_ogre_1_1_iterator_wrapper.html#a72df6843478e277b8dde180081156b98":[7,0,0,425,0],
-"class_ogre_1_1_iterator_wrapper.html#aae5af61f58bb7e21b76f6b44088d5ea8":[7,0,0,425,4],
-"class_ogre_1_1_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[7,0,0,425,6],
-"class_ogre_1_1_iterator_wrapper.html#ab2daa0557a06aebd61686b13c865b6c0":[7,0,0,425,8],
-"class_ogre_1_1_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[7,0,0,425,5],
-"class_ogre_1_1_iterator_wrapper.html#acfb61cec43a0da5ae1b7c6ee6274498d":[7,0,0,425,7],
+"class_ogre_1_1_iterator_wrapper.html":[7,0,0,426],
+"class_ogre_1_1_iterator_wrapper.html#a0fd0df9bbfe0fc16939600b37de81739":[7,0,0,426,9],
+"class_ogre_1_1_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[7,0,0,426,2],
+"class_ogre_1_1_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[7,0,0,426,3],
+"class_ogre_1_1_iterator_wrapper.html#a72bb580445cd26d668677e159b692d4f":[7,0,0,426,1],
+"class_ogre_1_1_iterator_wrapper.html#a72df6843478e277b8dde180081156b98":[7,0,0,426,0],
+"class_ogre_1_1_iterator_wrapper.html#aae5af61f58bb7e21b76f6b44088d5ea8":[7,0,0,426,4],
+"class_ogre_1_1_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[7,0,0,426,6],
+"class_ogre_1_1_iterator_wrapper.html#ab2daa0557a06aebd61686b13c865b6c0":[7,0,0,426,8],
+"class_ogre_1_1_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[7,0,0,426,5],
+"class_ogre_1_1_iterator_wrapper.html#acfb61cec43a0da5ae1b7c6ee6274498d":[7,0,0,426,7],
 "class_ogre_1_1_key_frame.html":[5,0,0,9],
 "class_ogre_1_1_key_frame.html#a2f8e964ccf18553eef80f93c26d0e7bc":[5,0,0,9,1],
 "class_ogre_1_1_key_frame.html#a6d31b620621fdeed1a3fc9f752498ad7":[5,0,0,9,0],
@@ -230,24 +249,5 @@ var NAVTREEINDEX72 =
 "class_ogre_1_1_key_frame.html#a8c4fe7a2c23ed4a24bf5030bc3113b94":[5,0,0,9,2],
 "class_ogre_1_1_layer_blend_mode_ex.html":[5,0,5,14],
 "class_ogre_1_1_layer_blend_mode_ex.html#a1a5c33d25313f28b75fe67903766b5fe":[5,0,5,14,0],
-"class_ogre_1_1_layer_blend_mode_ex.html#a334818129ca44c1fbdba2b3b2813368a":[5,0,5,14,4],
-"class_ogre_1_1_layer_blend_mode_ex.html#a6bd40927e40bcb2d6c4e077ebd56c24d":[5,0,5,14,7],
-"class_ogre_1_1_layer_blend_mode_ex.html#a71cee0ade264a82051913d5eb0fc4c40":[5,0,5,14,10],
-"class_ogre_1_1_layer_blend_mode_ex.html#a8af3aad5d2de939d0d9bff3049c82928":[5,0,5,14,8],
-"class_ogre_1_1_layer_blend_mode_ex.html#a92074f86847e7e5c065bd94498396ade":[5,0,5,14,1],
-"class_ogre_1_1_layer_blend_mode_ex.html#a94eeae80ba84e9aa5271d317d48f2688":[5,0,5,14,5],
-"class_ogre_1_1_layer_blend_mode_ex.html#a99adb8004759bf3825d934684ab8f171":[5,0,5,14,6],
-"class_ogre_1_1_layer_blend_mode_ex.html#a9dde2b63904e61319b175094f8fc67f0":[5,0,5,14,9],
-"class_ogre_1_1_layer_blend_mode_ex.html#ac2cb8de7b805400726882f7003a4bcda":[5,0,5,14,2],
-"class_ogre_1_1_layer_blend_mode_ex.html#afc151f1c17683cd99df776459df2c778":[5,0,5,14,3],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html":[5,0,9,26],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a1cfbebd281d571f3748cd8800aef076d":[5,0,9,26,0],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a1d1a64d84fe3bd0ff8d570e7c7ab3460":[5,0,9,26,10],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a2988a1a516ef7adc97f960e95aa54549":[5,0,9,26,2],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a2a6fb5e0335458e5c626740bfcbfc56c":[5,0,9,26,8],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a544318a0bd973ce48d3e959423a466c2":[5,0,9,26,1],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a9b5d6e5ff9339e7a010c2dfbcb051490":[5,0,9,26,5],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#aa19c6563c41297f7e14e8918dd89b074":[5,0,9,26,3],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#aa4f0c58ca0ea89aa7e4b11def4976ea6":[5,0,9,26,4],
-"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#abddaf4baa243cbda0e8a2bd43f3058f0":[5,0,9,26,9]
+"class_ogre_1_1_layer_blend_mode_ex.html#a334818129ca44c1fbdba2b3b2813368a":[5,0,5,14,4]
 };
