@@ -1,5 +1,24 @@
 var NAVTREEINDEX73 =
 {
+"class_ogre_1_1_layer_blend_mode_ex.html#a6bd40927e40bcb2d6c4e077ebd56c24d":[5,0,5,14,7],
+"class_ogre_1_1_layer_blend_mode_ex.html#a71cee0ade264a82051913d5eb0fc4c40":[5,0,5,14,10],
+"class_ogre_1_1_layer_blend_mode_ex.html#a8af3aad5d2de939d0d9bff3049c82928":[5,0,5,14,8],
+"class_ogre_1_1_layer_blend_mode_ex.html#a92074f86847e7e5c065bd94498396ade":[5,0,5,14,1],
+"class_ogre_1_1_layer_blend_mode_ex.html#a94eeae80ba84e9aa5271d317d48f2688":[5,0,5,14,5],
+"class_ogre_1_1_layer_blend_mode_ex.html#a99adb8004759bf3825d934684ab8f171":[5,0,5,14,6],
+"class_ogre_1_1_layer_blend_mode_ex.html#a9dde2b63904e61319b175094f8fc67f0":[5,0,5,14,9],
+"class_ogre_1_1_layer_blend_mode_ex.html#ac2cb8de7b805400726882f7003a4bcda":[5,0,5,14,2],
+"class_ogre_1_1_layer_blend_mode_ex.html#afc151f1c17683cd99df776459df2c778":[5,0,5,14,3],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html":[5,0,9,26],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a1d1a64d84fe3bd0ff8d570e7c7ab3460":[5,0,9,26,10],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a2a6fb5e0335458e5c626740bfcbfc56c":[5,0,9,26,8],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a2a791fce47290ff3b9ec7b6daac73458":[5,0,9,26,0],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a544318a0bd973ce48d3e959423a466c2":[5,0,9,26,1],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#a9b5d6e5ff9339e7a010c2dfbcb051490":[5,0,9,26,5],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#aa19c6563c41297f7e14e8918dd89b074":[5,0,9,26,3],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#aa4f0c58ca0ea89aa7e4b11def4976ea6":[5,0,9,26,4],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#abddaf4baa243cbda0e8a2bd43f3058f0":[5,0,9,26,9],
+"class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#ad26244d0895a5e1c2c272018af7b2d98":[5,0,9,26,2],
 "class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#ad28464a9e78991c046b70f2d6c95a753":[5,0,9,26,12],
 "class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#ad836bab9853f49b42a2fe9f2aab786b1":[5,0,9,26,7],
 "class_ogre_1_1_li_s_p_s_m_shadow_camera_setup.html#ae09cafbe81832dd23c70f85d9435b213":[5,0,9,26,6],
@@ -187,12 +206,12 @@ var NAVTREEINDEX73 =
 "class_ogre_1_1_linear_force_affector_1_1_cmd_force_vector.html":[5,2,6,12,1],
 "class_ogre_1_1_linear_force_affector_1_1_cmd_force_vector.html#ab167fb82f4c0cfff1a772d25ed97732b":[5,2,6,12,1,1],
 "class_ogre_1_1_linear_force_affector_1_1_cmd_force_vector.html#aca502fed2feb27c162f79de66c201b67":[5,2,6,12,1,0],
-"class_ogre_1_1_linear_force_affector_factory.html":[7,0,0,432],
-"class_ogre_1_1_linear_force_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,432,0],
-"class_ogre_1_1_lod0_stripifier.html":[7,0,0,436],
-"class_ogre_1_1_lod0_stripifier.html#a36470f9df4835807557d9a1b58c0e0b8":[7,0,0,436,3],
-"class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[7,0,0,436,1],
-"class_ogre_1_1_lod0_stripifier.html#aaf8b57b5395eed707f960a10a1856d1d":[7,0,0,436,2],
+"class_ogre_1_1_linear_force_affector_factory.html":[7,0,0,433],
+"class_ogre_1_1_linear_force_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,433,0],
+"class_ogre_1_1_lod0_stripifier.html":[7,0,0,437],
+"class_ogre_1_1_lod0_stripifier.html#a36470f9df4835807557d9a1b58c0e0b8":[7,0,0,437,3],
+"class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[7,0,0,437,1],
+"class_ogre_1_1_lod0_stripifier.html#aaf8b57b5395eed707f960a10a1856d1d":[7,0,0,437,2],
 "class_ogre_1_1_lod_collapse_cost.html":[5,1,2,0],
 "class_ogre_1_1_lod_collapse_cost.html#a0544405a072903833e93500006036743":[5,1,2,0,0],
 "class_ogre_1_1_lod_collapse_cost.html#a20750c76335b8ce8045103902da5ba7e":[5,1,2,0,3],
@@ -200,54 +219,35 @@ var NAVTREEINDEX73 =
 "class_ogre_1_1_lod_collapse_cost.html#a4580c69303375413f5a1bb9b0171ac76":[5,1,2,0,4],
 "class_ogre_1_1_lod_collapse_cost.html#a9bbdb780b79f29c37c205a3f05683437":[5,1,2,0,5],
 "class_ogre_1_1_lod_collapse_cost.html#ae76380b7497b62c7baafffe8a618a3d6":[5,1,2,0,2],
-"class_ogre_1_1_lod_collapse_cost_curvature.html":[7,0,0,438],
-"class_ogre_1_1_lod_collapse_cost_curvature.html#a20750c76335b8ce8045103902da5ba7e":[7,0,0,438,3],
-"class_ogre_1_1_lod_collapse_cost_curvature.html#a354e7502246237f033d48fec0adfad4f":[7,0,0,438,1],
-"class_ogre_1_1_lod_collapse_cost_curvature.html#a4580c69303375413f5a1bb9b0171ac76":[7,0,0,438,4],
-"class_ogre_1_1_lod_collapse_cost_curvature.html#a97a4ebc7be0ef5d4d81467edf558eb38":[7,0,0,438,0],
-"class_ogre_1_1_lod_collapse_cost_curvature.html#ae76380b7497b62c7baafffe8a618a3d6":[7,0,0,438,2],
-"class_ogre_1_1_lod_collapse_cost_outside.html":[7,0,0,439],
-"class_ogre_1_1_lod_collapse_cost_outside.html#a20750c76335b8ce8045103902da5ba7e":[7,0,0,439,5],
-"class_ogre_1_1_lod_collapse_cost_outside.html#a4580c69303375413f5a1bb9b0171ac76":[7,0,0,439,6],
-"class_ogre_1_1_lod_collapse_cost_outside.html#a93d759651b8798ed65205cc46224c3c5":[7,0,0,439,3],
-"class_ogre_1_1_lod_collapse_cost_outside.html#aa5cef7538a33a82740003f63b3e9337c":[7,0,0,439,0],
-"class_ogre_1_1_lod_collapse_cost_outside.html#acbd8331275592e9398b749610f6a8c9f":[7,0,0,439,2],
-"class_ogre_1_1_lod_collapse_cost_outside.html#ae76380b7497b62c7baafffe8a618a3d6":[7,0,0,439,4],
-"class_ogre_1_1_lod_collapse_cost_outside.html#af49fbc592c47e4b9521c03148bbbbbbf":[7,0,0,439,1],
-"class_ogre_1_1_lod_collapse_cost_profiler.html":[7,0,0,440],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a1fd0aae8b9143d3627f479447bc5f7c7":[7,0,0,440,1],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a20750c76335b8ce8045103902da5ba7e":[7,0,0,440,5],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[7,0,0,440,0],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a79e3dee5915b3467ee3fe9a4c527a6e9":[7,0,0,440,2],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#ae76380b7497b62c7baafffe8a618a3d6":[7,0,0,440,4],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#aede60fa7c250c08c8365f41ce5f04cd6":[7,0,0,440,3],
-"class_ogre_1_1_lod_collapse_cost_quadric.html":[7,0,0,441],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a4580c69303375413f5a1bb9b0171ac76":[7,0,0,441,4],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a8629e35e547c64c0d0c4961af2f1730a":[7,0,0,441,1],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#abab2944bfc909eb48ae0104039872d71":[7,0,0,441,2],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#ac0ccfe8fff61ddd8ce87bd47bc64dd17":[7,0,0,441,0],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#ae76380b7497b62c7baafffe8a618a3d6":[7,0,0,441,3],
+"class_ogre_1_1_lod_collapse_cost_curvature.html":[7,0,0,439],
+"class_ogre_1_1_lod_collapse_cost_curvature.html#a20750c76335b8ce8045103902da5ba7e":[7,0,0,439,3],
+"class_ogre_1_1_lod_collapse_cost_curvature.html#a354e7502246237f033d48fec0adfad4f":[7,0,0,439,1],
+"class_ogre_1_1_lod_collapse_cost_curvature.html#a4580c69303375413f5a1bb9b0171ac76":[7,0,0,439,4],
+"class_ogre_1_1_lod_collapse_cost_curvature.html#a97a4ebc7be0ef5d4d81467edf558eb38":[7,0,0,439,0],
+"class_ogre_1_1_lod_collapse_cost_curvature.html#ae76380b7497b62c7baafffe8a618a3d6":[7,0,0,439,2],
+"class_ogre_1_1_lod_collapse_cost_outside.html":[7,0,0,440],
+"class_ogre_1_1_lod_collapse_cost_outside.html#a20750c76335b8ce8045103902da5ba7e":[7,0,0,440,5],
+"class_ogre_1_1_lod_collapse_cost_outside.html#a4580c69303375413f5a1bb9b0171ac76":[7,0,0,440,6],
+"class_ogre_1_1_lod_collapse_cost_outside.html#a93d759651b8798ed65205cc46224c3c5":[7,0,0,440,3],
+"class_ogre_1_1_lod_collapse_cost_outside.html#aa5cef7538a33a82740003f63b3e9337c":[7,0,0,440,0],
+"class_ogre_1_1_lod_collapse_cost_outside.html#acbd8331275592e9398b749610f6a8c9f":[7,0,0,440,2],
+"class_ogre_1_1_lod_collapse_cost_outside.html#ae76380b7497b62c7baafffe8a618a3d6":[7,0,0,440,4],
+"class_ogre_1_1_lod_collapse_cost_outside.html#af49fbc592c47e4b9521c03148bbbbbbf":[7,0,0,440,1],
+"class_ogre_1_1_lod_collapse_cost_profiler.html":[7,0,0,441],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a1fd0aae8b9143d3627f479447bc5f7c7":[7,0,0,441,1],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a20750c76335b8ce8045103902da5ba7e":[7,0,0,441,5],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[7,0,0,441,0],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a79e3dee5915b3467ee3fe9a4c527a6e9":[7,0,0,441,2],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#ae76380b7497b62c7baafffe8a618a3d6":[7,0,0,441,4],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#aede60fa7c250c08c8365f41ce5f04cd6":[7,0,0,441,3],
+"class_ogre_1_1_lod_collapse_cost_quadric.html":[7,0,0,442],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a4580c69303375413f5a1bb9b0171ac76":[7,0,0,442,4],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a8629e35e547c64c0d0c4961af2f1730a":[7,0,0,442,1],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#abab2944bfc909eb48ae0104039872d71":[7,0,0,442,2],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#ac0ccfe8fff61ddd8ce87bd47bc64dd17":[7,0,0,442,0],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#ae76380b7497b62c7baafffe8a618a3d6":[7,0,0,442,3],
 "class_ogre_1_1_lod_collapser.html":[5,1,2,1],
 "class_ogre_1_1_lod_collapser.html#a51d851d50ebcee4f77cff26f500ccce7":[5,1,2,1,0],
 "class_ogre_1_1_lod_collapser.html#a8a3dc7a3ba0d2777dd8656429540e8cd":[5,1,2,1,3],
-"class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[5,1,2,1,2],
-"class_ogre_1_1_lod_collapser.html#ad292c42636402fafb2eb193264ca67a4":[5,1,2,1,1],
-"class_ogre_1_1_lod_config_serializer.html":[7,0,0,444],
-"class_ogre_1_1_lod_config_serializer.html#a0f12f84184b32b0d2716667d533e3d1c":[7,0,0,444,3],
-"class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39":[7,0,0,444,0],
-"class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39a10ce3b8f55cba526f6bc8237d8b25cc3":[7,0,0,444,0,2],
-"class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39a7f044c7683a7374276db6e7060f51240":[7,0,0,444,0,1],
-"class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39aed60ca999861d8939cf57f19090c70ef":[7,0,0,444,0,0],
-"class_ogre_1_1_lod_config_serializer.html#a72f631aab3f43aa1ccb441cbbd8cd63c":[7,0,0,444,5],
-"class_ogre_1_1_lod_config_serializer.html#a90888570c5ea11c98e7ea8cfdab52fae":[7,0,0,444,1],
-"class_ogre_1_1_lod_config_serializer.html#ab0d2cd1a61870f28aabbf0bd9d61b350":[7,0,0,444,2],
-"class_ogre_1_1_lod_config_serializer.html#af4e0f6e5ceae25f6fdb735cec0b51069":[7,0,0,444,4],
-"class_ogre_1_1_lod_input_provider.html":[7,0,0,448],
-"class_ogre_1_1_lod_input_provider.html#a551a6f7b7d3e27fccea16452485f5167":[7,0,0,448,0],
-"class_ogre_1_1_lod_input_provider.html#ae09684e1afda55cac84ad037c3f85fc0":[7,0,0,448,1],
-"class_ogre_1_1_lod_input_provider_buffer.html":[7,0,0,449],
-"class_ogre_1_1_lod_input_provider_buffer.html#a4b30960f0593fb75f91deb60cdeb801d":[7,0,0,449,0],
-"class_ogre_1_1_lod_input_provider_buffer.html#ad111c0b02f304bbef104e936e891e7b2":[7,0,0,449,1],
-"class_ogre_1_1_lod_input_provider_mesh.html":[7,0,0,450],
-"class_ogre_1_1_lod_input_provider_mesh.html#a18dc956dd9368ba9f793e4082fc6c93f":[7,0,0,450,0]
+"class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[5,1,2,1,2]
 };
