@@ -1,5 +1,28 @@
 var NAVTREEINDEX84 =
 {
+"class_ogre_1_1_octree_sphere_scene_query.html#a982dda57528c3a3ccaa4d577335ed87c":[5,2,3,9,4],
+"class_ogre_1_1_octree_sphere_scene_query.html#aa80d17ae16dbde77be04d8c050f96f2f":[5,2,3,9,2],
+"class_ogre_1_1_octree_sphere_scene_query.html#ab21e3cfc134292363497701523f87ade":[5,2,3,9,6],
+"class_ogre_1_1_octree_sphere_scene_query.html#abaca8d4d9b59a571e2d8e9a2cac7ce42":[5,2,3,9,13],
+"class_ogre_1_1_octree_sphere_scene_query.html#acceb4087f3a6ed148ae92f7e39fd1179":[5,2,3,9,17],
+"class_ogre_1_1_octree_sphere_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,3,9,16],
+"class_ogre_1_1_octree_sphere_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,3,9,11],
+"class_ogre_1_1_octree_sphere_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,2,3,9,10],
+"class_ogre_1_1_octree_sphere_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,2,3,9,15],
+"class_ogre_1_1_octree_sphere_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,3,9,12],
+"class_ogre_1_1_octree_zone.html":[5,2,4,1],
+"class_ogre_1_1_octree_zone.html#a0256face161bd2d9977bdf4903f25ee0":[5,2,4,1,9],
+"class_ogre_1_1_octree_zone.html#a03add4799fd3bf3cb0f6e8a81a3edd60":[5,2,4,1,12],
+"class_ogre_1_1_octree_zone.html#a0666b7f4ecadd02dca134a800ed6db70":[5,2,4,1,8],
+"class_ogre_1_1_octree_zone.html#a0ffb0e1db964e86afb1a39779d2ec97f":[5,2,4,1,3],
+"class_ogre_1_1_octree_zone.html#a129c7d66b74451efd77177c2f2b54af2":[5,2,4,1,29],
+"class_ogre_1_1_octree_zone.html#a29d50d9c2dbf62ce27bcfaa24406f2a0":[5,2,4,1,5],
+"class_ogre_1_1_octree_zone.html#a2a37e1359bca6c99a205cdec00fdbb56":[5,2,4,1,4],
+"class_ogre_1_1_octree_zone.html#a336085f80c96b69f4bb924e1e2026872":[5,2,4,1,22],
+"class_ogre_1_1_octree_zone.html#a3f2f62ba44ece0239408e0e8e04e0a72":[5,2,4,1,48],
+"class_ogre_1_1_octree_zone.html#a4509a95285b2d62f2988ea8a6030fbbe":[5,2,4,1,16],
+"class_ogre_1_1_octree_zone.html#a484054a38796da25820e41d71fa84d71":[5,2,4,1,25],
+"class_ogre_1_1_octree_zone.html#a48ddafbf9be0202144311004f02536ab":[5,2,4,1,28],
 "class_ogre_1_1_octree_zone.html#a4a3243152a6efbda021f9a77cfe7d756":[5,2,4,1,17],
 "class_ogre_1_1_octree_zone.html#a50973158ea5cf45cdb33643cbffb41d4":[5,2,4,1,7],
 "class_ogre_1_1_octree_zone.html#a56cfd6d3c1d59fe4b05e6755dcab51c9":[5,2,4,1,0],
@@ -59,13 +82,13 @@ var NAVTREEINDEX84 =
 "class_ogre_1_1_octree_zone_factory.html#a6bb27e0f1867d46a819dc485a4507fd8":[5,2,4,3,2],
 "class_ogre_1_1_octree_zone_factory.html#ade0f77212766fe3fe19a1979a1924f1a":[5,2,4,3,1],
 "class_ogre_1_1_octree_zone_factory.html#afb863ab16a3cfebe70c9d4abb629b7e2":[5,2,4,3,5],
-"class_ogre_1_1_octree_zone_plugin.html":[7,0,0,517],
-"class_ogre_1_1_octree_zone_plugin.html#a06462f615fbccf153d56fb0ae8b28de0":[7,0,0,517,3],
-"class_ogre_1_1_octree_zone_plugin.html#a08f0e85f621b1118f44fa8a18861df3f":[7,0,0,517,0],
-"class_ogre_1_1_octree_zone_plugin.html#a28e76b9a177bf5548c04546cfa8d8a86":[7,0,0,517,2],
-"class_ogre_1_1_octree_zone_plugin.html#a610c9077ff70835170347720aafcdb5b":[7,0,0,517,5],
-"class_ogre_1_1_octree_zone_plugin.html#a95629856343f774405e954b5af16dd0e":[7,0,0,517,4],
-"class_ogre_1_1_octree_zone_plugin.html#acf0674262a5a7c4aebd294a9f38ddd7f":[7,0,0,517,1],
+"class_ogre_1_1_octree_zone_plugin.html":[7,0,0,518],
+"class_ogre_1_1_octree_zone_plugin.html#a06462f615fbccf153d56fb0ae8b28de0":[7,0,0,518,3],
+"class_ogre_1_1_octree_zone_plugin.html#a08f0e85f621b1118f44fa8a18861df3f":[7,0,0,518,0],
+"class_ogre_1_1_octree_zone_plugin.html#a28e76b9a177bf5548c04546cfa8d8a86":[7,0,0,518,2],
+"class_ogre_1_1_octree_zone_plugin.html#a610c9077ff70835170347720aafcdb5b":[7,0,0,518,5],
+"class_ogre_1_1_octree_zone_plugin.html#a95629856343f774405e954b5af16dd0e":[7,0,0,518,4],
+"class_ogre_1_1_octree_zone_plugin.html#acf0674262a5a7c4aebd294a9f38ddd7f":[7,0,0,518,1],
 "class_ogre_1_1_optimised_util.html":[5,0,6,14],
 "class_ogre_1_1_optimised_util.html#a431efac44c070695de7011243b13b7af":[5,0,6,14,4],
 "class_ogre_1_1_optimised_util.html#a4f137d0ced0f82abd042d9b4eb99b105":[5,0,6,14,0],
@@ -226,28 +249,5 @@ var NAVTREEINDEX84 =
 "class_ogre_1_1_overlay_container.html#ae7b546ce6736b50bdcd5807d98cf156b":[5,1,3,7,45],
 "class_ogre_1_1_overlay_container.html#ae88216e2bab2a230b25cc8341981a6c1":[5,1,3,7,48],
 "class_ogre_1_1_overlay_container.html#ae944917873dd68126c129f05e51622d3":[5,1,3,7,116],
-"class_ogre_1_1_overlay_container.html#aef91545671c664dcd0511075ac309d36":[5,1,3,7,16],
-"class_ogre_1_1_overlay_container.html#af15092ccb2db4413a5d5a74f02ca5dfd":[5,1,3,7,70],
-"class_ogre_1_1_overlay_container.html#af4378d361e04e03e1ca8c63c73e53fc4":[5,1,3,7,56],
-"class_ogre_1_1_overlay_container.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[5,1,3,7,106],
-"class_ogre_1_1_overlay_container.html#af7360f8bd59d3ffdefcaed91769b17dd":[5,1,3,7,123],
-"class_ogre_1_1_overlay_container.html#afa199b851b646c4a17d182023f2a60ee":[5,1,3,7,11],
-"class_ogre_1_1_overlay_container.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,1,3,7,102],
-"class_ogre_1_1_overlay_container.html#afd5bad2f48558fedb9d76f5547214903":[5,1,3,7,49],
-"class_ogre_1_1_overlay_element.html":[5,1,3,8],
-"class_ogre_1_1_overlay_element.html#a02a099eba37c9f0f0700919535af0821":[5,1,3,8,4],
-"class_ogre_1_1_overlay_element.html#a08d117bf25f011f96d81f1f4ecb25113":[5,1,3,8,79],
-"class_ogre_1_1_overlay_element.html#a0984444e5ea957fea4880a8a2855e5d3":[5,1,3,8,30],
-"class_ogre_1_1_overlay_element.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,1,3,8,95],
-"class_ogre_1_1_overlay_element.html#a0d5508d74e0d742ed04ba5ba6c1a7113":[5,1,3,8,35],
-"class_ogre_1_1_overlay_element.html#a0e3fe5ec8406c5824cd4e4fa25f9e783":[5,1,3,8,66],
-"class_ogre_1_1_overlay_element.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,1,3,8,77],
-"class_ogre_1_1_overlay_element.html#a149ed9dba547535540a515c0936cc1f2":[5,1,3,8,42],
-"class_ogre_1_1_overlay_element.html#a14e63d4c3d587b01ea94904a9e4d1c6b":[5,1,3,8,15],
-"class_ogre_1_1_overlay_element.html#a153af53d919497af7340413866470613":[5,1,3,8,11],
-"class_ogre_1_1_overlay_element.html#a1548c9c20d0c4e4ff2c73590681dbddb":[5,1,3,8,33],
-"class_ogre_1_1_overlay_element.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[5,1,3,8,83],
-"class_ogre_1_1_overlay_element.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[5,1,3,8,81],
-"class_ogre_1_1_overlay_element.html#a1d18a26a0680bd724220ea282722d48c":[5,1,3,8,27],
-"class_ogre_1_1_overlay_element.html#a1e819a321a51a47238428307510559b7":[5,1,3,8,13]
+"class_ogre_1_1_overlay_container.html#aef91545671c664dcd0511075ac309d36":[5,1,3,7,16]
 };
