@@ -1,5 +1,28 @@
 var NAVTREEINDEX85 =
 {
+"class_ogre_1_1_overlay_container.html#af15092ccb2db4413a5d5a74f02ca5dfd":[5,1,3,7,70],
+"class_ogre_1_1_overlay_container.html#af4378d361e04e03e1ca8c63c73e53fc4":[5,1,3,7,56],
+"class_ogre_1_1_overlay_container.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[5,1,3,7,106],
+"class_ogre_1_1_overlay_container.html#af7360f8bd59d3ffdefcaed91769b17dd":[5,1,3,7,123],
+"class_ogre_1_1_overlay_container.html#afa199b851b646c4a17d182023f2a60ee":[5,1,3,7,11],
+"class_ogre_1_1_overlay_container.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,1,3,7,102],
+"class_ogre_1_1_overlay_container.html#afd5bad2f48558fedb9d76f5547214903":[5,1,3,7,49],
+"class_ogre_1_1_overlay_element.html":[5,1,3,8],
+"class_ogre_1_1_overlay_element.html#a02a099eba37c9f0f0700919535af0821":[5,1,3,8,4],
+"class_ogre_1_1_overlay_element.html#a08d117bf25f011f96d81f1f4ecb25113":[5,1,3,8,79],
+"class_ogre_1_1_overlay_element.html#a0984444e5ea957fea4880a8a2855e5d3":[5,1,3,8,30],
+"class_ogre_1_1_overlay_element.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,1,3,8,95],
+"class_ogre_1_1_overlay_element.html#a0d5508d74e0d742ed04ba5ba6c1a7113":[5,1,3,8,35],
+"class_ogre_1_1_overlay_element.html#a0e3fe5ec8406c5824cd4e4fa25f9e783":[5,1,3,8,66],
+"class_ogre_1_1_overlay_element.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,1,3,8,77],
+"class_ogre_1_1_overlay_element.html#a149ed9dba547535540a515c0936cc1f2":[5,1,3,8,42],
+"class_ogre_1_1_overlay_element.html#a14e63d4c3d587b01ea94904a9e4d1c6b":[5,1,3,8,15],
+"class_ogre_1_1_overlay_element.html#a153af53d919497af7340413866470613":[5,1,3,8,11],
+"class_ogre_1_1_overlay_element.html#a1548c9c20d0c4e4ff2c73590681dbddb":[5,1,3,8,33],
+"class_ogre_1_1_overlay_element.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[5,1,3,8,83],
+"class_ogre_1_1_overlay_element.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[5,1,3,8,81],
+"class_ogre_1_1_overlay_element.html#a1d18a26a0680bd724220ea282722d48c":[5,1,3,8,27],
+"class_ogre_1_1_overlay_element.html#a1e819a321a51a47238428307510559b7":[5,1,3,8,13],
 "class_ogre_1_1_overlay_element.html#a1fff3e0b4ad1470a0cb25a73779d3291":[5,1,3,8,17],
 "class_ogre_1_1_overlay_element.html#a25345420a3a217103f2624080cb48f45":[5,1,3,8,57],
 "class_ogre_1_1_overlay_element.html#a278c8fdde2e52a5851bbd308cf3e6180":[5,1,3,8,49],
@@ -172,82 +195,59 @@ var NAVTREEINDEX85 =
 "class_ogre_1_1_overlay_system.html#a0a6a53d54e3215fc2bf2c877fedd47d6":[5,1,3,12,5],
 "class_ogre_1_1_overlay_system.html#a338dd1abf82317692ce7504978c01a5c":[5,1,3,12,6],
 "class_ogre_1_1_overlay_system.html#aed637d7bad94336183321b5ee290751c":[5,1,3,12,4],
-"class_ogre_1_1_overlay_translator_manager.html":[7,0,0,527],
-"class_ogre_1_1_overlay_translator_manager.html#a924ce8c9706841852f0d7b5ee8b2908d":[7,0,0,527,2],
-"class_ogre_1_1_overlay_translator_manager.html#ab6f37f53f37199351afcc3dfd43dc248":[7,0,0,527,1],
-"class_ogre_1_1_overlay_translator_manager.html#ad3f69857ca91de924b42474dbdb06f2a":[7,0,0,527,0],
-"class_ogre_1_1_p_c_plane.html":[7,0,0,563],
-"class_ogre_1_1_p_c_plane.html#a060064e403c405d075786f043bcd37e8":[7,0,0,563,4],
-"class_ogre_1_1_p_c_plane.html#a090aae792b4fecc6e8b1b5810f029edf":[7,0,0,563,16],
-"class_ogre_1_1_p_c_plane.html#a09ed045de29ff480bfaaf8d35549f3b5":[7,0,0,563,6],
-"class_ogre_1_1_p_c_plane.html#a0b88208979cd8ccffd4d91bb8373549f":[7,0,0,563,2],
-"class_ogre_1_1_p_c_plane.html#a13bd791f119b3120bf03fe351b4665e4":[7,0,0,563,17],
-"class_ogre_1_1_p_c_plane.html#a1f019fbfffb03059e03c369b956f1bed":[7,0,0,563,7],
-"class_ogre_1_1_p_c_plane.html#a1f4b68ae4354cd7b0cc63374497461cb":[7,0,0,563,11],
-"class_ogre_1_1_p_c_plane.html#a1f5ace6a3a4bedc91a283895fb77a6a8":[7,0,0,563,18],
-"class_ogre_1_1_p_c_plane.html#a2472dfd80725c2e84b5ef7baa4384c2e":[7,0,0,563,1],
-"class_ogre_1_1_p_c_plane.html#a3f97462d3822f6add8c070048f6c2d92":[7,0,0,563,20],
-"class_ogre_1_1_p_c_plane.html#a513a2379245911d5ed1993d5f25c4bef":[7,0,0,563,15],
-"class_ogre_1_1_p_c_plane.html#a519225d752a20f3459d2f0cc20346468":[7,0,0,563,9],
-"class_ogre_1_1_p_c_plane.html#a699e7fd73bffd447e971c97ca38fe3b0":[7,0,0,563,19],
-"class_ogre_1_1_p_c_plane.html#a6b3f83e82290b617368501cab3c1919a":[7,0,0,563,8],
-"class_ogre_1_1_p_c_plane.html#a6f42638ed66e7661b8b911861fc67b64":[7,0,0,563,5],
-"class_ogre_1_1_p_c_plane.html#a74dab1f3fb059277cd477aa683b238f7":[7,0,0,563,14],
-"class_ogre_1_1_p_c_plane.html#a7f593c4a54f2d424a8f213421895715e":[7,0,0,563,10],
-"class_ogre_1_1_p_c_plane.html#a8e7de1712320968bee111002bc2938b8":[7,0,0,563,21],
-"class_ogre_1_1_p_c_plane.html#a93b10ba23a8142123cbcac6e4094f15c":[7,0,0,563,13],
-"class_ogre_1_1_p_c_plane.html#aa397a61879a2c4ffdc6c237820fae177":[7,0,0,563,12],
-"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bc":[7,0,0,563,0],
-"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bca44420e1c49338ae721f298826e164935":[7,0,0,563,0,3],
-"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bcaad112821a6c39f0097136ba5df53052a":[7,0,0,563,0,0],
-"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bcaaf227c36d02442779fd4600d00580f5e":[7,0,0,563,0,2],
-"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bcac5f2b56ac439b77aad6dfc4031891be5":[7,0,0,563,0,1],
-"class_ogre_1_1_p_c_plane.html#ad3eff30e9736cc380facaa825306dbf2":[7,0,0,563,3],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html":[7,0,0,564],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[7,0,0,564,0],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[7,0,0,564,0,2],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[7,0,0,564,0,1],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[7,0,0,564,0,0],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[7,0,0,564,0,4],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[7,0,0,564,0,3],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[7,0,0,564,10],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a250f90fa7444be8862efac6cde957bfc":[7,0,0,564,8],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a2a94055f8ff9e6056fb656ebbb157a0c":[7,0,0,564,2],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a31008988d5f9e024f7eea013413266d8":[7,0,0,564,4],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a40f55e11da42a7228929bc4cc049e041":[7,0,0,564,9],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a47fac5b11f62901c14b1bd757ea5c14b":[7,0,0,564,16],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[7,0,0,564,11],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a982dda57528c3a3ccaa4d577335ed87c":[7,0,0,564,6],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ab111eceae3a80cc277e83846d58a3ecb":[7,0,0,564,5],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ab95be91b59fd8e1b7097957946a2eb27":[7,0,0,564,3],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#abaca8d4d9b59a571e2d8e9a2cac7ce42":[7,0,0,564,15],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ac3b60af8a02139c85520a92a34920004":[7,0,0,564,1],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ac9f17a2607f960bc1ce451522994960c":[7,0,0,564,7],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#acceb4087f3a6ed148ae92f7e39fd1179":[7,0,0,564,19],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#acffb9330fc3de7109f8274822e362b00":[7,0,0,564,18],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[7,0,0,564,13],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[7,0,0,564,12],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[7,0,0,564,17],
-"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[7,0,0,564,14],
-"class_ogre_1_1_p_c_z_camera.html":[7,0,0,565],
-"class_ogre_1_1_p_c_z_camera.html#a00d4b6eb852e11325a4a237625c5de85":[7,0,0,565,60],
-"class_ogre_1_1_p_c_z_camera.html#a015c3801632c98bca5dbb5aa3da1aa24":[7,0,0,565,212],
-"class_ogre_1_1_p_c_z_camera.html#a01f48775e48b672d7796311f3ffe2930":[7,0,0,565,193],
-"class_ogre_1_1_p_c_z_camera.html#a02f7226a760a99f688fa9791745425ff":[7,0,0,565,91],
-"class_ogre_1_1_p_c_z_camera.html#a034c92d4ddca4da554e698466754f92b":[7,0,0,565,141],
-"class_ogre_1_1_p_c_z_camera.html#a063daea70f27ee80b47a9441b8fa152a":[7,0,0,565,89],
-"class_ogre_1_1_p_c_z_camera.html#a06be74c28a7415a0d09f611ef4a334b4":[7,0,0,565,108],
-"class_ogre_1_1_p_c_z_camera.html#a06f161ae0451be7eaa67e77c296d5631":[7,0,0,565,153],
-"class_ogre_1_1_p_c_z_camera.html#a07264525cc9ddfed69ef46b87e33d16a":[7,0,0,565,85],
-"class_ogre_1_1_p_c_z_camera.html#a08d005383a93a20e7a3b62bce04aa89b":[7,0,0,565,74],
-"class_ogre_1_1_p_c_z_camera.html#a0a0fe2643c8d7d52a18a8f013192064b":[7,0,0,565,166],
-"class_ogre_1_1_p_c_z_camera.html#a0a3632521a6f13e53b4bf1a8d006fb2e":[7,0,0,565,9],
-"class_ogre_1_1_p_c_z_camera.html#a0c554325e4abb582601511be7eed4a01":[7,0,0,565,119],
-"class_ogre_1_1_p_c_z_camera.html#a0c726a0326e8a7d9e80d030541b6bddf":[7,0,0,565,231],
-"class_ogre_1_1_p_c_z_camera.html#a0dd267c6ddf21fc1313962f62579a117":[7,0,0,565,147],
-"class_ogre_1_1_p_c_z_camera.html#a0f6c91af58775cfc445fe647d0be4a74":[7,0,0,565,23],
-"class_ogre_1_1_p_c_z_camera.html#a10602eee33f11f92d137a5677eb56308":[7,0,0,565,151],
-"class_ogre_1_1_p_c_z_camera.html#a1114480a27cfd0ceb4870bacf8bfec7f":[7,0,0,565,140],
-"class_ogre_1_1_p_c_z_camera.html#a132cdf93a3a7fde6dfad0104f9130105":[7,0,0,565,120],
-"class_ogre_1_1_p_c_z_camera.html#a139bdab72bf57abcee42ffefc404e421":[7,0,0,565,127]
+"class_ogre_1_1_overlay_translator_manager.html":[7,0,0,528],
+"class_ogre_1_1_overlay_translator_manager.html#a924ce8c9706841852f0d7b5ee8b2908d":[7,0,0,528,2],
+"class_ogre_1_1_overlay_translator_manager.html#ab6f37f53f37199351afcc3dfd43dc248":[7,0,0,528,1],
+"class_ogre_1_1_overlay_translator_manager.html#ad3f69857ca91de924b42474dbdb06f2a":[7,0,0,528,0],
+"class_ogre_1_1_p_c_plane.html":[7,0,0,564],
+"class_ogre_1_1_p_c_plane.html#a060064e403c405d075786f043bcd37e8":[7,0,0,564,4],
+"class_ogre_1_1_p_c_plane.html#a090aae792b4fecc6e8b1b5810f029edf":[7,0,0,564,16],
+"class_ogre_1_1_p_c_plane.html#a09ed045de29ff480bfaaf8d35549f3b5":[7,0,0,564,6],
+"class_ogre_1_1_p_c_plane.html#a0b88208979cd8ccffd4d91bb8373549f":[7,0,0,564,2],
+"class_ogre_1_1_p_c_plane.html#a13bd791f119b3120bf03fe351b4665e4":[7,0,0,564,17],
+"class_ogre_1_1_p_c_plane.html#a1f019fbfffb03059e03c369b956f1bed":[7,0,0,564,7],
+"class_ogre_1_1_p_c_plane.html#a1f4b68ae4354cd7b0cc63374497461cb":[7,0,0,564,11],
+"class_ogre_1_1_p_c_plane.html#a1f5ace6a3a4bedc91a283895fb77a6a8":[7,0,0,564,18],
+"class_ogre_1_1_p_c_plane.html#a2472dfd80725c2e84b5ef7baa4384c2e":[7,0,0,564,1],
+"class_ogre_1_1_p_c_plane.html#a3f97462d3822f6add8c070048f6c2d92":[7,0,0,564,20],
+"class_ogre_1_1_p_c_plane.html#a513a2379245911d5ed1993d5f25c4bef":[7,0,0,564,15],
+"class_ogre_1_1_p_c_plane.html#a519225d752a20f3459d2f0cc20346468":[7,0,0,564,9],
+"class_ogre_1_1_p_c_plane.html#a699e7fd73bffd447e971c97ca38fe3b0":[7,0,0,564,19],
+"class_ogre_1_1_p_c_plane.html#a6b3f83e82290b617368501cab3c1919a":[7,0,0,564,8],
+"class_ogre_1_1_p_c_plane.html#a6f42638ed66e7661b8b911861fc67b64":[7,0,0,564,5],
+"class_ogre_1_1_p_c_plane.html#a74dab1f3fb059277cd477aa683b238f7":[7,0,0,564,14],
+"class_ogre_1_1_p_c_plane.html#a7f593c4a54f2d424a8f213421895715e":[7,0,0,564,10],
+"class_ogre_1_1_p_c_plane.html#a8e7de1712320968bee111002bc2938b8":[7,0,0,564,21],
+"class_ogre_1_1_p_c_plane.html#a93b10ba23a8142123cbcac6e4094f15c":[7,0,0,564,13],
+"class_ogre_1_1_p_c_plane.html#aa397a61879a2c4ffdc6c237820fae177":[7,0,0,564,12],
+"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bc":[7,0,0,564,0],
+"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bca44420e1c49338ae721f298826e164935":[7,0,0,564,0,3],
+"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bcaad112821a6c39f0097136ba5df53052a":[7,0,0,564,0,0],
+"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bcaaf227c36d02442779fd4600d00580f5e":[7,0,0,564,0,2],
+"class_ogre_1_1_p_c_plane.html#aa5d44b14d6f032f3e0a26e83589180bcac5f2b56ac439b77aad6dfc4031891be5":[7,0,0,564,0,1],
+"class_ogre_1_1_p_c_plane.html#ad3eff30e9736cc380facaa825306dbf2":[7,0,0,564,3],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html":[7,0,0,565],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[7,0,0,565,0],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[7,0,0,565,0,2],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[7,0,0,565,0,1],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[7,0,0,565,0,0],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[7,0,0,565,0,4],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[7,0,0,565,0,3],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[7,0,0,565,10],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a250f90fa7444be8862efac6cde957bfc":[7,0,0,565,8],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a2a94055f8ff9e6056fb656ebbb157a0c":[7,0,0,565,2],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a31008988d5f9e024f7eea013413266d8":[7,0,0,565,4],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a40f55e11da42a7228929bc4cc049e041":[7,0,0,565,9],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a47fac5b11f62901c14b1bd757ea5c14b":[7,0,0,565,16],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[7,0,0,565,11],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#a982dda57528c3a3ccaa4d577335ed87c":[7,0,0,565,6],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ab111eceae3a80cc277e83846d58a3ecb":[7,0,0,565,5],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ab95be91b59fd8e1b7097957946a2eb27":[7,0,0,565,3],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#abaca8d4d9b59a571e2d8e9a2cac7ce42":[7,0,0,565,15],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ac3b60af8a02139c85520a92a34920004":[7,0,0,565,1],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ac9f17a2607f960bc1ce451522994960c":[7,0,0,565,7],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#acceb4087f3a6ed148ae92f7e39fd1179":[7,0,0,565,19],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#acffb9330fc3de7109f8274822e362b00":[7,0,0,565,18],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[7,0,0,565,13],
+"class_ogre_1_1_p_c_z_axis_aligned_box_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[7,0,0,565,12]
 };
