@@ -1,5 +1,28 @@
 var NAVTREEINDEX98 =
 {
+"class_ogre_1_1_pose.html#aab53719cd5a035c0b5ca9301c9927a9a":[5,0,0,14,1],
+"class_ogre_1_1_pose.html#aac73c679713e93a8dad3dfed46038809":[5,0,0,14,13],
+"class_ogre_1_1_pose.html#ab72ff022a57f41a11e33edd782089382":[5,0,0,14,18],
+"class_ogre_1_1_pose.html#ab7830f6ad3feaf3740a8e6477d97cef5":[5,0,0,14,2],
+"class_ogre_1_1_pose.html#ab8cf923ad91fc1c3e6e19259e07f9ec0":[5,0,0,14,3],
+"class_ogre_1_1_pose.html#ac6207382101e044739bc4c9f55304229":[5,0,0,14,20],
+"class_ogre_1_1_pose.html#ac92652fd8e7e7be224a77492004bf285":[5,0,0,14,6],
+"class_ogre_1_1_pose.html#ae3772f4da2c20736eead7c6a8c39703e":[5,0,0,14,21],
+"class_ogre_1_1_pose.html#ae61acae74c70fb3646902ce5f04ee3e7":[5,0,0,14,10],
+"class_ogre_1_1_pose.html#af88898dd4ae88f28fe8815137a308c51":[5,0,0,14,11],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html":[5,0,2,57],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a298f1b128634bef5d5964726097278e8":[5,0,2,57,2],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a403617d0cc5f8e8bffccca4012dd6fb1":[5,0,2,57,3],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a7fe96a9aaef9359e8077bdb0c234db2f":[5,0,2,57,1],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6":[5,0,2,57,4],
+"class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#af8a79ba69d0bd18034a45efd19e6a43f":[5,0,2,57,0],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html":[5,0,2,58],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a4e7e3b1f5f8a2d9005f243729cd5367b":[5,0,2,58,0],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a51a223dead21c6a2ddfa66f75d508553":[5,0,2,58,1],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#a6743ef063ddf25f8ccaa1fc95465e0c6":[5,0,2,58,3],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#ab4e31bae208b7526e183369be3acb410":[5,0,2,58,2],
+"class_ogre_1_1_process_name_exclusion_script_compiler_event.html#ae83d6b4f8c27207b09f2bae4e7c51ce6":[5,0,2,58,4],
+"class_ogre_1_1_process_resource_name_script_compiler_event.html":[5,0,2,59],
 "class_ogre_1_1_process_resource_name_script_compiler_event.html#a3c4bdfcd9e3758d5281dfe0ed7d8e5fc":[5,0,2,59,4],
 "class_ogre_1_1_process_resource_name_script_compiler_event.html#a93b2fb455dd0deec91a7f16a3a91c55e":[5,0,2,59,1],
 "class_ogre_1_1_process_resource_name_script_compiler_event.html#a9df601b04eff55b09762484c8eac6082":[5,0,2,59,3],
@@ -226,28 +249,5 @@ var NAVTREEINDEX98 =
 "class_ogre_1_1_quaternion.html#a3c41f8bb4147db31ff9674a70de1aad5":[5,0,6,18,23],
 "class_ogre_1_1_quaternion.html#a3ccc60338011887023b397a02a7f3336":[5,0,6,18,5],
 "class_ogre_1_1_quaternion.html#a441b8d52549e1dedec27420325a313ef":[5,0,6,18,55],
-"class_ogre_1_1_quaternion.html#a44f3c000c8f1ea2759c2e724e04bf86b":[5,0,6,18,54],
-"class_ogre_1_1_quaternion.html#a4f89136f9dcb79fef8c47dc418e3e55f":[5,0,6,18,38],
-"class_ogre_1_1_quaternion.html#a54dcd575915c7b7ddb65b8cb249de521":[5,0,6,18,7],
-"class_ogre_1_1_quaternion.html#a58a45c5dd46ceee8dbf81dfced570dbe":[5,0,6,18,21],
-"class_ogre_1_1_quaternion.html#a5e0706b3a46bb11f8e617a434ca5a9cb":[5,0,6,18,27],
-"class_ogre_1_1_quaternion.html#a5f43da8b8aa579e02035eecff89e16a5":[5,0,6,18,48],
-"class_ogre_1_1_quaternion.html#a5f764e1243eee86bccf7a435d310b778":[5,0,6,18,51],
-"class_ogre_1_1_quaternion.html#a6005735392c9b07901b8fe160c959f46":[5,0,6,18,13],
-"class_ogre_1_1_quaternion.html#a60829c0f8f2a36602ab5fdbb1a79b635":[5,0,6,18,52],
-"class_ogre_1_1_quaternion.html#a6367b543cf0d073d893139dd503b4fbd":[5,0,6,18,24],
-"class_ogre_1_1_quaternion.html#a6b53296360cc166c62533cff8f1edcc2":[5,0,6,18,53],
-"class_ogre_1_1_quaternion.html#a7ad7ad40e38bf351485c2a906c3949bb":[5,0,6,18,17],
-"class_ogre_1_1_quaternion.html#a7f25c623d95186b58f6367dcd097a5ba":[5,0,6,18,3],
-"class_ogre_1_1_quaternion.html#a814829e953cbf810c80a8b87626f6324":[5,0,6,18,15],
-"class_ogre_1_1_quaternion.html#a821a464cce9a81d5d20c620025043851":[5,0,6,18,36],
-"class_ogre_1_1_quaternion.html#a838d0736819d496073d99f3f74d0cac1":[5,0,6,18,47],
-"class_ogre_1_1_quaternion.html#a88535c5b20c8c5df90609ae90c5d775b":[5,0,6,18,9],
-"class_ogre_1_1_quaternion.html#a96623e9d56a68a171b3dd3d98bf5f3c4":[5,0,6,18,8],
-"class_ogre_1_1_quaternion.html#a98993e6f63209a39149d132623bbf41b":[5,0,6,18,26],
-"class_ogre_1_1_quaternion.html#a9b45997a81d85662350808b7043d535d":[5,0,6,18,1],
-"class_ogre_1_1_quaternion.html#a9e14e6aa96e714397b31929299ca681d":[5,0,6,18,32],
-"class_ogre_1_1_quaternion.html#aa4915f1a8047e3c8a0a9c380fe3ae695":[5,0,6,18,22],
-"class_ogre_1_1_quaternion.html#aa7328cd3883a92ee9c9322805d038f11":[5,0,6,18,58],
-"class_ogre_1_1_quaternion.html#aac3debd2245b0dcefff4ce2fda46eef1":[5,0,6,18,25]
+"class_ogre_1_1_quaternion.html#a44f3c000c8f1ea2759c2e724e04bf86b":[5,0,6,18,54]
 };
