@@ -1,5 +1,28 @@
 var NAVTREEINDEX99 =
 {
+"class_ogre_1_1_quaternion.html#a4f89136f9dcb79fef8c47dc418e3e55f":[5,0,6,18,38],
+"class_ogre_1_1_quaternion.html#a54dcd575915c7b7ddb65b8cb249de521":[5,0,6,18,7],
+"class_ogre_1_1_quaternion.html#a58a45c5dd46ceee8dbf81dfced570dbe":[5,0,6,18,21],
+"class_ogre_1_1_quaternion.html#a5e0706b3a46bb11f8e617a434ca5a9cb":[5,0,6,18,27],
+"class_ogre_1_1_quaternion.html#a5f43da8b8aa579e02035eecff89e16a5":[5,0,6,18,48],
+"class_ogre_1_1_quaternion.html#a5f764e1243eee86bccf7a435d310b778":[5,0,6,18,51],
+"class_ogre_1_1_quaternion.html#a6005735392c9b07901b8fe160c959f46":[5,0,6,18,13],
+"class_ogre_1_1_quaternion.html#a60829c0f8f2a36602ab5fdbb1a79b635":[5,0,6,18,52],
+"class_ogre_1_1_quaternion.html#a6367b543cf0d073d893139dd503b4fbd":[5,0,6,18,24],
+"class_ogre_1_1_quaternion.html#a6b53296360cc166c62533cff8f1edcc2":[5,0,6,18,53],
+"class_ogre_1_1_quaternion.html#a7ad7ad40e38bf351485c2a906c3949bb":[5,0,6,18,17],
+"class_ogre_1_1_quaternion.html#a7f25c623d95186b58f6367dcd097a5ba":[5,0,6,18,3],
+"class_ogre_1_1_quaternion.html#a814829e953cbf810c80a8b87626f6324":[5,0,6,18,15],
+"class_ogre_1_1_quaternion.html#a821a464cce9a81d5d20c620025043851":[5,0,6,18,36],
+"class_ogre_1_1_quaternion.html#a838d0736819d496073d99f3f74d0cac1":[5,0,6,18,47],
+"class_ogre_1_1_quaternion.html#a88535c5b20c8c5df90609ae90c5d775b":[5,0,6,18,9],
+"class_ogre_1_1_quaternion.html#a96623e9d56a68a171b3dd3d98bf5f3c4":[5,0,6,18,8],
+"class_ogre_1_1_quaternion.html#a98993e6f63209a39149d132623bbf41b":[5,0,6,18,26],
+"class_ogre_1_1_quaternion.html#a9b45997a81d85662350808b7043d535d":[5,0,6,18,1],
+"class_ogre_1_1_quaternion.html#a9e14e6aa96e714397b31929299ca681d":[5,0,6,18,32],
+"class_ogre_1_1_quaternion.html#aa4915f1a8047e3c8a0a9c380fe3ae695":[5,0,6,18,22],
+"class_ogre_1_1_quaternion.html#aa7328cd3883a92ee9c9322805d038f11":[5,0,6,18,58],
+"class_ogre_1_1_quaternion.html#aac3debd2245b0dcefff4ce2fda46eef1":[5,0,6,18,25],
 "class_ogre_1_1_quaternion.html#aaf249bc76b399f92c0c2f93377b032ab":[5,0,6,18,43],
 "class_ogre_1_1_quaternion.html#ab0c47f1a7308ac4c17db9f9ddb6e4a72":[5,0,6,18,45],
 "class_ogre_1_1_quaternion.html#ab58dc0c4c04d0579ce9321a719f10d5c":[5,0,6,18,0],
@@ -226,28 +249,5 @@ var NAVTREEINDEX99 =
 "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312a1749fc49b1811bf3f129c722a6e8bd51":[5,1,6,5,0,4],
 "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312a9b746851560ab52d22335755dd36a0ea":[5,1,6,5,0,2],
 "class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312aa27b75d58d2ae680d71d5eda917c5783":[5,1,6,5,0,8],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312aacb3f8c7623415a9398f1d0aeb0849d9":[5,1,6,5,0,6],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312abfddaa99b1d15933e549af52af916c86":[5,1,6,5,0,5],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312ac887733af706c0769dcbb9215f7e8b50":[5,1,6,5,0,1],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312ace9a03298936fc08b7474848ca2ce7b3":[5,1,6,5,0,0],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312ad9ee9f8d6b6508f5e0402140afe2f655":[5,1,6,5,0,3],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312af67c3c93adcb32edbb0b93fa6ac21ac0":[5,1,6,5,0,7],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#ab8ed4fa20a94d4dc3b964ee20d56769f":[5,1,6,5,12],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#aeacadad2424b2f76c78a6c7b86c31ead":[5,1,6,5,5],
-"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#aefb06f44383244d59e3832f691d9f7b6":[5,1,6,5,14],
-"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html":[5,1,6,6],
-"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#ga1bb9cbae97b99f6ed962b2f87a89e04d":[5,1,6,6,7],
-"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#ga3a272a71bc57581c22597533d085c10c":[5,1,6,6,6],
-"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#ga6bec48df043c761525c10fa1c3805208":[5,1,6,6,8],
-"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#ga85e711c9def8444e407820c07e23d126":[5,1,6,6,4],
-"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#ga9f6040d44ac57c6bdb187bc111716aa7":[5,1,6,6,10],
-"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#gaed668a1eb73bffe240faec2e174701c7":[5,1,6,6,9],
-"class_ogre_1_1_r_t_shader_1_1_dual_quaternion_skinning.html#gafa9516c0d0a2b16f3dae733a989b844e":[5,1,6,6,5],
-"class_ogre_1_1_r_t_shader_1_1_f_f_p_alpha_test.html":[7,0,0,2,7],
-"class_ogre_1_1_r_t_shader_1_1_f_f_p_alpha_test.html#a282fdd1db596a8231050b57da209c4e2":[7,0,0,2,7,2],
-"class_ogre_1_1_r_t_shader_1_1_f_f_p_alpha_test.html#a3492abd3bca55e04d591cf59e6111c00":[7,0,0,2,7,3],
-"class_ogre_1_1_r_t_shader_1_1_f_f_p_alpha_test.html#a45437f54494aff2e12d9ed2bb0b9f61c":[7,0,0,2,7,1],
-"class_ogre_1_1_r_t_shader_1_1_f_f_p_alpha_test.html#a4b43c261946926ebbc6456deccc6697a":[7,0,0,2,7,5],
-"class_ogre_1_1_r_t_shader_1_1_f_f_p_alpha_test.html#a9d34ec312d5b8a627be41da5b57382eb":[7,0,0,2,7,7],
-"class_ogre_1_1_r_t_shader_1_1_f_f_p_alpha_test.html#aa73560a3f1b9117cb8b438867848c255":[7,0,0,2,7,6]
+"class_ogre_1_1_r_t_shader_1_1_const_parameter.html#a91fc3614f191bebf0461676a03750312aacb3f8c7623415a9398f1d0aeb0849d9":[5,1,6,5,0,6]
 };
