@@ -24,7 +24,7 @@ var searchData=
   ['any',['Any',['../class_ogre_1_1_any.html',1,'Ogre']]],
   ['anynumeric',['AnyNumeric',['../class_ogre_1_1_any_numeric.html',1,'Ogre']]],
   ['apkfilesystemarchivefactory',['APKFileSystemArchiveFactory',['../class_ogre_1_1_a_p_k_file_system_archive_factory.html',1,'Ogre']]],
-  ['applicationcontext',['ApplicationContext',['../class_ogre_bites_1_1_application_context.html',1,'OgreBites']]],
+  ['applicationcontextbase',['ApplicationContextBase',['../class_ogre_bites_1_1_application_context_base.html',1,'OgreBites']]],
   ['archive',['Archive',['../class_ogre_1_1_archive.html',1,'Ogre']]],
   ['archivefactory',['ArchiveFactory',['../class_ogre_1_1_archive_factory.html',1,'Ogre']]],
   ['archivemanager',['ArchiveManager',['../class_ogre_1_1_archive_manager.html',1,'Ogre']]],
