@@ -35,8 +35,8 @@ var searchData=
   ['sgtechniqueresolverlistener',['SGTechniqueResolverListener',['../class_ogre_bites_1_1_s_g_technique_resolver_listener.html',1,'OgreBites']]],
   ['shadergenerator',['ShaderGenerator',['../class_ogre_1_1_r_t_shader_1_1_shader_generator.html',1,'Ogre::RTShader::ShaderGenerator'],['../class_ogre_1_1_shader_generator.html',1,'Ogre::ShaderGenerator']]],
   ['shaderhelper',['ShaderHelper',['../class_ogre_1_1_shader_helper.html',1,'Ogre']]],
-  ['shaderhelpercg',['ShaderHelperCg',['../class_ogre_1_1_shader_helper_cg.html',1,'Ogre']]],
-  ['shaderhelperglsl',['ShaderHelperGLSL',['../class_ogre_1_1_shader_helper_g_l_s_l.html',1,'Ogre']]],
+  ['shaderhelpercg',['ShaderHelperCg',['../struct_ogre_1_1_shader_helper_cg.html',1,'Ogre']]],
+  ['shaderhelperglsl',['ShaderHelperGLSL',['../struct_ogre_1_1_shader_helper_g_l_s_l.html',1,'Ogre']]],
   ['shadermanager',['ShaderManager',['../class_ogre_1_1_shader_manager.html',1,'Ogre']]],
   ['shaderpiecesmanager',['ShaderPiecesManager',['../class_ogre_1_1_shader_pieces_manager.html',1,'Ogre']]],
   ['shaderprogramwritercgfactory',['ShaderProgramWriterCGFactory',['../class_ogre_1_1_r_t_shader_1_1_shader_program_writer_c_g_factory.html',1,'Ogre::RTShader']]],
@@ -48,7 +48,6 @@ var searchData=
   ['shadowcaster',['ShadowCaster',['../class_ogre_1_1_shadow_caster.html',1,'Ogre']]],
   ['shadowrenderable',['ShadowRenderable',['../class_ogre_1_1_shadow_renderable.html',1,'Ogre']]],
   ['shadowtextureconfig',['ShadowTextureConfig',['../struct_ogre_1_1_shadow_texture_config.html',1,'Ogre']]],
-  ['shadowtexturemanager',['ShadowTextureManager',['../class_ogre_1_1_shadow_texture_manager.html',1,'Ogre']]],
   ['sharedptr',['SharedPtr',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20abstractnodelist_20_3e',['SharedPtr&lt; AbstractNodeList &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20animablevalue_20_3e',['SharedPtr&lt; AnimableValue &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
@@ -60,6 +59,7 @@ var searchData=
   ['sharedptr_3c_20gpulogicalbufferstruct_20_3e',['SharedPtr&lt; GpuLogicalBufferStruct &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20gpunamedconstants_20_3e',['SharedPtr&lt; GpuNamedConstants &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20gpuprogram_20_3e',['SharedPtr&lt; GpuProgram &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
+  ['sharedptr_3c_20gpuprogramparameters_20_3e',['SharedPtr&lt; GpuProgramParameters &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20gpusharedparameters_20_3e',['SharedPtr&lt; GpuSharedParameters &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20hardwareindexbuffer_20_3e',['SharedPtr&lt; HardwareIndexBuffer &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
   ['sharedptr_3c_20hardwareuniformbuffer_20_3e',['SharedPtr&lt; HardwareUniformBuffer &gt;',['../class_ogre_1_1_shared_ptr.html',1,'Ogre']]],
@@ -104,7 +104,6 @@ var searchData=
   ['singleton_3c_20distancelodspherestrategy_20_3e',['Singleton&lt; DistanceLodSphereStrategy &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20dynlibmanager_20_3e',['Singleton&lt; DynLibManager &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20externaltexturesourcemanager_20_3e',['Singleton&lt; ExternalTextureSourceManager &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
-  ['singleton_3c_20ffprenderstatebuilder_20_3e',['Singleton&lt; FFPRenderStateBuilder &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20fontmanager_20_3e',['Singleton&lt; FontManager &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20glrttmanager_20_3e',['Singleton&lt; GLRTTManager &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20glslesprogrammanager_20_3e',['Singleton&lt; GLSLESProgramManager &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
@@ -137,7 +136,6 @@ var searchData=
   ['singleton_3c_20screenratiopixelcountlodstrategy_20_3e',['Singleton&lt; ScreenRatioPixelCountLodStrategy &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20scriptcompilermanager_20_3e',['Singleton&lt; ScriptCompilerManager &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20shadergenerator_20_3e',['Singleton&lt; ShaderGenerator &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
-  ['singleton_3c_20shadowtexturemanager_20_3e',['Singleton&lt; ShadowTextureManager &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20skeletonmanager_20_3e',['Singleton&lt; SkeletonManager &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20terrainglobaloptions_20_3e',['Singleton&lt; TerrainGlobalOptions &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
   ['singleton_3c_20textureatlassamplerfactory_20_3e',['Singleton&lt; TextureAtlasSamplerFactory &gt;',['../class_ogre_1_1_singleton.html',1,'Ogre']]],
@@ -161,7 +159,6 @@ var searchData=
   ['smallvectorimpl',['SmallVectorImpl',['../class_ogre_1_1_small_vector_impl.html',1,'Ogre']]],
   ['smallvectorimpl_3c_20edge_20_3e',['SmallVectorImpl&lt; Edge &gt;',['../class_ogre_1_1_small_vector_impl.html',1,'Ogre']]],
   ['smallvectorimpl_3c_20triangle_20_2a_20_3e',['SmallVectorImpl&lt; Triangle * &gt;',['../class_ogre_1_1_small_vector_impl.html',1,'Ogre']]],
-  ['smallvectorimpl_3c_20triangle_20_2a_3e',['SmallVectorImpl&lt; Triangle *&gt;',['../class_ogre_1_1_small_vector_impl.html',1,'Ogre']]],
   ['smallvectortemplatebase',['SmallVectorTemplateBase',['../class_ogre_1_1_small_vector_template_base.html',1,'Ogre']]],
   ['smallvectortemplatebase_3c_20edge_2c_20ispodlike_3c_20edge_20_3e_3a_3avalue_20_3e',['SmallVectorTemplateBase&lt; Edge, isPodLike&lt; Edge &gt;::value &gt;',['../class_ogre_1_1_small_vector_template_base.html',1,'Ogre']]],
   ['smallvectortemplatebase_3c_20t_2c_20ispodlike_3c_20t_20_3e_3a_3avalue_20_3e',['SmallVectorTemplateBase&lt; T, isPodLike&lt; T &gt;::value &gt;',['../class_ogre_1_1_small_vector_template_base.html',1,'Ogre']]],
