@@ -21,7 +21,6 @@ var searchData=
   ['cmdalphaadjust',['CmdAlphaAdjust',['../class_ogre_1_1_colour_fader_affector_1_1_cmd_alpha_adjust.html',1,'Ogre::ColourFaderAffector']]],
   ['cmdalphaadjust1',['CmdAlphaAdjust1',['../class_ogre_1_1_colour_fader_affector2_1_1_cmd_alpha_adjust1.html',1,'Ogre::ColourFaderAffector2']]],
   ['cmdalphaadjust2',['CmdAlphaAdjust2',['../class_ogre_1_1_colour_fader_affector2_1_1_cmd_alpha_adjust2.html',1,'Ogre::ColourFaderAffector2']]],
-  ['cmdangle',['CmdAngle',['../class_ogre_1_1_emitter_commands_1_1_cmd_angle.html',1,'Ogre::EmitterCommands']]],
   ['cmdargs',['CmdArgs',['../class_ogre_1_1_cg_program_1_1_cmd_args.html',1,'Ogre::CgProgram']]],
   ['cmdassemblercode',['CmdAssemblerCode',['../class_ogre_1_1_d3_d9_h_l_s_l_program_1_1_cmd_assembler_code.html',1,'Ogre::D3D9HLSLProgram']]],
   ['cmdattach',['CmdAttach',['../class_ogre_1_1_g_l_s_l_shader_common_1_1_cmd_attach.html',1,'Ogre::GLSLShaderCommon']]],
@@ -45,11 +44,9 @@ var searchData=
   ['cmdbounce',['CmdBounce',['../class_ogre_1_1_deflector_plane_affector_1_1_cmd_bounce.html',1,'Ogre::DeflectorPlaneAffector']]],
   ['cmdcaption',['CmdCaption',['../class_ogre_1_1_overlay_element_commands_1_1_cmd_caption.html',1,'Ogre::OverlayElementCommands::CmdCaption'],['../class_ogre_1_1_text_area_overlay_element_1_1_cmd_caption.html',1,'Ogre::TextAreaOverlayElement::CmdCaption']]],
   ['cmdcharheight',['CmdCharHeight',['../class_ogre_1_1_text_area_overlay_element_1_1_cmd_char_height.html',1,'Ogre::TextAreaOverlayElement']]],
-  ['cmdcolour',['CmdColour',['../class_ogre_1_1_emitter_commands_1_1_cmd_colour.html',1,'Ogre::EmitterCommands::CmdColour'],['../class_ogre_1_1_text_area_overlay_element_1_1_cmd_colour.html',1,'Ogre::TextAreaOverlayElement::CmdColour']]],
+  ['cmdcolour',['CmdColour',['../class_ogre_1_1_text_area_overlay_element_1_1_cmd_colour.html',1,'Ogre::TextAreaOverlayElement']]],
   ['cmdcolouradjust',['CmdColourAdjust',['../class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html',1,'Ogre::ColourInterpolatorAffector']]],
   ['cmdcolourbottom',['CmdColourBottom',['../class_ogre_1_1_text_area_overlay_element_1_1_cmd_colour_bottom.html',1,'Ogre::TextAreaOverlayElement']]],
-  ['cmdcolourrangeend',['CmdColourRangeEnd',['../class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html',1,'Ogre::EmitterCommands']]],
-  ['cmdcolourrangestart',['CmdColourRangeStart',['../class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_start.html',1,'Ogre::EmitterCommands']]],
   ['cmdcolourtop',['CmdColourTop',['../class_ogre_1_1_text_area_overlay_element_1_1_cmd_colour_top.html',1,'Ogre::TextAreaOverlayElement']]],
   ['cmdcolumnmajormatrices',['CmdColumnMajorMatrices',['../class_ogre_1_1_d3_d11_h_l_s_l_program_1_1_cmd_column_major_matrices.html',1,'Ogre::D3D11HLSLProgram::CmdColumnMajorMatrices'],['../class_ogre_1_1_d3_d9_gpu_program_1_1_cmd_column_major_matrices.html',1,'Ogre::D3D9GpuProgram::CmdColumnMajorMatrices'],['../class_ogre_1_1_d3_d9_h_l_s_l_program_1_1_cmd_column_major_matrices.html',1,'Ogre::D3D9HLSLProgram::CmdColumnMajorMatrices'],['../class_ogre_1_1_g_l_s_l_shader_common_1_1_cmd_column_major_matrices.html',1,'Ogre::GLSLShaderCommon::CmdColumnMajorMatrices']]],
   ['cmdcommondirection',['CmdCommonDirection',['../class_ogre_1_1_billboard_particle_renderer_1_1_cmd_common_direction.html',1,'Ogre::BillboardParticleRenderer']]],
@@ -57,11 +54,6 @@ var searchData=
   ['cmdcull',['CmdCull',['../class_ogre_1_1_particle_system_1_1_cmd_cull.html',1,'Ogre::ParticleSystem']]],
   ['cmddelegate',['CmdDelegate',['../class_ogre_1_1_unified_high_level_gpu_program_1_1_cmd_delegate.html',1,'Ogre::UnifiedHighLevelGpuProgram']]],
   ['cmddepth',['CmdDepth',['../class_ogre_1_1_area_emitter_1_1_cmd_depth.html',1,'Ogre::AreaEmitter']]],
-  ['cmddirection',['CmdDirection',['../class_ogre_1_1_emitter_commands_1_1_cmd_direction.html',1,'Ogre::EmitterCommands']]],
-  ['cmddirpositionref',['CmdDirPositionRef',['../class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html',1,'Ogre::EmitterCommands']]],
-  ['cmdduration',['CmdDuration',['../class_ogre_1_1_emitter_commands_1_1_cmd_duration.html',1,'Ogre::EmitterCommands']]],
-  ['cmdemissionrate',['CmdEmissionRate',['../class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html',1,'Ogre::EmitterCommands']]],
-  ['cmdemittedemitter',['CmdEmittedEmitter',['../class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html',1,'Ogre::EmitterCommands']]],
   ['cmdemittedemitterquota',['CmdEmittedEmitterQuota',['../class_ogre_1_1_particle_system_1_1_cmd_emitted_emitter_quota.html',1,'Ogre::ParticleSystem']]],
   ['cmdenablebackwardscompatibility',['CmdEnableBackwardsCompatibility',['../class_ogre_1_1_d3_d11_h_l_s_l_program_1_1_cmd_enable_backwards_compatibility.html',1,'Ogre::D3D11HLSLProgram']]],
   ['cmdentrypoint',['CmdEntryPoint',['../class_ogre_1_1_cg_program_1_1_cmd_entry_point.html',1,'Ogre::CgProgram::CmdEntryPoint'],['../class_ogre_1_1_d3_d11_h_l_s_l_program_1_1_cmd_entry_point.html',1,'Ogre::D3D11HLSLProgram::CmdEntryPoint'],['../class_ogre_1_1_d3_d9_h_l_s_l_program_1_1_cmd_entry_point.html',1,'Ogre::D3D9HLSLProgram::CmdEntryPoint'],['../class_ogre_1_1_g_l_s_l_e_s_cg_program_1_1_cmd_entry_point.html',1,'Ogre::GLSLESCgProgram::CmdEntryPoint']]],
@@ -80,32 +72,19 @@ var searchData=
   ['cmdinnery',['CmdInnerY',['../class_ogre_1_1_hollow_ellipsoid_emitter_1_1_cmd_inner_y.html',1,'Ogre::HollowEllipsoidEmitter::CmdInnerY'],['../class_ogre_1_1_ring_emitter_1_1_cmd_inner_y.html',1,'Ogre::RingEmitter::CmdInnerY']]],
   ['cmdinnerz',['CmdInnerZ',['../class_ogre_1_1_hollow_ellipsoid_emitter_1_1_cmd_inner_z.html',1,'Ogre::HollowEllipsoidEmitter']]],
   ['cmdinputfilename',['CmdInputFileName',['../class_ogre_1_1_external_texture_source_1_1_cmd_input_file_name.html',1,'Ogre::ExternalTextureSource']]],
-  ['cmdinputoperationtype',['CmdInputOperationType',['../class_ogre_1_1_g_l_s_l_shader_common_1_1_cmd_input_operation_type.html',1,'Ogre::GLSLShaderCommon']]],
   ['cmditerationinterval',['CmdIterationInterval',['../class_ogre_1_1_particle_system_1_1_cmd_iteration_interval.html',1,'Ogre::ParticleSystem']]],
   ['cmdkeepvelocity',['CmdKeepVelocity',['../class_ogre_1_1_direction_randomiser_affector_1_1_cmd_keep_velocity.html',1,'Ogre::DirectionRandomiserAffector']]],
   ['cmdleft',['CmdLeft',['../class_ogre_1_1_overlay_element_commands_1_1_cmd_left.html',1,'Ogre::OverlayElementCommands']]],
   ['cmdlocalspace',['CmdLocalSpace',['../class_ogre_1_1_particle_system_1_1_cmd_local_space.html',1,'Ogre::ParticleSystem']]],
   ['cmdmaterial',['CmdMaterial',['../class_ogre_1_1_overlay_element_commands_1_1_cmd_material.html',1,'Ogre::OverlayElementCommands::CmdMaterial'],['../class_ogre_1_1_particle_system_1_1_cmd_material.html',1,'Ogre::ParticleSystem::CmdMaterial']]],
-  ['cmdmaxduration',['CmdMaxDuration',['../class_ogre_1_1_emitter_commands_1_1_cmd_max_duration.html',1,'Ogre::EmitterCommands']]],
-  ['cmdmaxoutputvertices',['CmdMaxOutputVertices',['../class_ogre_1_1_g_l_s_l_shader_common_1_1_cmd_max_output_vertices.html',1,'Ogre::GLSLShaderCommon']]],
-  ['cmdmaxrepeatdelay',['CmdMaxRepeatDelay',['../class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html',1,'Ogre::EmitterCommands']]],
-  ['cmdmaxttl',['CmdMaxTTL',['../class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html',1,'Ogre::EmitterCommands']]],
-  ['cmdmaxvelocity',['CmdMaxVelocity',['../class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html',1,'Ogre::EmitterCommands']]],
   ['cmdmetricsmode',['CmdMetricsMode',['../class_ogre_1_1_overlay_element_commands_1_1_cmd_metrics_mode.html',1,'Ogre::OverlayElementCommands']]],
   ['cmdmicrocode',['CmdMicrocode',['../class_ogre_1_1_d3_d9_h_l_s_l_program_1_1_cmd_microcode.html',1,'Ogre::D3D9HLSLProgram']]],
-  ['cmdminduration',['CmdMinDuration',['../class_ogre_1_1_emitter_commands_1_1_cmd_min_duration.html',1,'Ogre::EmitterCommands']]],
-  ['cmdminrepeatdelay',['CmdMinRepeatDelay',['../class_ogre_1_1_emitter_commands_1_1_cmd_min_repeat_delay.html',1,'Ogre::EmitterCommands']]],
-  ['cmdminttl',['CmdMinTTL',['../class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html',1,'Ogre::EmitterCommands']]],
-  ['cmdminvelocity',['CmdMinVelocity',['../class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html',1,'Ogre::EmitterCommands']]],
-  ['cmdname',['CmdName',['../class_ogre_1_1_emitter_commands_1_1_cmd_name.html',1,'Ogre::EmitterCommands']]],
   ['cmdnonvisibletimeout',['CmdNonvisibleTimeout',['../class_ogre_1_1_particle_system_1_1_cmd_nonvisible_timeout.html',1,'Ogre::ParticleSystem']]],
   ['cmdoptimisation',['CmdOptimisation',['../class_ogre_1_1_d3_d9_h_l_s_l_program_1_1_cmd_optimisation.html',1,'Ogre::D3D9HLSLProgram::CmdOptimisation'],['../class_ogre_1_1_g_l_s_l_e_s_program_1_1_cmd_optimisation.html',1,'Ogre::GLSLESProgram::CmdOptimisation']]],
-  ['cmdoutputoperationtype',['CmdOutputOperationType',['../class_ogre_1_1_g_l_s_l_shader_common_1_1_cmd_output_operation_type.html',1,'Ogre::GLSLShaderCommon']]],
   ['cmdplanenormal',['CmdPlaneNormal',['../class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_normal.html',1,'Ogre::DeflectorPlaneAffector']]],
   ['cmdplanepoint',['CmdPlanePoint',['../class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_point.html',1,'Ogre::DeflectorPlaneAffector']]],
   ['cmdplaymode',['CmdPlayMode',['../class_ogre_1_1_external_texture_source_1_1_cmd_play_mode.html',1,'Ogre::ExternalTextureSource']]],
   ['cmdpointrendering',['CmdPointRendering',['../class_ogre_1_1_billboard_particle_renderer_1_1_cmd_point_rendering.html',1,'Ogre::BillboardParticleRenderer']]],
-  ['cmdposition',['CmdPosition',['../class_ogre_1_1_emitter_commands_1_1_cmd_position.html',1,'Ogre::EmitterCommands']]],
   ['cmdpreprocessordefines',['CmdPreprocessorDefines',['../class_ogre_1_1_d3_d11_h_l_s_l_program_1_1_cmd_preprocessor_defines.html',1,'Ogre::D3D11HLSLProgram::CmdPreprocessorDefines'],['../class_ogre_1_1_d3_d9_h_l_s_l_program_1_1_cmd_preprocessor_defines.html',1,'Ogre::D3D9HLSLProgram::CmdPreprocessorDefines'],['../class_ogre_1_1_g_l_s_l_shader_common_1_1_cmd_preprocessor_defines.html',1,'Ogre::GLSLShaderCommon::CmdPreprocessorDefines']]],
   ['cmdprofiles',['CmdProfiles',['../class_ogre_1_1_cg_program_1_1_cmd_profiles.html',1,'Ogre::CgProgram::CmdProfiles'],['../class_ogre_1_1_g_l_s_l_e_s_cg_program_1_1_cmd_profiles.html',1,'Ogre::GLSLESCgProgram::CmdProfiles']]],
   ['cmdquota',['CmdQuota',['../class_ogre_1_1_particle_system_1_1_cmd_quota.html',1,'Ogre::ParticleSystem']]],
@@ -114,7 +93,6 @@ var searchData=
   ['cmdredadjust1',['CmdRedAdjust1',['../class_ogre_1_1_colour_fader_affector2_1_1_cmd_red_adjust1.html',1,'Ogre::ColourFaderAffector2']]],
   ['cmdredadjust2',['CmdRedAdjust2',['../class_ogre_1_1_colour_fader_affector2_1_1_cmd_red_adjust2.html',1,'Ogre::ColourFaderAffector2']]],
   ['cmdrenderer',['CmdRenderer',['../class_ogre_1_1_particle_system_1_1_cmd_renderer.html',1,'Ogre::ParticleSystem']]],
-  ['cmdrepeatdelay',['CmdRepeatDelay',['../class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html',1,'Ogre::EmitterCommands']]],
   ['cmdrotationrangeend',['CmdRotationRangeEnd',['../class_ogre_1_1_rotation_affector_1_1_cmd_rotation_range_end.html',1,'Ogre::RotationAffector']]],
   ['cmdrotationrangestart',['CmdRotationRangeStart',['../class_ogre_1_1_rotation_affector_1_1_cmd_rotation_range_start.html',1,'Ogre::RotationAffector']]],
   ['cmdrotationspeedrangeend',['CmdRotationSpeedRangeEnd',['../class_ogre_1_1_rotation_affector_1_1_cmd_rotation_speed_range_end.html',1,'Ogre::RotationAffector']]],
@@ -130,10 +108,7 @@ var searchData=
   ['cmdtimeadjust',['CmdTimeAdjust',['../class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html',1,'Ogre::ColourInterpolatorAffector']]],
   ['cmdtop',['CmdTop',['../class_ogre_1_1_overlay_element_commands_1_1_cmd_top.html',1,'Ogre::OverlayElementCommands']]],
   ['cmdtransparent',['CmdTransparent',['../class_ogre_1_1_panel_overlay_element_1_1_cmd_transparent.html',1,'Ogre::PanelOverlayElement']]],
-  ['cmdttl',['CmdTTL',['../class_ogre_1_1_emitter_commands_1_1_cmd_t_t_l.html',1,'Ogre::EmitterCommands']]],
-  ['cmdup',['CmdUp',['../class_ogre_1_1_emitter_commands_1_1_cmd_up.html',1,'Ogre::EmitterCommands']]],
   ['cmduvcoords',['CmdUVCoords',['../class_ogre_1_1_panel_overlay_element_1_1_cmd_u_v_coords.html',1,'Ogre::PanelOverlayElement']]],
-  ['cmdvelocity',['CmdVelocity',['../class_ogre_1_1_emitter_commands_1_1_cmd_velocity.html',1,'Ogre::EmitterCommands']]],
   ['cmdverticalalign',['CmdVerticalAlign',['../class_ogre_1_1_overlay_element_commands_1_1_cmd_vertical_align.html',1,'Ogre::OverlayElementCommands']]],
   ['cmdvisible',['CmdVisible',['../class_ogre_1_1_overlay_element_commands_1_1_cmd_visible.html',1,'Ogre::OverlayElementCommands']]],
   ['cmdwidth',['CmdWidth',['../class_ogre_1_1_area_emitter_1_1_cmd_width.html',1,'Ogre::AreaEmitter::CmdWidth'],['../class_ogre_1_1_overlay_element_commands_1_1_cmd_width.html',1,'Ogre::OverlayElementCommands::CmdWidth'],['../class_ogre_1_1_particle_system_1_1_cmd_width.html',1,'Ogre::ParticleSystem::CmdWidth']]],
@@ -187,6 +162,7 @@ var searchData=
   ['concretenode',['ConcreteNode',['../struct_ogre_1_1_concrete_node.html',1,'Ogre']]],
   ['configdialog',['ConfigDialog',['../class_ogre_1_1_config_dialog.html',1,'Ogre::ConfigDialog'],['../class_ogre_bites_1_1_config_dialog.html',1,'OgreBites::ConfigDialog']]],
   ['configfile',['ConfigFile',['../class_ogre_1_1_config_file.html',1,'Ogre']]],
+  ['configoption',['ConfigOption',['../struct_ogre_1_1_config_option.html',1,'Ogre']]],
   ['constmapiterator',['ConstMapIterator',['../class_ogre_1_1_const_map_iterator.html',1,'Ogre']]],
   ['constparameter',['ConstParameter',['../class_ogre_1_1_r_t_shader_1_1_const_parameter.html',1,'Ogre::RTShader']]],
   ['constvectoriterator',['ConstVectorIterator',['../class_ogre_1_1_const_vector_iterator.html',1,'Ogre']]],
