@@ -31,12 +31,12 @@ var searchData=
   ['glcopyingrendertexture',['GLCopyingRenderTexture',['../class_ogre_1_1_g_l_copying_render_texture.html',1,'Ogre']]],
   ['glcopyingrttmanager',['GLCopyingRTTManager',['../class_ogre_1_1_g_l_copying_r_t_t_manager.html',1,'Ogre']]],
   ['gldepthbuffer',['GLDepthBuffer',['../class_ogre_1_1_g_l_depth_buffer.html',1,'Ogre']]],
+  ['gldepthbuffercommon',['GLDepthBufferCommon',['../class_ogre_1_1_g_l_depth_buffer_common.html',1,'Ogre']]],
   ['gles2depthbuffer',['GLES2DepthBuffer',['../class_ogre_1_1_g_l_e_s2_depth_buffer.html',1,'Ogre']]],
   ['gles2fbomanager',['GLES2FBOManager',['../class_ogre_1_1_g_l_e_s2_f_b_o_manager.html',1,'Ogre']]],
   ['gles2fbomultirendertarget',['GLES2FBOMultiRenderTarget',['../class_ogre_1_1_g_l_e_s2_f_b_o_multi_render_target.html',1,'Ogre']]],
   ['gles2fborendertexture',['GLES2FBORenderTexture',['../class_ogre_1_1_g_l_e_s2_f_b_o_render_texture.html',1,'Ogre']]],
   ['gles2framebufferobject',['GLES2FrameBufferObject',['../class_ogre_1_1_g_l_e_s2_frame_buffer_object.html',1,'Ogre']]],
-  ['gles2gpuprogrammanager',['GLES2GpuProgramManager',['../class_ogre_1_1_g_l_e_s2_gpu_program_manager.html',1,'Ogre']]],
   ['gles2hardwarebuffer',['GLES2HardwareBuffer',['../class_ogre_1_1_g_l_e_s2_hardware_buffer.html',1,'Ogre']]],
   ['gles2hardwarebuffermanager',['GLES2HardwareBufferManager',['../class_ogre_1_1_g_l_e_s2_hardware_buffer_manager.html',1,'Ogre']]],
   ['gles2hardwareindexbuffer',['GLES2HardwareIndexBuffer',['../class_ogre_1_1_g_l_e_s2_hardware_index_buffer.html',1,'Ogre']]],
@@ -105,7 +105,6 @@ var searchData=
   ['glslshader',['GLSLShader',['../class_ogre_1_1_g_l_s_l_shader.html',1,'Ogre']]],
   ['glslshadercommon',['GLSLShaderCommon',['../class_ogre_1_1_g_l_s_l_shader_common.html',1,'Ogre']]],
   ['glslshaderfactory',['GLSLShaderFactory',['../class_ogre_1_1_g_l_s_l_shader_factory.html',1,'Ogre']]],
-  ['glslshadermanager',['GLSLShaderManager',['../class_ogre_1_1_g_l_s_l_shader_manager.html',1,'Ogre']]],
   ['glstatecachemanager',['GLStateCacheManager',['../class_ogre_1_1_g_l_state_cache_manager.html',1,'Ogre']]],
   ['glstatecachemanagercommon',['GLStateCacheManagerCommon',['../class_ogre_1_1_g_l_state_cache_manager_common.html',1,'Ogre']]],
   ['glsurfacedesc',['GLSurfaceDesc',['../struct_ogre_1_1_g_l_surface_desc.html',1,'Ogre']]],
