@@ -31,5 +31,5 @@ var searchData=
   ['trianglefacenormallist',['TriangleFaceNormalList',['../class_ogre_1_1_edge_data.html#a64e153ea58ec4f80064986f2d9db201d',1,'Ogre::EdgeData']]],
   ['trianglelightfacinglist',['TriangleLightFacingList',['../class_ogre_1_1_edge_data.html#a40386af98df21e634c60b85d4434684b',1,'Ogre::EdgeData']]],
   ['trianglelist',['TriangleList',['../class_ogre_1_1_edge_data.html#afaf35a82abd84227e184cf35be1255b6',1,'Ogre::EdgeData::TriangleList()'],['../struct_ogre_1_1_lod_data.html#a3041597a221fda483795a206a9c8d481',1,'Ogre::LodData::TriangleList()']]],
-  ['type',['Type',['../class_ogre_1_1_com_ptr.html#acea4812003c2493f333bd710a077a32a',1,'Ogre::ComPtr::Type()'],['../struct_ogre_1_1deque.html#a8ef708c605cdfef7dde4d3aa3ed8ea99',1,'Ogre::deque::type()'],['../struct_ogre_1_1vector.html#a433d2c685114e4935ed8b8126540f874',1,'Ogre::vector::type()'],['../struct_ogre_1_1list.html#af5f494d11293e3207bf6d71dfd559a3b',1,'Ogre::list::type()'],['../struct_ogre_1_1set.html#ab212178827fff17754a2926d84f8f4dc',1,'Ogre::set::type()'],['../struct_ogre_1_1map.html#a32ee61e7fed8a58db9379ed59cc20d33',1,'Ogre::map::type()'],['../struct_ogre_1_1multimap.html#aaed3d4a16033f6f15eca2ceb551ad258',1,'Ogre::multimap::type()']]]
+  ['type',['type',['../struct_ogre_1_1deque.html#a8ef708c605cdfef7dde4d3aa3ed8ea99',1,'Ogre::deque::type()'],['../struct_ogre_1_1vector.html#a433d2c685114e4935ed8b8126540f874',1,'Ogre::vector::type()'],['../struct_ogre_1_1list.html#af5f494d11293e3207bf6d71dfd559a3b',1,'Ogre::list::type()'],['../struct_ogre_1_1set.html#ab212178827fff17754a2926d84f8f4dc',1,'Ogre::set::type()'],['../struct_ogre_1_1map.html#a32ee61e7fed8a58db9379ed59cc20d33',1,'Ogre::map::type()'],['../struct_ogre_1_1multimap.html#aaed3d4a16033f6f15eca2ceb551ad258',1,'Ogre::multimap::type()'],['../class_ogre_1_1_com_ptr.html#acea4812003c2493f333bd710a077a32a',1,'Ogre::ComPtr::Type()']]]
 ];
