@@ -45,7 +45,7 @@ var searchData=
   ['currentsize',['currentSize',['../struct_ogre_1_1_gpu_logical_index_use.html#a01c5262cf4575c5eee15bca1f318762c',1,'Ogre::GpuLogicalIndexUse']]],
   ['currenttimemillisecs',['currentTimeMillisecs',['../struct_ogre_1_1_profile_history.html#adb6659f5cf777d82b1f17f030674e7f3',1,'Ogre::ProfileHistory']]],
   ['currenttimepercent',['currentTimePercent',['../struct_ogre_1_1_profile_history.html#a68871d928375a383c656513031642560',1,'Ogre::ProfileHistory']]],
-  ['currentvalue',['currentValue',['../struct_ogre_1_1___config_option.html#aa41fec08addba15ef4c67b7c8db86f04',1,'Ogre::_ConfigOption']]],
+  ['currentvalue',['currentValue',['../struct_ogre_1_1_config_option.html#a0e082b7e9f4874eca45b5634d327e5e9',1,'Ogre::ConfigOption']]],
   ['currtime',['currTime',['../class_ogre_1_1_profile_instance.html#ad19af15bb373d720d1b2caf30cf92ed6',1,'Ogre::ProfileInstance']]],
   ['customattributestring_5ffbo',['CustomAttributeString_FBO',['../class_ogre_1_1_g_l_render_texture.html#a0c1183426657f0c4bb9cab4d0849e6cd',1,'Ogre::GLRenderTexture']]],
   ['customattributestring_5fglcontext',['CustomAttributeString_GLCONTEXT',['../class_ogre_1_1_g_l_render_texture.html#a71d9d9ecb01f76de433f3b3b1fd3b8ce',1,'Ogre::GLRenderTexture']]],
